/************************************************************************************/
/*  Copyright (C)           Microcyber Inc. All Rights Reserved                     */
/*  Product:                NCS-FI105 Profibus PA                                   */
/*                                                                                  */
/*  Device:                 NCS-FI105 Fieldbus to Current Converter for PROFIBUS PA */
/*  Description:            Device Description File                                 */
/*  Dictionary:             SIPADC01.dct                                            */
/*                                                                                  */
/*  Revision:  1.0                                                                  */
/*  Date:      2012-04-10                                                           */
/*  Author:    Ning Dekui                                                           */
/************************************************************************************/
MANUFACTURER            0x16c,
DEVICE_TYPE             0x01,
DEVICE_REVISION         0x01,
DD_REVISION             0x01

#define _NCS_FI
#define DEVICE_TYPE "NCS_FI105"

#include "SI_FileM.inc"
#include "SI_HlpM.inc"
#include "SI_OptM.inc"
#include "SIPAST_CommError.inc"

/*
#include "SI_MainMenu.inc"
#include "SI_ViewM.inc"
*/

#include "defmacros.inc"
#include "Phys_Blk.inc"
#include "AO4_Blk5.inc"
#include "LCD_Blk10.inc"
#include "MC_YT.inc" 


/***********************************************************************/
/*    Transducer Block 1                                               */
/***********************************************************************/

BLOCK transducer_block_1
{
    TYPE    TRANSDUCER;
    NUMBER    1;
}

trans1_FI_1_blk_reserve                          LIKE VARIABLE    phys_blk_reserve
{
}

VARIABLE trans1_FI_1_blk_object
{
    LABEL        [blk_block_object];
    HELP        [blk_block_object_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        {    3,    [blk_block_object_TRANSDUCER]        }
    }
    CLASS       DEVICE;// TEMPORARY ;
    HANDLING    READ;
}

VARIABLE trans1_FI_1_blk_parent_class
{
    LABEL        [blk_parent_class];
    HELP        [trans_blk_parent_class_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        {    240,    "Converter"   }
    }
    HANDLING    READ;
}

VARIABLE trans1_FI_1_blk_class
{
    LABEL        [blk_class];
    HELP        [trans_blk_class_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        SELECT( trans1_FI_1_blk_parent_class )
        {
            CASE 240:
            {    1,        "Fieldbus to Current"         },

            DEFAULT:
            {    1,        [standard]                    },
        }
        {    250,    [not_used]                          },
        {    251,    [none]                              },
        {    252,    [unknown]                           },
        {    253,    [special]                           }
    }
    CLASS       DEVICE;// TEMPORARY ;
    HANDLING    READ;
}

trans1_FI_1_blk_dd_reference                     LIKE VARIABLE    phys_blk_dd_reference
{
}

trans1_FI_1_blk_dd_rev                           LIKE VARIABLE    phys_blk_dd_rev
{
}

trans1_FI_1_blk_profile                          LIKE VARIABLE    phys_blk_profile
{
}

trans1_FI_1_blk_profile_rev                      LIKE VARIABLE    phys_blk_profile_rev
{
}

trans1_FI_1_blk_execution_time                   LIKE VARIABLE    phys_blk_execution_time
{
}

trans1_FI_1_blk_num_parameters                   LIKE VARIABLE    phys_blk_num_parameters
{
}

trans1_FI_1_blk_index_view_1                     LIKE VARIABLE    phys_blk_index_view_1
{
}

trans1_FI_1_blk_num_view_lists                   LIKE VARIABLE    phys_blk_num_view_lists
{
}

trans1_FI_1_st_rev                               LIKE VARIABLE    phys_st_rev
{
}

trans1_FI_1_tag_desc                             LIKE VARIABLE    phys_tag_desc
{
    REDEFINE LABEL        "Transducer 1 Tag";
}

trans1_FI_1_strategy                             LIKE VARIABLE    phys_strategy
{
}

trans1_FI_1_alert_key                            LIKE VARIABLE    phys_alert_key
{
}

trans1_FI_1_target_mode                          LIKE VARIABLE    phys_target_mode
{
}

trans1_FI_1_actual_mode                          LIKE VARIABLE    phys_actual_mode
{
}

trans1_FI_1_permitted_mode                       LIKE VARIABLE    phys_permitted_mode
{
}

trans1_FI_1_normal_mode                          LIKE VARIABLE    phys_normal_mode
{
}

trans1_FI_1_current_state_alarm_sum              LIKE VARIABLE    phys_current_state_alarm_sum
{
}

trans1_FI_1_unacknowledged_state_alarm_sum       LIKE VARIABLE    phys_unacknowledged_state_alarm_sum
{
}

trans1_FI_1_unreported_state_alarm_sum           LIKE VARIABLE    phys_unreported_state_alarm_sum
{
}

trans1_FI_1_disabled_state_alarm_sum             LIKE VARIABLE    phys_disabled_state_alarm_sum
{
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: Fieldbus to Current Converter                  */
/*---------------------------------------------------------------------*/
VARIABLE trans1_FI_1_final_value
{
    LABEL       "Final Value";
    HELP        "Final Value";
    CLASS       CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ;
}
VARIABLE trans1_FI_1_final_value_status
{
    LABEL       [status_limit];
    HELP        [value_status_help];
    CLASS       CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_GENERAL//STATUS_OUTPUT_NO_RCAS
    }
    HANDLING    READ;
}
//VARIABLE trans1_FI_1_final_value_status
//{
//    LABEL       [status_quality];
//    HELP        [value_status_help];
//    CLASS       CONTAINED & DYNAMIC;
//    TYPE        ENUMERATED (1)
//    {
//        DEFAULT_VALUE    0;
//        STATUS_GENERAL//STATUS_OUTPUT_NO_RCAS
//    }
//    HANDLING    READ;
//}

//VARIABLE trans1_FI_1_final_value_status_quality
//{
//    LABEL       [status_quality];
//    HELP        [value_status_help];
//    CLASS       CONTAINED & DYNAMIC;
//    TYPE        ENUMERATED (1)
//    {
//        DEFAULT_VALUE    0;
//        STATUS_OUTPUT_NO_RCAS
//    }
//    HANDLING    READ;
//}

//trans1_FI_1_final_value_status_limit            LIKE VARIABLE    trans1_FI_1_final_value_status_quality
//{
//    REDEFINE LABEL       [status_limit];        
//    REDEFINE TYPE        ENUMERATED (1)
//    {
//        STATUS_OUTPUT_LIMIT
//    }
//}

VARIABLE trans1_FI_1_final_value_upper_range
{
	LABEL		"Upper [EU(100%)]";
	HELP		"Upper [EU(100%)]";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	20.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_1_final_value_lower_range
{
	LABEL		"Lower [EU(0%)]";
	HELP		"Lower [EU(0%)]";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	4.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_1_final_value_range_unit
{
	LABEL		"Unit";
	HELP		"Unit";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 1211;
		{ 1211,  [mA], 		[mA_help] }
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_1_final_value_range_decimal_point
{
	LABEL		[decimal_point];
	HELP		[decimal_point_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	2;
		{	0,   "0"		},
		{	1,   "1"		},
		{	2,   "2"		},
		{	3,   "3"		},
		{	4,   "4"		},
		{	5,   "5"		}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_1_cal_point_hi
{
    LABEL       [trans_cal_point_hi];        
    HELP        [trans_cal_point_hi_help];
    CLASS       CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    20.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_1_cal_point_lo
{
    LABEL       [trans_cal_point_lo];        
    HELP        [trans_cal_point_lo_help];
    CLASS       CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    4.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_1_cal_min_span
{
    LABEL       [trans_cal_min_span];        
    HELP        [trans_cal_min_span_help];
    CLASS       CONTAINED;
    TYPE        FLOAT;
    HANDLING    READ;
}

VARIABLE trans1_FI_1_cal_unit
{
    LABEL       "Calibration Unit";
    HELP        "Calibration Unit";
    CLASS       CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEFAULT_VALUE    1211;
        { 1211,  [mA], 		[mA_help] }
    }
    HANDLING    READ;
}

VARIABLE trans1_FI_1_act_sn
{
    LABEL       "Serial Number";
    HELP        "Serial number";
    CLASS        CONTAINED;
    TYPE        ASCII (32)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_1_cal_loc
{
    LABEL       "Maintenance Location";
    HELP        "Maintenance Location";
    CLASS        CONTAINED;
    TYPE        ASCII (32)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_1_cal_date
{
    LABEL       "Maintenance Date";
    HELP        "Maintenance Date";
    CLASS        CONTAINED;
    TYPE        ASCII (16)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_1_cal_who
{
    LABEL       "Maintenance Staff";
    HELP        "Maintenance Staff";
    CLASS        CONTAINED;
    TYPE        ASCII (32)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_1_return_value
{
    LABEL       "Return Value";
    HELP        "Return Value";
    CLASS       CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ;
}

VARIABLE trans1_FI_1_return_value_status
{
    LABEL       [status_limit];
    HELP        [value_status_help];
    CLASS       CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_GENERAL//STATUS_OUTPUT_NO_RCAS
    }
    HANDLING    READ;
}
//VARIABLE trans1_FI_1_return_value_status_quality
//{
//    LABEL       [status_quality];
//    HELP        [value_status_help];
//    CLASS       CONTAINED & DYNAMIC;
//    TYPE        ENUMERATED (1)
//    {
//        DEFAULT_VALUE    0;
//        STATUS_OUTPUT_NO_RCAS
//    }
//    HANDLING    READ;
//}

//trans1_FI_1_return_value_status_limit            LIKE VARIABLE    trans1_FI_1_return_value_status_quality
//{
//    REDEFINE LABEL       [status_limit];        
//    REDEFINE TYPE        ENUMERATED (1)
//    {
//        STATUS_OUTPUT_LIMIT
//    }
//}

VARIABLE trans1_FI_1_sensor_value
{
    LABEL       "Sensor Value";
    HELP        "Sensor Value";
    CLASS       CONTAINED & DYNAMIC;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_1_lin_type
{
    LABEL       "Linearization Type";    
    HELP        [trans_lin_type_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        {   0,      "No Linearization."		        },
        {   1,      "User defined. (Table)"		}
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_1_cal_control
{
    LABEL       "Calibration Control";    
    HELP        "Calibration Control";
    CLASS       CONTAINED;
	TYPE		UNSIGNED_INTEGER(1)
	{
		DEFAULT_VALUE	0;
		{0, "False"},
		{1, "True"}
	}
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_1_tab_entryidx
{
    LABEL       "TAB ENTRY";    
    HELP        "TAB ENTRY";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}

VARIABLE trans1_FI_1_tab_x_value
{
    LABEL       "TAB X VALUE";    
    HELP        "TAB X VALUE";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        FLOAT;
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_1_tab_y_value
{
    LABEL       "TAB Y VALUE";    
    HELP        "TAB Y VALUE";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        FLOAT;
	HANDLING    READ & WRITE ;
}

VARIABLE trans1_FI_1_tab_minnumber
{
    LABEL       "TAB MIN NUMBER";    
    HELP        "TAB MIN NUMBER";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_1_tab_maxnumber
{
    LABEL       "TAB MAX NUMBER";    
    HELP        "TAB MAX NUMBER";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_1_tab_opcode
{
    LABEL       "TAB OP CODE";    
    HELP        "TAB OP CODE";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE            ENUMERATED (1)  /* UNSIGNED_INTEGER (1)  */
    {
        {	0, [lin_tab_op_code_NOT_INIT] },
        {	1, [lin_tab_op_code_START]	},
        {	2, "Reserved."},
        {	3, [lin_tab_op_code_END]},
	    {	4, [lin_tab_op_code_DELETE_VALUE]},
        {	5, [lin_tab_op_code_INSERT_VALUE]},
        {	6, [lin_tab_op_code_REPLACE_VALUE]}
    }
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_1_tab_status
{
    LABEL       "TAB STATUS";    
    HELP        "TAB STATUS";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE    ENUMERATED (1)  /* UNSIGNED_INTEGER (1)  */
    {
        {	0, [lin_tab_status_NOT_INIT]},
        {	1, [lin_tab_status_GOOD]},
		{	2, [lin_tab_status_NOT_INC]},
        {	3, [lin_tab_status_NOT_DEC]},
        {	4, [lin_tab_status_NOT_ENOUGH_VALUES]},
		{	5, [lin_tab_status_TOO_MANY_VALUES]},
		{	6, [lin_tab_status_GRADIENT]},
		{	7, [lin_tab_status_NOT_ACCEPTED]},
        {	8, "Table is currently loaded"},
        {	9, "sorting and checking of Table"},
        {	20, [lin_tab_status_NOT_INC]},
        {	21, [lin_tab_status_NOT_DEC]},
        {	22, [lin_tab_status_NOT_ENOUGH_VALUES]},
		{	23, [lin_tab_status_TOO_MANY_VALUES]},
		{	24, [lin_tab_status_GRADIENT]},
		{	25, [lin_tab_status_NOT_ACCEPTED]},
        {	26, "Table is currently loaded"},
        {	27, "sorting and checking of Table"}
    }
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_1_tab_actualnumber
{
    LABEL       "TAB ACTUAL NUMBER";    
    HELP        "TAB ACTUAL NUMBER";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}

VARIABLE table_x_1
{
	LABEL		"X1:";
	CLASS  	    LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 0.0;
	}
}

VARIABLE table_x_2
{
	LABEL		"X2:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 5.0;
	}
}

VARIABLE table_x_3
{
	LABEL		"X3:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 10.0;
	}
}

VARIABLE table_x_4
{
	LABEL		"X4:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 15.0;
	}
}

VARIABLE table_x_5
{
	LABEL		"X5:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 20.0;
	}
}

VARIABLE table_x_6
{
	LABEL		"X6:";
	CLASS   	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 25.0;
	}
}

VARIABLE table_x_7
{
	LABEL		"X7:";
	CLASS       LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 30.0;
	}
}

VARIABLE table_x_8
{
	LABEL		"X8:";
	CLASS       LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 40.0;
	}
}

VARIABLE table_x_9
{
	LABEL		"X9:";
	CLASS  	    LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 50.0;
	}
}

VARIABLE table_x_10
{
	LABEL		"X10:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 60.0;
	}
}

VARIABLE table_x_11
{
	LABEL		"X11:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 70.0;
	}
}

VARIABLE table_x_12
{
	LABEL		"X12:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 80.0;
	}
}

VARIABLE table_x_13
{
	LABEL		"X13:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 85.0;
	}
}

VARIABLE table_x_14
{
	LABEL		"X14:";
	CLASS   	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 90.0;
	}
}

VARIABLE table_x_15
{
	LABEL		"X15:";
	CLASS       LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 95.0;
	}
}

VARIABLE table_x_16
{
	LABEL		"X16:";
	CLASS       LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 100.0;
	}
}

VARIABLE table_y_1
{
	LABEL		"Y1";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 0.0;
	}
}

VARIABLE table_y_2
{
	LABEL		"Y2";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 5.0;
	}
}

VARIABLE table_y_3
{
	LABEL		"Y3:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 10.0;
	}
}

VARIABLE table_y_4
{
	LABEL		"Y4:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 15.0;
	}
}

VARIABLE table_y_5
{
	LABEL		"Y5:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 20.0;
	}
}

VARIABLE table_y_6
{
	LABEL		"Y6:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 25.0;
	}
}

VARIABLE table_y_7
{
	LABEL		"Y7:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 30.0;
	}
}

VARIABLE table_y_8
{
	LABEL		"Y8:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 40.0;
	}
}
VARIABLE table_y_9
{
	LABEL		"Y9";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 50.0;
	}
}

VARIABLE table_y_10
{
	LABEL		"Y10";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 60.0;
	}
}

VARIABLE table_y_11
{
	LABEL		"Y11:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 70.0;
	}
}

VARIABLE table_y_12
{
	LABEL		"Y12:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 80.0;
	}
}

VARIABLE table_y_13
{
	LABEL		"Y13:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 85.0;
	}
}

VARIABLE table_y_14
{
	LABEL		"Y14:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 90.0;
	}
}

VARIABLE table_y_15
{
	LABEL		"Y15:";
	CLASS  	LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 95.0;
	}
}

VARIABLE table_y_16
{
	LABEL		"Y16:";
	CLASS       LOCAL;
	TYPE 		FLOAT
	{
		DEFAULT_VALUE 100.0;
	}
}

VARIABLE trans1_FI_1_actuator_action
{
    LABEL       "Actuator_Action";    
    HELP        "Fail-Safe position for power-loss of the actuator respectively the valve";
    CLASS        CONTAINED;
    TYPE        ENUMERATED (1)
    {
                DEFAULT_VALUE    0;
        {   0,      "Not initialized"   },
        {   1,      "Opening(100%)"		},
        {   2,      "Closing(0)%"       },
        {   3,      "None/remain in actual position"}
    }
    HANDLING    READ & WRITE;
}

UNIT TRANS1_FI_1_FINAL_VALUE_UNIT
{
    trans1_FI_1_final_value_range_unit:

    trans1_FI_1_final_value_upper_range,
    trans1_FI_1_final_value_lower_range,
    trans1_FI_1_final_value,
    trans1_FI_1_sensor_value,
    trans1_FI_1_return_value
}

UNIT TRANS1_FI_1_CAL_UNIT
{
    trans1_FI_1_cal_unit:

    trans1_FI_1_cal_point_hi,
    trans1_FI_1_cal_point_lo,
    trans1_FI_1_cal_min_span
}

/***********************************************************************/
/*    Transducer Block 2                                               */
/***********************************************************************/

BLOCK transducer_block_2
{
    TYPE    TRANSDUCER;
    NUMBER    2;
}

trans1_FI_2_blk_reserve                          LIKE VARIABLE    phys_blk_reserve
{
}

VARIABLE trans1_FI_2_blk_object
{
    LABEL        [blk_block_object];
    HELP        [blk_block_object_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        {    3,    [blk_block_object_TRANSDUCER]        }
    }
    CLASS       DEVICE;// TEMPORARY ;
    HANDLING    READ;
}

VARIABLE trans1_FI_2_blk_parent_class
{
    LABEL        [blk_parent_class];
    HELP        [trans_blk_parent_class_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        {    240,    "Converter"   }
    }
    HANDLING    READ;
}

VARIABLE trans1_FI_2_blk_class
{
    LABEL        [blk_class];
    HELP        [trans_blk_class_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        SELECT( trans1_FI_2_blk_parent_class )
        {
            CASE 240:
            {    1,        "Fieldbus to Current"         },

            DEFAULT:
            {    1,        [standard]                    },
        }
        {    250,    [not_used]                          },
        {    251,    [none]                              },
        {    252,    [unknown]                           },
        {    253,    [special]                           }
    }
    CLASS       DEVICE;// TEMPORARY ;
    HANDLING    READ;
}

trans1_FI_2_blk_dd_reference                     LIKE VARIABLE    phys_blk_dd_reference
{
}

trans1_FI_2_blk_dd_rev                           LIKE VARIABLE    phys_blk_dd_rev
{
}

trans1_FI_2_blk_profile                          LIKE VARIABLE    phys_blk_profile
{
}

trans1_FI_2_blk_profile_rev                      LIKE VARIABLE    phys_blk_profile_rev
{
}

trans1_FI_2_blk_execution_time                   LIKE VARIABLE    phys_blk_execution_time
{
}

trans1_FI_2_blk_num_parameters                   LIKE VARIABLE    phys_blk_num_parameters
{
}

trans1_FI_2_blk_index_view_1                     LIKE VARIABLE    phys_blk_index_view_1
{
}

trans1_FI_2_blk_num_view_lists                   LIKE VARIABLE    phys_blk_num_view_lists
{
}

trans1_FI_2_st_rev                               LIKE VARIABLE    phys_st_rev
{
}

trans1_FI_2_tag_desc                             LIKE VARIABLE    phys_tag_desc
{
    REDEFINE LABEL        "Transducer 2 Tag";
}

trans1_FI_2_strategy                             LIKE VARIABLE    phys_strategy
{
}

trans1_FI_2_alert_key                            LIKE VARIABLE    phys_alert_key
{
}

trans1_FI_2_target_mode                          LIKE VARIABLE    phys_target_mode
{
}

trans1_FI_2_actual_mode                          LIKE VARIABLE    phys_actual_mode
{
}

trans1_FI_2_permitted_mode                       LIKE VARIABLE    phys_permitted_mode
{
}

trans1_FI_2_normal_mode                          LIKE VARIABLE    phys_normal_mode
{
}

trans1_FI_2_current_state_alarm_sum              LIKE VARIABLE    phys_current_state_alarm_sum
{
}

trans1_FI_2_unacknowledged_state_alarm_sum       LIKE VARIABLE    phys_unacknowledged_state_alarm_sum
{
}

trans1_FI_2_unreported_state_alarm_sum           LIKE VARIABLE    phys_unreported_state_alarm_sum
{
}

trans1_FI_2_disabled_state_alarm_sum             LIKE VARIABLE    phys_disabled_state_alarm_sum
{
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: Fieldbus to Current Converter                  */
/*---------------------------------------------------------------------*/
VARIABLE trans1_FI_2_final_value
{
    LABEL       "Final Value";
    HELP        "Final Value";
    CLASS       CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ;
}
VARIABLE trans1_FI_2_final_value_status
{
    LABEL       [status_limit];
    HELP        [value_status_help];
    CLASS       CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_GENERAL//STATUS_OUTPUT_NO_RCAS
    }
    HANDLING    READ;
}
//VARIABLE trans1_FI_2_final_value_status_quality
//{
//    LABEL       [status_quality];
//    HELP        [value_status_help];
//    CLASS       CONTAINED & DYNAMIC;
//    TYPE        ENUMERATED (1)
//    {
//        DEFAULT_VALUE    0;
//        STATUS_OUTPUT_NO_RCAS
//    }
//    HANDLING    READ;
//}
//
//trans1_FI_2_final_value_status_limit            LIKE VARIABLE    trans1_FI_2_final_value_status_quality
//{
//    REDEFINE LABEL       [status_limit];        
//    REDEFINE TYPE        ENUMERATED (1)
//    {
//        STATUS_OUTPUT_LIMIT
//    }
//}

VARIABLE trans1_FI_2_final_value_upper_range
{
	LABEL		"Upper [EU(100%)]";
	HELP		"Upper [EU(100%)]";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	20.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_2_final_value_lower_range
{
	LABEL		"Lower [EU(0%)]";
	HELP		"Lower [EU(0%)]";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	4.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_2_final_value_range_unit
{
	LABEL		"Unit";
	HELP		"Unit";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 1211;
		{ 1211,  [mA], 		[mA_help] }
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_2_final_value_range_decimal_point
{
	LABEL		[decimal_point];
	HELP		[decimal_point_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	2;
		{	0,   "0"		},
		{	1,   "1"		},
		{	2,   "2"		},
		{	3,   "3"		},
		{	4,   "4"		},
		{	5,   "5"		}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_2_cal_point_hi
{
    LABEL       [trans_cal_point_hi];        
    HELP        [trans_cal_point_hi_help];
    CLASS       CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    20.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_2_cal_point_lo
{
    LABEL       [trans_cal_point_lo];        
    HELP        [trans_cal_point_lo_help];
    CLASS       CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    4.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_2_cal_min_span
{
    LABEL       [trans_cal_min_span];        
    HELP        [trans_cal_min_span_help];
    CLASS       CONTAINED;
    TYPE        FLOAT;
    HANDLING    READ;
}

VARIABLE trans1_FI_2_cal_unit
{
    LABEL       "Calibration Unit";
    HELP        "Calibration Unit";
    CLASS       CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEFAULT_VALUE    1211;
        { 1211,  [mA], 		[mA_help] }
    }
    HANDLING    READ;
}

VARIABLE trans1_FI_2_act_sn
{
    LABEL       "Serial Number";
    HELP        "Serial number";
    CLASS        CONTAINED;
    TYPE        ASCII (32)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_2_cal_loc
{
    LABEL       "Maintenance Location";
    HELP        "Maintenance Location";
    CLASS        CONTAINED;
    TYPE        ASCII (32)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_2_cal_date
{
    LABEL       "Maintenance Date";
    HELP        "Maintenance Date";
    CLASS        CONTAINED;
    TYPE        ASCII (16)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_2_cal_who
{
    LABEL       "Maintenance Staff";
    HELP        "Maintenance Staff";
    CLASS        CONTAINED;
    TYPE        ASCII (32)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_2_return_value
{
    LABEL       "Return Value";
    HELP        "Return Value";
    CLASS       CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ;
}
VARIABLE trans1_FI_2_return_value_status
{
    LABEL       [status_limit];
    HELP        [value_status_help];
    CLASS       CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_GENERAL//STATUS_OUTPUT_NO_RCAS
    }
    HANDLING    READ;
}
//VARIABLE trans1_FI_2_return_value_status_quality
//{
//    LABEL       [status_quality];
//    HELP        [value_status_help];
//    CLASS       CONTAINED & DYNAMIC;
//    TYPE        ENUMERATED (1)
//    {
//        DEFAULT_VALUE    0;
//        STATUS_OUTPUT_NO_RCAS
//    }
//    HANDLING    READ;
//}
//
//trans1_FI_2_return_value_status_limit            LIKE VARIABLE    trans1_FI_2_return_value_status_quality
//{
//    REDEFINE LABEL       [status_limit];        
//    REDEFINE TYPE        ENUMERATED (1)
//    {
//        STATUS_OUTPUT_LIMIT
//    }
//}

VARIABLE trans1_FI_2_sensor_value
{
    LABEL       "Sensor Value";
    HELP        "Sensor Value";
    CLASS       CONTAINED & DYNAMIC;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_2_lin_type
{
    LABEL       "Linearization Type";    
    HELP        [trans_lin_type_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        {   0,      "No Linearization."		        },
        {   1,      "User defined. (Table)"		}
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_2_cal_control
{
    LABEL       "Calibration Control";    
    HELP        "Calibration Control";
    CLASS       CONTAINED;
	TYPE		UNSIGNED_INTEGER(1)
	{
		DEFAULT_VALUE	0;
		{0, "False"},
		{1, "True"}
	}
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_2_tab_entryidx
{
    LABEL       "TAB ENTRY";    
    HELP        "TAB ENTRY";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}

VARIABLE trans1_FI_2_tab_x_value
{
    LABEL       "TAB X VALUE";    
    HELP        "TAB X VALUE";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        FLOAT;
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_2_tab_y_value
{
    LABEL       "TAB Y VALUE";    
    HELP        "TAB Y VALUE";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        FLOAT;
	HANDLING    READ & WRITE ;
}

VARIABLE trans1_FI_2_tab_minnumber
{
    LABEL       "TAB MIN NUMBER";    
    HELP        "TAB MIN NUMBER";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_2_tab_maxnumber
{
    LABEL       "TAB MAX NUMBER";    
    HELP        "TAB MAX NUMBER";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_2_tab_opcode
{
    LABEL       "TAB OP CODE";    
    HELP        "TAB OP CODE";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE            ENUMERATED (1)  /* UNSIGNED_INTEGER (1)  */
    {
        {	0, [lin_tab_op_code_NOT_INIT] },
        {	1, [lin_tab_op_code_START]	},
        {	2, "Reserved."},
        {	3, [lin_tab_op_code_END]},
	    {	4, [lin_tab_op_code_DELETE_VALUE]},
        {	5, [lin_tab_op_code_INSERT_VALUE]},
        {	6, [lin_tab_op_code_REPLACE_VALUE]}
    }
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_2_tab_status
{
    LABEL       "TAB STATUS";    
    HELP        "TAB STATUS";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE    ENUMERATED (1)  /* UNSIGNED_INTEGER (1)  */
    {
        {	0, [lin_tab_status_NOT_INIT]},
        {	1, [lin_tab_status_GOOD]},
		{	2, [lin_tab_status_NOT_INC]},
        {	3, [lin_tab_status_NOT_DEC]},
        {	4, [lin_tab_status_NOT_ENOUGH_VALUES]},
		{	5, [lin_tab_status_TOO_MANY_VALUES]},
		{	6, [lin_tab_status_GRADIENT]},
		{	7, [lin_tab_status_NOT_ACCEPTED]},
        {	8, "Table is currently loaded"},
        {	9, "sorting and checking of Table"},
        {	20, [lin_tab_status_NOT_INC]},
        {	21, [lin_tab_status_NOT_DEC]},
        {	22, [lin_tab_status_NOT_ENOUGH_VALUES]},
		{	23, [lin_tab_status_TOO_MANY_VALUES]},
		{	24, [lin_tab_status_GRADIENT]},
		{	25, [lin_tab_status_NOT_ACCEPTED]},
        {	26, "Table is currently loaded"},
        {	27, "sorting and checking of Table"}
    }
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_2_tab_actualnumber
{
    LABEL       "TAB ACTUAL NUMBER";    
    HELP        "TAB ACTUAL NUMBER";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}

VARIABLE trans1_FI_2_actuator_action
{
    LABEL       "Actuator_Action";    
    HELP        "Fail-Safe position for power-loss of the actuator respectively the valve";
    CLASS        CONTAINED;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        {   0,      "Not initialized"   },
        {   1,      "Opening(100%)"		},
        {   2,      "Closing(0)%"       },
        {   3,      "None/remain in actual position"}
    }
    HANDLING    READ & WRITE;
}
UNIT TRANS1_FI_2_FINAL_VALUE_UNIT
{
    trans1_FI_2_final_value_range_unit:

    trans1_FI_2_final_value_upper_range,
    trans1_FI_2_final_value_lower_range,
    trans1_FI_2_final_value,
    trans1_FI_2_sensor_value,
    trans1_FI_2_return_value
}

UNIT TRANS1_FI_2_CAL_UNIT
{
    trans1_FI_2_cal_unit:

    trans1_FI_2_cal_point_hi,
    trans1_FI_2_cal_point_lo,
    trans1_FI_2_cal_min_span
}

/***********************************************************************/
/*    Transducer Block 3                                               */
/***********************************************************************/

BLOCK transducer_block_3
{
    TYPE    TRANSDUCER;
    NUMBER    3;
}

trans1_FI_3_blk_reserve                          LIKE VARIABLE    phys_blk_reserve
{
}

VARIABLE trans1_FI_3_blk_object
{
    LABEL        [blk_block_object];
    HELP        [blk_block_object_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        {    3,    [blk_block_object_TRANSDUCER]        }
    }
    CLASS       DEVICE;// TEMPORARY ;
    HANDLING    READ;
}

VARIABLE trans1_FI_3_blk_parent_class
{
    LABEL        [blk_parent_class];
    HELP        [trans_blk_parent_class_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        {    240,    "Converter"   }
    }
    HANDLING    READ;
}

VARIABLE trans1_FI_3_blk_class
{
    LABEL        [blk_class];
    HELP        [trans_blk_class_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        SELECT( trans1_FI_3_blk_parent_class )
        {
            CASE 240:
            {    1,        "Fieldbus to Current"         },

            DEFAULT:
            {    1,        [standard]                    },
        }
        {    250,    [not_used]                          },
        {    251,    [none]                              },
        {    252,    [unknown]                           },
        {    253,    [special]                           }
    }
    CLASS       DEVICE;// TEMPORARY ;
    HANDLING    READ;
}

trans1_FI_3_blk_dd_reference                     LIKE VARIABLE    phys_blk_dd_reference
{
}

trans1_FI_3_blk_dd_rev                           LIKE VARIABLE    phys_blk_dd_rev
{
}

trans1_FI_3_blk_profile                          LIKE VARIABLE    phys_blk_profile
{
}

trans1_FI_3_blk_profile_rev                      LIKE VARIABLE    phys_blk_profile_rev
{
}

trans1_FI_3_blk_execution_time                   LIKE VARIABLE    phys_blk_execution_time
{
}

trans1_FI_3_blk_num_parameters                   LIKE VARIABLE    phys_blk_num_parameters
{
}

trans1_FI_3_blk_index_view_1                     LIKE VARIABLE    phys_blk_index_view_1
{
}

trans1_FI_3_blk_num_view_lists                   LIKE VARIABLE    phys_blk_num_view_lists
{
}

trans1_FI_3_st_rev                               LIKE VARIABLE    phys_st_rev
{
}

trans1_FI_3_tag_desc                             LIKE VARIABLE    phys_tag_desc
{
    REDEFINE LABEL        "Transducer 3 Tag";
}

trans1_FI_3_strategy                             LIKE VARIABLE    phys_strategy
{
}

trans1_FI_3_alert_key                            LIKE VARIABLE    phys_alert_key
{
}

trans1_FI_3_target_mode                          LIKE VARIABLE    phys_target_mode
{
}

trans1_FI_3_actual_mode                          LIKE VARIABLE    phys_actual_mode
{
}

trans1_FI_3_permitted_mode                       LIKE VARIABLE    phys_permitted_mode
{
}

trans1_FI_3_normal_mode                          LIKE VARIABLE    phys_normal_mode
{
}

trans1_FI_3_current_state_alarm_sum              LIKE VARIABLE    phys_current_state_alarm_sum
{
}

trans1_FI_3_unacknowledged_state_alarm_sum       LIKE VARIABLE    phys_unacknowledged_state_alarm_sum
{
}

trans1_FI_3_unreported_state_alarm_sum           LIKE VARIABLE    phys_unreported_state_alarm_sum
{
}

trans1_FI_3_disabled_state_alarm_sum             LIKE VARIABLE    phys_disabled_state_alarm_sum
{
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: Fieldbus to Current Converter                  */
/*---------------------------------------------------------------------*/
VARIABLE trans1_FI_3_final_value
{
    LABEL       "Final Value";
    HELP        "Final Value";
    CLASS       CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ;
}
VARIABLE trans1_FI_3_final_value_status
{
    LABEL       [status_limit];
    HELP        [value_status_help];
    CLASS       CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_GENERAL//STATUS_OUTPUT_NO_RCAS
    }
    HANDLING    READ;
}
//VARIABLE trans1_FI_3_final_value_status_quality
//{
//    LABEL       [status_quality];
//    HELP        [value_status_help];
//    CLASS       CONTAINED & DYNAMIC;
//    TYPE        ENUMERATED (1)
//    {
//        DEFAULT_VALUE    0;
//        STATUS_OUTPUT_NO_RCAS
//    }
//    HANDLING    READ;
//}
//
//trans1_FI_3_final_value_status_limit            LIKE VARIABLE    trans1_FI_3_final_value_status_quality
//{
//    REDEFINE LABEL       [status_limit];        
//    REDEFINE TYPE        ENUMERATED (1)
//    {
//        STATUS_OUTPUT_LIMIT
//    }
//}

VARIABLE trans1_FI_3_final_value_upper_range
{
	LABEL		"Upper [EU(100%)]";
	HELP		"Upper [EU(100%)]";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	20.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_3_final_value_lower_range
{
	LABEL		"Lower [EU(0%)]";
	HELP		"Lower [EU(0%)]";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	4.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_3_final_value_range_unit
{
	LABEL		"Unit";
	HELP		"Unit";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 1211;
		{ 1211,  [mA], 		[mA_help] }
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_3_final_value_range_decimal_point
{
	LABEL		[decimal_point];
	HELP		[decimal_point_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	2;
		{	0,   "0"		},
		{	1,   "1"		},
		{	2,   "2"		},
		{	3,   "3"		},
		{	4,   "4"		},
		{	5,   "5"		}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_3_cal_point_hi
{
    LABEL       [trans_cal_point_hi];        
    HELP        [trans_cal_point_hi_help];
    CLASS       CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    20.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_3_cal_point_lo
{
    LABEL       [trans_cal_point_lo];        
    HELP        [trans_cal_point_lo_help];
    CLASS       CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    4.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_3_cal_min_span
{
    LABEL       [trans_cal_min_span];        
    HELP        [trans_cal_min_span_help];
    CLASS       CONTAINED;
    TYPE        FLOAT;
    HANDLING    READ;
}

VARIABLE trans1_FI_3_cal_unit
{
    LABEL       "Calibration Unit";
    HELP        "Calibration Unit";
    CLASS       CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEFAULT_VALUE    1211;
        { 1211,  [mA], 		[mA_help] }
    }
    HANDLING    READ;
}

VARIABLE trans1_FI_3_act_sn
{
    LABEL       "Serial Number";
    HELP        "Serial number";
    CLASS        CONTAINED;
    TYPE        ASCII (32)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_3_cal_loc
{
    LABEL       "Maintenance Location";
    HELP        "Maintenance Location";
    CLASS        CONTAINED;
    TYPE        ASCII (32)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_3_cal_date
{
    LABEL       "Maintenance Date";
    HELP        "Maintenance Date";
    CLASS        CONTAINED;
    TYPE        ASCII (16)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_3_cal_who
{
    LABEL       "Maintenance Staff";
    HELP        "Maintenance Staff";
    CLASS        CONTAINED;
    TYPE        ASCII (32)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_3_return_value
{
    LABEL       "Return Value";
    HELP        "Return Value";
    CLASS       CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ;
}
VARIABLE trans1_FI_3_return_value_status
{
    LABEL       [status_limit];
    HELP        [value_status_help];
    CLASS       CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_GENERAL//STATUS_OUTPUT_NO_RCAS
    }
    HANDLING    READ;
}
//VARIABLE trans1_FI_3_return_value_status_quality
//{
//    LABEL       [status_quality];
//    HELP        [value_status_help];
//    CLASS       CONTAINED & DYNAMIC;
//    TYPE        ENUMERATED (1)
//    {
//        DEFAULT_VALUE    0;
//        STATUS_GENERAL//STATUS_OUTPUT_NO_RCAS
//    }
//    HANDLING    READ;
//}
//
//trans1_FI_3_return_value_status_limit            LIKE VARIABLE    trans1_FI_3_return_value_status_quality
//{
//    REDEFINE LABEL       [status_limit];        
//    REDEFINE TYPE        ENUMERATED (1)
//    {
//        STATUS_OUTPUT_LIMIT
//    }
//}

VARIABLE trans1_FI_3_sensor_value
{
    LABEL       "Sensor Value";
    HELP        "Sensor Value";
    CLASS       CONTAINED & DYNAMIC;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_3_lin_type
{
    LABEL       "Linearization Type";    
    HELP        [trans_lin_type_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        {   0,      "No Linearization."		        },
        {   1,      "User defined. (Table)"		}
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_3_cal_control
{
    LABEL       "Calibration Control";    
    HELP        "Calibration Control";
    CLASS       CONTAINED;
	TYPE		UNSIGNED_INTEGER(1)
	{
		DEFAULT_VALUE	0;
		{0, "False"},
		{1, "True"}
	}
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_3_tab_entryidx
{
    LABEL       "TAB ENTRY";    
    HELP        "TAB ENTRY";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}

VARIABLE trans1_FI_3_tab_x_value
{
    LABEL       "TAB X VALUE";    
    HELP        "TAB X VALUE";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        FLOAT;
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_3_tab_y_value
{
    LABEL       "TAB Y VALUE";    
    HELP        "TAB Y VALUE";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        FLOAT;
	HANDLING    READ & WRITE ;
}

VARIABLE trans1_FI_3_tab_minnumber
{
    LABEL       "TAB MIN NUMBER";    
    HELP        "TAB MIN NUMBER";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_3_tab_maxnumber
{
    LABEL       "TAB MAX NUMBER";    
    HELP        "TAB MAX NUMBER";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_3_tab_opcode
{
    LABEL       "TAB OP CODE";    
    HELP        "TAB OP CODE";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE            ENUMERATED (1)  /* UNSIGNED_INTEGER (1)  */
    {
        {	0, [lin_tab_op_code_NOT_INIT] },
        {	1, [lin_tab_op_code_START]	},
        {	2, "Reserved."},
        {	3, [lin_tab_op_code_END]},
	    {	4, [lin_tab_op_code_DELETE_VALUE]},
        {	5, [lin_tab_op_code_INSERT_VALUE]},
        {	6, [lin_tab_op_code_REPLACE_VALUE]}
    }
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_3_tab_status
{
    LABEL       "TAB STATUS";    
    HELP        "TAB STATUS";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE    ENUMERATED (1)  /* UNSIGNED_INTEGER (1)  */
    {
        {	0, [lin_tab_status_NOT_INIT]},
        {	1, [lin_tab_status_GOOD]},
		{	2, [lin_tab_status_NOT_INC]},
        {	3, [lin_tab_status_NOT_DEC]},
        {	4, [lin_tab_status_NOT_ENOUGH_VALUES]},
		{	5, [lin_tab_status_TOO_MANY_VALUES]},
		{	6, [lin_tab_status_GRADIENT]},
		{	7, [lin_tab_status_NOT_ACCEPTED]},
        {	8, "Table is currently loaded"},
        {	9, "sorting and checking of Table"},
        {	20, [lin_tab_status_NOT_INC]},
        {	21, [lin_tab_status_NOT_DEC]},
        {	22, [lin_tab_status_NOT_ENOUGH_VALUES]},
		{	23, [lin_tab_status_TOO_MANY_VALUES]},
		{	24, [lin_tab_status_GRADIENT]},
		{	25, [lin_tab_status_NOT_ACCEPTED]},
        {	26, "Table is currently loaded"},
        {	27, "sorting and checking of Table"}
    }
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_3_tab_actualnumber
{
    LABEL       "TAB ACTUAL NUMBER";    
    HELP        "TAB ACTUAL NUMBER";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}

VARIABLE trans1_FI_3_actuator_action
{
    LABEL       "Actuator_Action";    
    HELP        "Fail-Safe position for power-loss of the actuator respectively the valve";
    CLASS        CONTAINED;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        {   0,      "Not initialized"   },
        {   1,      "Opening(100%)"		},
        {   2,      "Closing(0)%"       },
        {   3,      "None/remain in actual position"}
    }
    HANDLING    READ & WRITE;
}

UNIT TRANS1_FI_3_FINAL_VALUE_UNIT
{
    trans1_FI_3_final_value_range_unit:

    trans1_FI_3_final_value_upper_range,
    trans1_FI_3_final_value_lower_range,
    trans1_FI_3_final_value,
    trans1_FI_3_sensor_value,
    trans1_FI_3_return_value
}

UNIT TRANS1_FI_3_CAL_UNIT
{
    trans1_FI_3_cal_unit:

    trans1_FI_3_cal_point_hi,
    trans1_FI_3_cal_point_lo,
    trans1_FI_3_cal_min_span
}

/***********************************************************************/
/*    Transducer Block 4                                               */
/***********************************************************************/

BLOCK transducer_block_4
{
    TYPE    TRANSDUCER;
    NUMBER    4;
}

trans1_FI_4_blk_reserve                          LIKE VARIABLE    phys_blk_reserve
{
}

VARIABLE trans1_FI_4_blk_object
{
    LABEL        [blk_block_object];
    HELP        [blk_block_object_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        {    3,    [blk_block_object_TRANSDUCER]        }
    }
    CLASS       DEVICE;// TEMPORARY ;
    HANDLING    READ;
}

VARIABLE trans1_FI_4_blk_parent_class
{
    LABEL        [blk_parent_class];
    HELP        [trans_blk_parent_class_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        {    240,    "Converter"   }
    }
    HANDLING    READ;
}

VARIABLE trans1_FI_4_blk_class
{
    LABEL        [blk_class];
    HELP        [trans_blk_class_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        SELECT( trans1_FI_4_blk_parent_class )
        {
            CASE 240:
            {    1,        "Fieldbus to Current"         },

            DEFAULT:
            {    1,        [standard]                    },
        }
        {    250,    [not_used]                          },
        {    251,    [none]                              },
        {    252,    [unknown]                           },
        {    253,    [special]                           }
    }
    CLASS      DEVICE;//  TEMPORARY ;
    HANDLING    READ;
}

trans1_FI_4_blk_dd_reference                     LIKE VARIABLE    phys_blk_dd_reference
{
}

trans1_FI_4_blk_dd_rev                           LIKE VARIABLE    phys_blk_dd_rev
{
}

trans1_FI_4_blk_profile                          LIKE VARIABLE    phys_blk_profile
{
}

trans1_FI_4_blk_profile_rev                      LIKE VARIABLE    phys_blk_profile_rev
{
}

trans1_FI_4_blk_execution_time                   LIKE VARIABLE    phys_blk_execution_time
{
}

trans1_FI_4_blk_num_parameters                   LIKE VARIABLE    phys_blk_num_parameters
{
}

trans1_FI_4_blk_index_view_1                     LIKE VARIABLE    phys_blk_index_view_1
{
}

trans1_FI_4_blk_num_view_lists                   LIKE VARIABLE    phys_blk_num_view_lists
{
}

trans1_FI_4_st_rev                               LIKE VARIABLE    phys_st_rev
{
}

trans1_FI_4_tag_desc                             LIKE VARIABLE    phys_tag_desc
{
    REDEFINE LABEL        "Transducer 4 Tag";
}

trans1_FI_4_strategy                             LIKE VARIABLE    phys_strategy
{
}

trans1_FI_4_alert_key                            LIKE VARIABLE    phys_alert_key
{
}

trans1_FI_4_target_mode                          LIKE VARIABLE    phys_target_mode
{
}

trans1_FI_4_actual_mode                          LIKE VARIABLE    phys_actual_mode
{
}

trans1_FI_4_permitted_mode                       LIKE VARIABLE    phys_permitted_mode
{
}

trans1_FI_4_normal_mode                          LIKE VARIABLE    phys_normal_mode
{
}

trans1_FI_4_current_state_alarm_sum              LIKE VARIABLE    phys_current_state_alarm_sum
{
}

trans1_FI_4_unacknowledged_state_alarm_sum       LIKE VARIABLE    phys_unacknowledged_state_alarm_sum
{
}

trans1_FI_4_unreported_state_alarm_sum           LIKE VARIABLE    phys_unreported_state_alarm_sum
{
}

trans1_FI_4_disabled_state_alarm_sum             LIKE VARIABLE    phys_disabled_state_alarm_sum
{
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: Fieldbus to Current Converter                  */
/*---------------------------------------------------------------------*/
VARIABLE trans1_FI_4_final_value
{
    LABEL       "Final Value";
    HELP        "Final Value";
    CLASS       CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ;
}
VARIABLE trans1_FI_4_final_value_status
{
    LABEL       [status_limit];
    HELP        [value_status_help];
    CLASS       CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_GENERAL//STATUS_OUTPUT_NO_RCAS
    }
    HANDLING    READ;
}
//VARIABLE trans1_FI_4_final_value_status_quality
//{
//    LABEL       [status_quality];
//    HELP        [value_status_help];
//    CLASS       CONTAINED & DYNAMIC;
//    TYPE        ENUMERATED (1)
//    {
//        DEFAULT_VALUE    0;
//        STATUS_OUTPUT_NO_RCAS
//    }
//    HANDLING    READ;
//}

//trans1_FI_4_final_value_status_limit            LIKE VARIABLE    trans1_FI_4_final_value_status_quality
//{
//    REDEFINE LABEL       [status_limit];        
//    REDEFINE TYPE        ENUMERATED (1)
//    {
//        STATUS_OUTPUT_LIMIT
//    }
//}

VARIABLE trans1_FI_4_final_value_upper_range
{
	LABEL		"Upper [EU(100%)]";
	HELP		"Upper [EU(100%)]";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	20.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_4_final_value_lower_range
{
	LABEL		"Lower [EU(0%)]";
	HELP		"Lower [EU(0%)]";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	4.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_4_final_value_range_unit
{
	LABEL		"Unit";
	HELP		"Unit";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 1211;
		{ 1211,  [mA], 		[mA_help] }
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_4_final_value_range_decimal_point
{
	LABEL		[decimal_point];
	HELP		[decimal_point_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	2;
		{	0,   "0"		},
		{	1,   "1"		},
		{	2,   "2"		},
		{	3,   "3"		},
		{	4,   "4"		},
		{	5,   "5"		}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_FI_4_cal_point_hi
{
    LABEL       [trans_cal_point_hi];        
    HELP        [trans_cal_point_hi_help];
    CLASS       CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    20.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_4_cal_point_lo
{
    LABEL       [trans_cal_point_lo];        
    HELP        [trans_cal_point_lo_help];
    CLASS       CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    4.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_4_cal_min_span
{
    LABEL       [trans_cal_min_span];        
    HELP        [trans_cal_min_span_help];
    CLASS       CONTAINED;
    TYPE        FLOAT;
    HANDLING    READ;
}

VARIABLE trans1_FI_4_cal_unit
{
    LABEL       "Calibration Unit";
    HELP        "Calibration Unit";
    CLASS       CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEFAULT_VALUE    1211;
        { 1211,  [mA], 		[mA_help] }
    }
    HANDLING    READ;
}

VARIABLE trans1_FI_4_act_sn
{
    LABEL       "Serial Number";
    HELP        "Serial number";
    CLASS        CONTAINED;
    TYPE        ASCII (32)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_4_cal_loc
{
    LABEL       "Maintenance Location";
    HELP        "Maintenance Location";
    CLASS        CONTAINED;
    TYPE        ASCII (32)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_4_cal_date
{
    LABEL       "Maintenance Date";
    HELP        "Maintenance Date";
    CLASS        CONTAINED;
    TYPE        ASCII (16)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;   
}

VARIABLE trans1_FI_4_cal_who
{
    LABEL       "Maintenance Staff";
    HELP        "Maintenance Staff";
    CLASS        CONTAINED;
    TYPE        ASCII (32)
    {
        DEFAULT_VALUE  "";
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_4_return_value
{
    LABEL       "Return Value";
    HELP        "Return Value";
    CLASS       CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ;
}
VARIABLE trans1_FI_4_return_value_status
{
    LABEL       [status_limit];
    HELP        [value_status_help];
    CLASS       CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_GENERAL//STATUS_OUTPUT_NO_RCAS
    }
    HANDLING    READ;
}

//VARIABLE trans1_FI_4_return_value_status_quality
//{
//    LABEL       [status_quality];
//    HELP        [value_status_help];
//    CLASS       CONTAINED & DYNAMIC;
//    TYPE        ENUMERATED (1)
//    {
//        DEFAULT_VALUE    0;
//        STATUS_GENERAL//STATUS_OUTPUT_NO_RCAS
//    }
//    HANDLING    READ;
//}
//
//trans1_FI_4_return_value_status_limit            LIKE VARIABLE    trans1_FI_4_return_value_status_quality
//{
//    REDEFINE LABEL       [status_limit];        
//    REDEFINE TYPE        ENUMERATED (1)
//    {
//        STATUS_OUTPUT_LIMIT
//    }
//}

VARIABLE trans1_FI_4_sensor_value
{
    LABEL       "Sensor Value";
    HELP        "Sensor Value";
    CLASS       CONTAINED & DYNAMIC;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_4_lin_type
{
    LABEL       "Linearization Type";    
    HELP        [trans_lin_type_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        {   0,      "No Linearization."		    },
        {   1,      "User defined. (Table)"		}

    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_4_cal_control
{
    LABEL       "Calibration Control";    
    HELP        "Calibration Control";
    CLASS       CONTAINED;
	TYPE		UNSIGNED_INTEGER(1)
	{
		DEFAULT_VALUE	0;
		{0, "False"},
		{1, "True"}
	}
    HANDLING    READ & WRITE;
}

VARIABLE trans1_FI_4_tab_entryidx
{
    LABEL       "TAB ENTRY";    
    HELP        "TAB ENTRY";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}

VARIABLE trans1_FI_4_tab_x_value
{
    LABEL       "TAB X VALUE";    
    HELP        "TAB X VALUE";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        FLOAT;
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_4_tab_y_value
{
    LABEL       "TAB Y VALUE";    
    HELP        "TAB Y VALUE";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        FLOAT;
	HANDLING    READ & WRITE ;
}

VARIABLE trans1_FI_4_tab_minnumber
{
    LABEL       "TAB MIN NUMBER";    
    HELP        "TAB MIN NUMBER";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_4_tab_maxnumber
{
    LABEL       "TAB MAX NUMBER";    
    HELP        "TAB MAX NUMBER";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_4_tab_opcode
{
    LABEL       "TAB OP CODE";    
    HELP        "TAB OP CODE";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE            ENUMERATED (1)  /* UNSIGNED_INTEGER (1)  */
    {
        {	0, [lin_tab_op_code_NOT_INIT] },
        {	1, [lin_tab_op_code_START]	},
        {	2, "Reserved."},
        {	3, [lin_tab_op_code_END]},
	    {	4, [lin_tab_op_code_DELETE_VALUE]},
        {	5, [lin_tab_op_code_INSERT_VALUE]},
        {	6, [lin_tab_op_code_REPLACE_VALUE]}
    }
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_4_tab_status
{
    LABEL       "TAB STATUS";    
    HELP        "TAB STATUS";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE    ENUMERATED (1)  /* UNSIGNED_INTEGER (1)  */
    {
        {	0, [lin_tab_status_NOT_INIT]},
        {	1, [lin_tab_status_GOOD]},
		{	2, [lin_tab_status_NOT_INC]},
        {	3, [lin_tab_status_NOT_DEC]},
        {	4, [lin_tab_status_NOT_ENOUGH_VALUES]},
		{	5, [lin_tab_status_TOO_MANY_VALUES]},
		{	6, [lin_tab_status_GRADIENT]},
		{	7, [lin_tab_status_NOT_ACCEPTED]},
        {	8, "Table is currently loaded"},
        {	9, "sorting and checking of Table"},
        {	20, [lin_tab_status_NOT_INC]},
        {	21, [lin_tab_status_NOT_DEC]},
        {	22, [lin_tab_status_NOT_ENOUGH_VALUES]},
		{	23, [lin_tab_status_TOO_MANY_VALUES]},
		{	24, [lin_tab_status_GRADIENT]},
		{	25, [lin_tab_status_NOT_ACCEPTED]},
        {	26, "Table is currently loaded"},
        {	27, "sorting and checking of Table"}
    }
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_4_tab_actualnumber
{
    LABEL       "TAB ACTUAL NUMBER";    
    HELP        "TAB ACTUAL NUMBER";
    CLASS       CONTAINED&DYNAMIC ;
	TYPE        UNSIGNED_INTEGER (1);
	HANDLING    READ & WRITE ;
}
VARIABLE trans1_FI_4_actuator_action
{
    LABEL       "Actuator_Action";    
    HELP        "Fail-Safe position for power-loss of the actuator respectively the valve";
    CLASS        CONTAINED;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        {   0,      "Not initialized"   },
        {   1,      "Opening(100%)"		},
        {   2,      "Closing(0)%"       },
        {   3,      "None/remain in actual position"}
    }
    HANDLING    READ & WRITE;
}
UNIT TRANS1_FI_4_FINAL_VALUE_UNIT
{
    trans1_FI_4_final_value_range_unit:

    trans1_FI_4_final_value_upper_range,
    trans1_FI_4_final_value_lower_range,
    trans1_FI_4_final_value,
    trans1_FI_4_sensor_value,
    trans1_FI_4_return_value
}

UNIT TRANS1_FI_4_CAL_UNIT
{
    trans1_FI_4_cal_unit:

    trans1_FI_4_cal_point_hi,
    trans1_FI_4_cal_point_lo,
    trans1_FI_4_cal_min_span
}

/*---------------------------------------------------------------------*/
/*    Commands                                                         */
/*---------------------------------------------------------------------*/
/***********************************************************************/
/*    Transducer Block 1                                               */
/***********************************************************************/
COMMAND read_trans1_FI_1_blk
{
    BLOCK transducer_block_1;
    INDEX 0;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_blk_reserve,
            trans1_FI_1_blk_object, 
            trans1_FI_1_blk_parent_class, 
            trans1_FI_1_blk_class,
            trans1_FI_1_blk_dd_reference, 
            trans1_FI_1_blk_dd_rev, 
            trans1_FI_1_blk_profile, 
            trans1_FI_1_blk_profile_rev,
            trans1_FI_1_blk_execution_time, 
            trans1_FI_1_blk_num_parameters, 
            trans1_FI_1_blk_index_view_1,
            trans1_FI_1_blk_num_view_lists
        }
    }
}

COMMAND read_trans1_FI_1_st_rev
{
    BLOCK transducer_block_1;
    INDEX 1;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_st_rev
        }
    }
}

COMMAND read_trans1_FI_1_tag_desc
{
    BLOCK transducer_block_1;
    INDEX 2;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_tag_desc
        }
    }
}

COMMAND write_trans1_FI_1_tag_desc
{
    BLOCK transducer_block_1;
    INDEX 2;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_tag_desc
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_strategy
{
    BLOCK transducer_block_1;
    INDEX 3;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_strategy
        }
    }
}

COMMAND write_trans1_FI_1_strategy
{
    BLOCK transducer_block_1;
    INDEX 3;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_strategy
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_alert_key
{
    BLOCK transducer_block_1;
    INDEX 4;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_alert_key
        }
    }
}

COMMAND write_trans1_FI_1_alert_key
{
    BLOCK transducer_block_1;
    INDEX 4;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_alert_key
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_target_mode
{
    BLOCK transducer_block_1;
    INDEX 5;
    OPERATION  READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_target_mode
        }
    }
}

COMMAND write_trans1_FI_1_target_mode
{
    BLOCK transducer_block_1;
    INDEX 5;
    OPERATION  WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_target_mode
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_FI_1_mode
{
    BLOCK transducer_block_1;
    INDEX 6;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_actual_mode,
            trans1_FI_1_permitted_mode,
            trans1_FI_1_normal_mode
        }
    }
}

COMMAND read_trans1_FI_1_alarm
{
    BLOCK transducer_block_1;
    INDEX 7;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_current_state_alarm_sum, 
            trans1_FI_1_unacknowledged_state_alarm_sum,
            trans1_FI_1_unreported_state_alarm_sum, 
            trans1_FI_1_disabled_state_alarm_sum
        }
    }
}

COMMAND read_trans1_FI_1_final_value
{
    BLOCK transducer_block_1;
    INDEX 8;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_final_value,
            trans1_FI_1_final_value_status
//            trans1_FI_1_final_value_status_quality    <0xFC>,
//            trans1_FI_1_final_value_status_limit      <0x03>
        }
    }
}

COMMAND read_trans1_FI_1_final_value_range 
{
	BLOCK transducer_block_1;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
            trans1_FI_1_final_value_upper_range,
            trans1_FI_1_final_value_lower_range,
            trans1_FI_1_final_value_range_unit,
            trans1_FI_1_final_value_range_decimal_point
		}
	}
}

COMMAND write_trans1_FI_1_final_value_range 
{
	BLOCK transducer_block_1;
	INDEX 9;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
            trans1_FI_1_final_value_upper_range,
            trans1_FI_1_final_value_lower_range,
            trans1_FI_1_final_value_range_unit,
            trans1_FI_1_final_value_range_decimal_point
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_FI_1_cal_point_hi
{
    BLOCK transducer_block_1;
    INDEX 10;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_cal_point_hi
        }
    }
}

COMMAND write_trans1_FI_1_cal_point_hi
{
    BLOCK transducer_block_1;
    INDEX 10;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_cal_point_hi
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_cal_point_lo
{
    BLOCK transducer_block_1;
    INDEX 11;
    OPERATION  READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_cal_point_lo
        }
    }
}

COMMAND write_trans1_FI_1_cal_point_lo
{
    BLOCK transducer_block_1;
    INDEX 11;
    OPERATION  WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_cal_point_lo
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_cal_min_span
{
    BLOCK transducer_block_1;
    INDEX 12;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_cal_min_span
        }
    }
}

COMMAND read_trans1_FI_1_cal_unit
{
    BLOCK transducer_block_1;
    INDEX 13;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_cal_unit
        }
    }
}

COMMAND read_trans1_FI_1_act_sn
{
    BLOCK transducer_block_1;
    INDEX 14;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_act_sn
        }
    }
}

COMMAND write_trans1_FI_1_act_sn
{
    BLOCK transducer_block_1;
    INDEX 14;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_act_sn
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_cal_loc
{
    BLOCK transducer_block_1;
    INDEX 15;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_cal_loc
        }
    }
}

COMMAND write_trans1_FI_1_cal_loc
{
    BLOCK transducer_block_1;
    INDEX 15;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_cal_loc
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_cal_date
{
    BLOCK transducer_block_1;
    INDEX 16;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_cal_date
        }
    }
}

COMMAND write_trans1_FI_1_cal_date
{
    BLOCK transducer_block_1;
    INDEX 16;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_cal_date
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_cal_who
{
    BLOCK transducer_block_1;
    INDEX 17;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_cal_who
        }
    }
}

COMMAND write_trans1_FI_1_cal_who
{
    BLOCK transducer_block_1;
    INDEX 17;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_cal_who
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_return_value
{
    BLOCK transducer_block_1;
    INDEX 18;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_return_value,
            trans1_FI_1_return_value_status
//            trans1_FI_1_return_value_status_quality    <0xFC>,
//            trans1_FI_1_return_value_status_limit      <0x03>
        }
    }
}

COMMAND read_trans1_FI_1_sensor_value
{
    BLOCK transducer_block_1;
    INDEX 19;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_sensor_value
        }
    }
}

COMMAND write_trans1_FI_1_sensor_value
{
    BLOCK transducer_block_1;
    INDEX 19;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_sensor_value
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_lin_type
{
    BLOCK transducer_block_1;
    INDEX 20;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_lin_type
        }
    }
}

COMMAND write_trans1_FI_1_lin_type
{
    BLOCK transducer_block_1;
    INDEX 20;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_lin_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_cal_control
{
    BLOCK transducer_block_1;
    INDEX 21;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_cal_control
        }
    }
}

COMMAND write_trans1_FI_1_cal_control
{
    BLOCK transducer_block_1;
    INDEX 21;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_cal_control
        }
        REPLY
        {
        }
    }
}
COMMAND read_trans1_FI_1_tab_entryidx
{
    BLOCK transducer_block_1;
    INDEX 22;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_tab_entryidx
        }
    }
}

COMMAND write_trans1_FI_1_tab_entryidx
{
    BLOCK transducer_block_1;
    INDEX 22;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_tab_entryidx
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_tab_value
{
    BLOCK transducer_block_1;
    INDEX 23;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_tab_x_value,
            trans1_FI_1_tab_y_value
        }
    }
}

COMMAND write_trans1_FI_1_tab_value
{
    BLOCK transducer_block_1;
    INDEX 23;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_tab_x_value,
            trans1_FI_1_tab_y_value
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_tab_minnumber
{
    BLOCK transducer_block_1;
    INDEX 24;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_tab_minnumber
        }
    }
}

COMMAND write_trans1_FI_tab_1_minnumber
{
    BLOCK transducer_block_1;
    INDEX 24;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_tab_minnumber
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_FI_1_tab_maxnumber
{
    BLOCK transducer_block_1;
    INDEX 25;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_tab_maxnumber
        }
    }
}

COMMAND write_trans1_FI_1_tab_maxnumber
{
    BLOCK transducer_block_1;
    INDEX 25;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_tab_maxnumber
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_FI_1_tab_opcode
{
    BLOCK transducer_block_1;
    INDEX 26;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_tab_opcode
        }
    }
}

COMMAND write_trans1_FI_1_tab_opcode
{
    BLOCK transducer_block_1;
    INDEX 26;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_tab_opcode
        }
        REPLY
        {
        }
    }
}
COMMAND read_trans1_FI_1_tab_status
{
    BLOCK transducer_block_1;
    INDEX 27;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_tab_status
        }
    }
}

COMMAND write_trans1_FI_1_tab_status
{
    BLOCK transducer_block_1;
    INDEX 27;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_tab_status
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_tab_actualnumber
{
    BLOCK transducer_block_1;
    INDEX 28;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_tab_actualnumber
        }
    }
}

COMMAND write_trans1_FI_1_tab_actualnumber
{
    BLOCK transducer_block_1;
    INDEX 28;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_tab_actualnumber
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_1_actuator_action
{
    BLOCK transducer_block_1;
    INDEX 29;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_1_actuator_action
        }
    }
}

COMMAND write_trans1_FI_1_actuator_action
{
    BLOCK transducer_block_1;
    INDEX 29;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_1_actuator_action
        }
        REPLY
        {
            
        }
    }
}


/***********************************************************************/
/*    Transducer Block 2                                               */
/***********************************************************************/
COMMAND read_trans1_FI_2_blk
{
    BLOCK transducer_block_2;
    INDEX 0;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_blk_reserve,
            trans1_FI_2_blk_object, 
            trans1_FI_2_blk_parent_class, 
            trans1_FI_2_blk_class,
            trans1_FI_2_blk_dd_reference, 
            trans1_FI_2_blk_dd_rev, 
            trans1_FI_2_blk_profile, 
            trans1_FI_2_blk_profile_rev,
            trans1_FI_2_blk_execution_time, 
            trans1_FI_2_blk_num_parameters, 
            trans1_FI_2_blk_index_view_1,
            trans1_FI_2_blk_num_view_lists
        }
    }
}

COMMAND read_trans1_FI_2_st_rev
{
    BLOCK transducer_block_2;
    INDEX 1;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_st_rev
        }
    }
}

COMMAND read_trans1_FI_2_tag_desc
{
    BLOCK transducer_block_2;
    INDEX 2;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_tag_desc
        }
    }
}

COMMAND write_trans1_FI_2_tag_desc
{
    BLOCK transducer_block_2;
    INDEX 2;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_tag_desc
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_strategy
{
    BLOCK transducer_block_2;
    INDEX 3;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_strategy
        }
    }
}

COMMAND write_trans1_FI_2_strategy
{
    BLOCK transducer_block_2;
    INDEX 3;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_strategy
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_alert_key
{
    BLOCK transducer_block_2;
    INDEX 4;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_alert_key
        }
    }
}

COMMAND write_trans1_FI_2_alert_key
{
    BLOCK transducer_block_2;
    INDEX 4;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_alert_key
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_target_mode
{
    BLOCK transducer_block_2;
    INDEX 5;
    OPERATION  READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_target_mode
        }
    }
}

COMMAND write_trans1_FI_2_target_mode
{
    BLOCK transducer_block_2;
    INDEX 5;
    OPERATION  WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_target_mode
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_FI_2_mode
{
    BLOCK transducer_block_2;
    INDEX 6;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_actual_mode,
            trans1_FI_2_permitted_mode,
            trans1_FI_2_normal_mode
        }
    }
}

COMMAND read_trans1_FI_2_alarm
{
    BLOCK transducer_block_2;
    INDEX 7;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_current_state_alarm_sum, 
            trans1_FI_2_unacknowledged_state_alarm_sum,
            trans1_FI_2_unreported_state_alarm_sum, 
            trans1_FI_2_disabled_state_alarm_sum
        }
    }
}

COMMAND read_trans1_FI_2_final_value
{
    BLOCK transducer_block_2;
    INDEX 8;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_final_value,
            trans1_FI_2_final_value_status
//            trans1_FI_2_final_value_status_quality    <0xFC>,
//            trans1_FI_2_final_value_status_limit      <0x03>
        }
    }
}

COMMAND read_trans1_FI_2_final_value_range 
{
	BLOCK transducer_block_2;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
            trans1_FI_2_final_value_upper_range,
            trans1_FI_2_final_value_lower_range,
            trans1_FI_2_final_value_range_unit,
            trans1_FI_2_final_value_range_decimal_point
		}
	}
}

COMMAND write_trans1_FI_2_final_value_range 
{
	BLOCK transducer_block_2;
	INDEX 9;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
            trans1_FI_2_final_value_upper_range,
            trans1_FI_2_final_value_lower_range,
            trans1_FI_2_final_value_range_unit,
            trans1_FI_2_final_value_range_decimal_point
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_FI_2_cal_point_hi
{
    BLOCK transducer_block_2;
    INDEX 10;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_cal_point_hi
        }
    }
}

COMMAND write_trans1_FI_2_cal_point_hi
{
    BLOCK transducer_block_2;
    INDEX 10;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_cal_point_hi
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_cal_point_lo
{
    BLOCK transducer_block_2;
    INDEX 11;
    OPERATION  READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_cal_point_lo
        }
    }
}

COMMAND write_trans1_FI_2_cal_point_lo
{
    BLOCK transducer_block_2;
    INDEX 11;
    OPERATION  WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_cal_point_lo
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_cal_min_span
{
    BLOCK transducer_block_2;
    INDEX 12;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_cal_min_span
        }
    }
}

COMMAND read_trans1_FI_2_cal_unit
{
    BLOCK transducer_block_2;
    INDEX 13;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_cal_unit
        }
    }
}

COMMAND read_trans1_FI_2_act_sn
{
    BLOCK transducer_block_2;
    INDEX 14;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_act_sn
        }
    }
}

COMMAND write_trans1_FI_2_act_sn
{
    BLOCK transducer_block_2;
    INDEX 14;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_act_sn
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_cal_loc
{
    BLOCK transducer_block_2;
    INDEX 15;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_cal_loc
        }
    }
}

COMMAND write_trans1_FI_2_cal_loc
{
    BLOCK transducer_block_2;
    INDEX 15;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_cal_loc
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_cal_date
{
    BLOCK transducer_block_2;
    INDEX 16;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_cal_date
        }
    }
}

COMMAND write_trans1_FI_2_cal_date
{
    BLOCK transducer_block_2;
    INDEX 16;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_cal_date
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_cal_who
{
    BLOCK transducer_block_2;
    INDEX 17;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_cal_who
        }
    }
}

COMMAND write_trans1_FI_2_cal_who
{
    BLOCK transducer_block_2;
    INDEX 17;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_cal_who
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_return_value
{
    BLOCK transducer_block_2;
    INDEX 18;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_return_value,
            trans1_FI_2_return_value_status       //<0xFC>
//            trans1_FI_2_return_value_status_quality    <0xFC>,
//            trans1_FI_2_return_value_status_limit      <0x03>
        }
    }
}

COMMAND read_trans1_FI_2_sensor_value
{
    BLOCK transducer_block_2;
    INDEX 19;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_sensor_value
        }
    }
}

COMMAND write_trans1_FI_2_sensor_value
{
    BLOCK transducer_block_2;
    INDEX 19;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_sensor_value
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_lin_type
{
    BLOCK transducer_block_2;
    INDEX 20;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_lin_type
        }
    }
}

COMMAND write_trans1_FI_2_lin_type
{
    BLOCK transducer_block_2;
    INDEX 20;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_lin_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_cal_control
{
    BLOCK transducer_block_2;
    INDEX 21;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_cal_control
        }
    }
}

COMMAND write_trans1_FI_2_cal_control
{
    BLOCK transducer_block_2;
    INDEX 21;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_cal_control
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_tab_entryidx
{
    BLOCK transducer_block_2;
    INDEX 22;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_tab_entryidx
        }
    }
}

COMMAND write_trans1_FI_2_tab_entryidx
{
    BLOCK transducer_block_2;
    INDEX 22;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_tab_entryidx
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_tab_value
{
    BLOCK transducer_block_2;
    INDEX 23;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_tab_x_value,
            trans1_FI_2_tab_y_value
        }
    }
}

COMMAND write_trans1_FI_2_tab_value
{
    BLOCK transducer_block_2;
    INDEX 23;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_tab_x_value,
            trans1_FI_2_tab_y_value
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_tab_minnumber
{
    BLOCK transducer_block_2;
    INDEX 24;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_tab_minnumber
        }
    }
}

COMMAND write_trans1_FI_tab_2_minnumber
{
    BLOCK transducer_block_2;
    INDEX 24;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_tab_minnumber
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_FI_2_tab_maxnumber
{
    BLOCK transducer_block_2;
    INDEX 25;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_tab_maxnumber
        }
    }
}

COMMAND write_trans1_FI_2_tab_maxnumber
{
    BLOCK transducer_block_2;
    INDEX 25;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_tab_maxnumber
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_FI_2_tab_opcode
{
    BLOCK transducer_block_2;
    INDEX 26;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_tab_opcode
        }
    }
}

COMMAND write_trans1_FI_2_tab_opcode
{
    BLOCK transducer_block_2;
    INDEX 26;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_tab_opcode
        }
        REPLY
        {
        }
    }
}
COMMAND read_trans1_FI_2_tab_status
{
    BLOCK transducer_block_2;
    INDEX 27;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_tab_status
        }
    }
}

COMMAND write_trans1_FI_2_tab_status
{
    BLOCK transducer_block_2;
    INDEX 27;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_tab_status
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_2_tab_actualnumber
{
    BLOCK transducer_block_2;
    INDEX 28;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_tab_actualnumber
        }
    }
}

COMMAND write_trans1_FI_2_tab_actualnumber
{
    BLOCK transducer_block_2;
    INDEX 28;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_tab_actualnumber
        }
        REPLY
        {
        }
    }
}
COMMAND read_trans2_FI_1_cactuator_action
{
    BLOCK transducer_block_2;
    INDEX 29;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_2_actuator_action
        }
    }
}

COMMAND write_trans1_FI_2_actuator_action
{
    BLOCK transducer_block_2;
    INDEX 29;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_2_actuator_action
        }
        REPLY
        {
            
        }
    }
}
/***********************************************************************/
/*    Transducer Block 3                                               */
/***********************************************************************/
COMMAND read_trans1_FI_3_blk
{
    BLOCK transducer_block_3;
    INDEX 0;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_blk_reserve,
            trans1_FI_3_blk_object, 
            trans1_FI_3_blk_parent_class, 
            trans1_FI_3_blk_class,
            trans1_FI_3_blk_dd_reference, 
            trans1_FI_3_blk_dd_rev, 
            trans1_FI_3_blk_profile, 
            trans1_FI_3_blk_profile_rev,
            trans1_FI_3_blk_execution_time, 
            trans1_FI_3_blk_num_parameters, 
            trans1_FI_3_blk_index_view_1,
            trans1_FI_3_blk_num_view_lists
        }
    }
}

COMMAND read_trans1_FI_3_st_rev
{
    BLOCK transducer_block_3;
    INDEX 1;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_st_rev
        }
    }
}

COMMAND read_trans1_FI_3_tag_desc
{
    BLOCK transducer_block_3;
    INDEX 2;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_tag_desc
        }
    }
}

COMMAND write_trans1_FI_3_tag_desc
{
    BLOCK transducer_block_3;
    INDEX 2;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_tag_desc
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_strategy
{
    BLOCK transducer_block_3;
    INDEX 3;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_strategy
        }
    }
}

COMMAND write_trans1_FI_3_strategy
{
    BLOCK transducer_block_3;
    INDEX 3;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_strategy
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_alert_key
{
    BLOCK transducer_block_3;
    INDEX 4;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_alert_key
        }
    }
}

COMMAND write_trans1_FI_3_alert_key
{
    BLOCK transducer_block_3;
    INDEX 4;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_alert_key
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_target_mode
{
    BLOCK transducer_block_3;
    INDEX 5;
    OPERATION  READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_target_mode
        }
    }
}

COMMAND write_trans1_FI_3_target_mode
{
    BLOCK transducer_block_3;
    INDEX 5;
    OPERATION  WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_target_mode
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_FI_3_mode
{
    BLOCK transducer_block_3;
    INDEX 6;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_actual_mode,
            trans1_FI_3_permitted_mode,
            trans1_FI_3_normal_mode
        }
    }
}

COMMAND read_trans1_FI_3_alarm
{
    BLOCK transducer_block_3;
    INDEX 7;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_current_state_alarm_sum, 
            trans1_FI_3_unacknowledged_state_alarm_sum,
            trans1_FI_3_unreported_state_alarm_sum, 
            trans1_FI_3_disabled_state_alarm_sum
        }
    }
}

COMMAND read_trans1_FI_3_final_value
{
    BLOCK transducer_block_3;
    INDEX 8;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_final_value,
            trans1_FI_3_final_value_status      
//            trans1_FI_3_final_value_status_quality    <0xFC>,
//            trans1_FI_3_final_value_status_limit      <0x03>
        }
    }
}

COMMAND read_trans1_FI_3_final_value_range 
{
	BLOCK transducer_block_3;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
            trans1_FI_3_final_value_upper_range,
            trans1_FI_3_final_value_lower_range,
            trans1_FI_3_final_value_range_unit,
            trans1_FI_3_final_value_range_decimal_point
		}
	}
}

COMMAND write_trans1_FI_3_final_value_range 
{
	BLOCK transducer_block_3;
	INDEX 9;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
            trans1_FI_3_final_value_upper_range,
            trans1_FI_3_final_value_lower_range,
            trans1_FI_3_final_value_range_unit,
            trans1_FI_3_final_value_range_decimal_point
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_FI_3_cal_point_hi
{
    BLOCK transducer_block_3;
    INDEX 10;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_cal_point_hi
        }
    }
}

COMMAND write_trans1_FI_3_cal_point_hi
{
    BLOCK transducer_block_3;
    INDEX 10;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_cal_point_hi
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_cal_point_lo
{
    BLOCK transducer_block_3;
    INDEX 11;
    OPERATION  READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_cal_point_lo
        }
    }
}

COMMAND write_trans1_FI_3_cal_point_lo
{
    BLOCK transducer_block_3;
    INDEX 11;
    OPERATION  WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_cal_point_lo
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_cal_min_span
{
    BLOCK transducer_block_3;
    INDEX 12;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_cal_min_span
        }
    }
}

COMMAND read_trans1_FI_3_cal_unit
{
    BLOCK transducer_block_3;
    INDEX 13;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_cal_unit
        }
    }
}

COMMAND read_trans1_FI_3_act_sn
{
    BLOCK transducer_block_3;
    INDEX 14;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_act_sn
        }
    }
}

COMMAND write_trans1_FI_3_act_sn
{
    BLOCK transducer_block_3;
    INDEX 14;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_act_sn
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_cal_loc
{
    BLOCK transducer_block_3;
    INDEX 15;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_cal_loc
        }
    }
}

COMMAND write_trans1_FI_3_cal_loc
{
    BLOCK transducer_block_3;
    INDEX 15;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_cal_loc
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_cal_date
{
    BLOCK transducer_block_3;
    INDEX 16;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_cal_date
        }
    }
}

COMMAND write_trans1_FI_3_cal_date
{
    BLOCK transducer_block_3;
    INDEX 16;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_cal_date
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_cal_who
{
    BLOCK transducer_block_3;
    INDEX 17;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_cal_who
        }
    }
}

COMMAND write_trans1_FI_3_cal_who
{
    BLOCK transducer_block_3;
    INDEX 17;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_cal_who
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_return_value
{
    BLOCK transducer_block_3;
    INDEX 18;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_return_value,
            trans1_FI_3_return_value_status
//            trans1_FI_3_return_value_status_quality    <0xFC>,
//            trans1_FI_3_return_value_status_limit      <0x03>
        }
    }
}

COMMAND read_trans1_FI_3_sensor_value
{
    BLOCK transducer_block_3;
    INDEX 19;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_sensor_value
        }
    }
}

COMMAND write_trans1_FI_3_sensor_value
{
    BLOCK transducer_block_3;
    INDEX 19;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_sensor_value
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_lin_type
{
    BLOCK transducer_block_3;
    INDEX 20;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_lin_type
        }
    }
}

COMMAND write_trans1_FI_3_lin_type
{
    BLOCK transducer_block_3;
    INDEX 20;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_lin_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_cal_control
{
    BLOCK transducer_block_3;
    INDEX 21;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_cal_control
        }
    }
}

COMMAND write_trans1_FI_3_cal_control
{
    BLOCK transducer_block_3;
    INDEX 21;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_cal_control
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_tab_entryidx
{
    BLOCK transducer_block_3;
    INDEX 22;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_tab_entryidx
        }
    }
}

COMMAND write_trans1_FI_3_tab_entryidx
{
    BLOCK transducer_block_3;
    INDEX 22;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_tab_entryidx
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_tab_value
{
    BLOCK transducer_block_3;
    INDEX 23;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_tab_x_value,
            trans1_FI_3_tab_y_value
        }
    }
}

COMMAND write_trans1_FI_3_tab_value
{
    BLOCK transducer_block_3;
    INDEX 23;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_tab_x_value,
            trans1_FI_3_tab_y_value
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_tab_minnumber
{
    BLOCK transducer_block_3;
    INDEX 24;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_tab_minnumber
        }
    }
}

COMMAND write_trans1_FI_tab_3_minnumber
{
    BLOCK transducer_block_3;
    INDEX 24;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_tab_minnumber
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_FI_3_tab_maxnumber
{
    BLOCK transducer_block_3;
    INDEX 25;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_tab_maxnumber
        }
    }
}

COMMAND write_trans1_FI_3_tab_maxnumber
{
    BLOCK transducer_block_3;
    INDEX 25;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_tab_maxnumber
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_FI_3_tab_opcode
{
    BLOCK transducer_block_3;
    INDEX 26;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_tab_opcode
        }
    }
}

COMMAND write_trans1_FI_3_tab_opcode
{
    BLOCK transducer_block_3;
    INDEX 26;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_tab_opcode
        }
        REPLY
        {
        }
    }
}
COMMAND read_trans1_FI_3_tab_status
{
    BLOCK transducer_block_3;
    INDEX 27;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_tab_status
        }
    }
}

COMMAND write_trans1_FI_3_tab_status
{
    BLOCK transducer_block_3;
    INDEX 27;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_tab_status
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_3_tab_actualnumber
{
    BLOCK transducer_block_3;
    INDEX 28;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_tab_actualnumber
        }
    }
}

COMMAND write_trans1_FI_3_tab_actualnumber
{
    BLOCK transducer_block_3;
    INDEX 28;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_tab_actualnumber
        }
        REPLY
        {
        }
    }
}
COMMAND read_trans1_FI_3_actuator_action
{
    BLOCK transducer_block_3;
    INDEX 29;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_3_actuator_action
        }
    }
}

COMMAND write_trans1_FI_3_actuator_action
{
    BLOCK transducer_block_3;
    INDEX 29;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_3_actuator_action
        }
        REPLY
        {
            
        }
    }
}
/***********************************************************************/
/*    Transducer Block 4                                               */
/***********************************************************************/
COMMAND read_trans1_FI_4_blk
{
    BLOCK transducer_block_4;
    INDEX 0;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_blk_reserve,
            trans1_FI_4_blk_object, 
            trans1_FI_4_blk_parent_class, 
            trans1_FI_4_blk_class,
            trans1_FI_4_blk_dd_reference, 
            trans1_FI_4_blk_dd_rev, 
            trans1_FI_4_blk_profile, 
            trans1_FI_4_blk_profile_rev,
            trans1_FI_4_blk_execution_time, 
            trans1_FI_4_blk_num_parameters, 
            trans1_FI_4_blk_index_view_1,
            trans1_FI_4_blk_num_view_lists
        }
    }
}

COMMAND read_trans1_FI_4_st_rev
{
    BLOCK transducer_block_4;
    INDEX 1;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_st_rev
        }
    }
}

COMMAND read_trans1_FI_4_tag_desc
{
    BLOCK transducer_block_4;
    INDEX 2;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_tag_desc
        }
    }
}

COMMAND write_trans1_FI_4_tag_desc
{
    BLOCK transducer_block_4;
    INDEX 2;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_tag_desc
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_strategy
{
    BLOCK transducer_block_4;
    INDEX 3;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_strategy
        }
    }
}

COMMAND write_trans1_FI_4_strategy
{
    BLOCK transducer_block_4;
    INDEX 3;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_strategy
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_alert_key
{
    BLOCK transducer_block_4;
    INDEX 4;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_alert_key
        }
    }
}

COMMAND write_trans1_FI_4_alert_key
{
    BLOCK transducer_block_4;
    INDEX 4;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_alert_key
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_target_mode
{
    BLOCK transducer_block_4;
    INDEX 5;
    OPERATION  READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_target_mode
        }
    }
}

COMMAND write_trans1_FI_4_target_mode
{
    BLOCK transducer_block_4;
    INDEX 5;
    OPERATION  WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_target_mode
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_FI_4_mode
{
    BLOCK transducer_block_4;
    INDEX 6;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_actual_mode,
            trans1_FI_4_permitted_mode,
            trans1_FI_4_normal_mode
        }
    }
}

COMMAND read_trans1_FI_4_alarm
{
    BLOCK transducer_block_4;
    INDEX 7;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_current_state_alarm_sum, 
            trans1_FI_4_unacknowledged_state_alarm_sum,
            trans1_FI_4_unreported_state_alarm_sum, 
            trans1_FI_4_disabled_state_alarm_sum
        }
    }
}

COMMAND read_trans1_FI_4_final_value
{
    BLOCK transducer_block_4;
    INDEX 8;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_final_value,
            trans1_FI_4_final_value_status    
//            trans1_FI_4_final_value_status_quality    <0xFC>,
//            trans1_FI_4_final_value_status_limit      <0x03>
        }
    }
}

COMMAND read_trans1_FI_4_final_value_range 
{
	BLOCK transducer_block_4;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
            trans1_FI_4_final_value_upper_range,
            trans1_FI_4_final_value_lower_range,
            trans1_FI_4_final_value_range_unit,
            trans1_FI_4_final_value_range_decimal_point
		}
	}
}

COMMAND write_trans1_FI_4_final_value_range 
{
	BLOCK transducer_block_4;
	INDEX 9;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
            trans1_FI_4_final_value_upper_range,
            trans1_FI_4_final_value_lower_range,
            trans1_FI_4_final_value_range_unit,
            trans1_FI_4_final_value_range_decimal_point
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_FI_4_cal_point_hi
{
    BLOCK transducer_block_4;
    INDEX 10;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_cal_point_hi
        }
    }
}

COMMAND write_trans1_FI_4_cal_point_hi
{
    BLOCK transducer_block_4;
    INDEX 10;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_cal_point_hi
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_cal_point_lo
{
    BLOCK transducer_block_4;
    INDEX 11;
    OPERATION  READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_cal_point_lo
        }
    }
}

COMMAND write_trans1_FI_4_cal_point_lo
{
    BLOCK transducer_block_4;
    INDEX 11;
    OPERATION  WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_cal_point_lo
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_cal_min_span
{
    BLOCK transducer_block_4;
    INDEX 12;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_cal_min_span
        }
    }
}

COMMAND read_trans1_FI_4_cal_unit
{
    BLOCK transducer_block_4;
    INDEX 13;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_cal_unit
        }
    }
}

COMMAND read_trans1_FI_4_act_sn
{
    BLOCK transducer_block_4;
    INDEX 14;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_act_sn
        }
    }
}

COMMAND write_trans1_FI_4_act_sn
{
    BLOCK transducer_block_4;
    INDEX 14;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_act_sn
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_cal_loc
{
    BLOCK transducer_block_4;
    INDEX 15;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_cal_loc
        }
    }
}

COMMAND write_trans1_FI_4_cal_loc
{
    BLOCK transducer_block_4;
    INDEX 15;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_cal_loc
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_cal_date
{
    BLOCK transducer_block_4;
    INDEX 16;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_cal_date
        }
    }
}

COMMAND write_trans1_FI_4_cal_date
{
    BLOCK transducer_block_4;
    INDEX 16;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_cal_date
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_cal_who
{
    BLOCK transducer_block_4;
    INDEX 17;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_cal_who
        }
    }
}

COMMAND write_trans1_FI_4_cal_who
{
    BLOCK transducer_block_4;
    INDEX 17;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_cal_who
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_return_value
{
    BLOCK transducer_block_4;
    INDEX 18;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_return_value,
            trans1_FI_4_return_value_status
//            trans1_FI_4_return_value_status_quality    <0xFC>,
//            trans1_FI_4_return_value_status_limit      <0x03>
        }
    }
}

COMMAND read_trans1_FI_4_sensor_value
{
    BLOCK transducer_block_4;
    INDEX 19;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_sensor_value
        }
    }
}

COMMAND write_trans1_FI_4_sensor_value
{
    BLOCK transducer_block_4;
    INDEX 19;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_sensor_value
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_lin_type
{
    BLOCK transducer_block_4;
    INDEX 20;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_lin_type
        }
    }
}

COMMAND write_trans1_FI_4_lin_type
{
    BLOCK transducer_block_4;
    INDEX 20;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_lin_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_cal_control
{
    BLOCK transducer_block_4;
    INDEX 21;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_cal_control
        }
    }
}

COMMAND write_trans1_FI_4_cal_control
{
    BLOCK transducer_block_4;
    INDEX 21;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_cal_control
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_tab_entryidx
{
    BLOCK transducer_block_4;
    INDEX 22;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_tab_entryidx
        }
    }
}

COMMAND write_trans1_FI_4_tab_entryidx
{
    BLOCK transducer_block_4;
    INDEX 22;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_tab_entryidx
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_tab_value
{
    BLOCK transducer_block_4;
    INDEX 23;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_tab_x_value,
            trans1_FI_4_tab_y_value
        }
    }
}

COMMAND write_trans1_FI_4_tab_value
{
    BLOCK transducer_block_4;
    INDEX 23;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_tab_x_value,
            trans1_FI_4_tab_y_value
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_tab_minnumber
{
    BLOCK transducer_block_4;
    INDEX 24;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_tab_minnumber
        }
    }
}

COMMAND write_trans1_FI_tab_4_minnumber
{
    BLOCK transducer_block_4;
    INDEX 24;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_tab_minnumber
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_FI_4_tab_maxnumber
{
    BLOCK transducer_block_4;
    INDEX 25;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_tab_maxnumber
        }
    }
}

COMMAND write_trans1_FI_4_tab_maxnumber
{
    BLOCK transducer_block_4;
    INDEX 25;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_tab_maxnumber
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_FI_4_tab_opcode
{
    BLOCK transducer_block_4;
    INDEX 26;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_tab_opcode
        }
    }
}

COMMAND write_trans1_FI_4_tab_opcode
{
    BLOCK transducer_block_4;
    INDEX 26;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_tab_opcode
        }
        REPLY
        {
        }
    }
}
COMMAND read_trans1_FI_4_tab_status
{
    BLOCK transducer_block_4;
    INDEX 27;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_tab_status
        }
    }
}

COMMAND write_trans1_FI_4_tab_status
{
    BLOCK transducer_block_4;
    INDEX 27;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_tab_status
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_FI_4_tab_actualnumber
{
    BLOCK transducer_block_4;
    INDEX 28;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_tab_actualnumber
        }
    }
}

COMMAND write_trans1_FI_4_tab_actualnumber
{
    BLOCK transducer_block_4;
    INDEX 28;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_tab_actualnumber
        }
        REPLY
        {
        }
    }
}
COMMAND read_trans1_FI_4_actuator_action
{
    BLOCK transducer_block_4;
    INDEX 29;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_FI_4_actuator_action
        }
    }
}

COMMAND write_trans1_FI_4_actuator_action
{
    BLOCK transducer_block_4;
    INDEX 29;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_FI_4_actuator_action
        }
        REPLY
        {
            
        }
    }
}


/***********************************************************************/
/*****    Menu: Specialist  **********************************************/
/***********************************************************************/

MENU Menu_Main_Specialist
{
    LABEL        [main_menu];
    ITEMS
    {
        Menu_File,
        Menu_S_Device,
        Menu_S_View,
        Menu_Options,
        Menu_Help
    }
}

/***********************************************************************/
/*****    Menu: Maintenance  *********************************************/
/***********************************************************************/

MENU Menu_Main_Maintenance
{
    LABEL        [main_menu];
    ITEMS
    {
        Menu_File,
        Menu_M_Device,
        Menu_M_View,
        Menu_Options,
        Menu_Help
    }
}

//MENU download_variables
//{
//    LABEL        [menu_load_to_PC];
//    ITEMS
//    {
//    /* PHYSICAL BLOCK    */
//    /* TRANDSDUCER BLOCK 1    */
//        trans1_FI_1_st_rev,
//    /* TRANDSDUCER BLOCK 2    */
//        trans1_FI_2_st_rev,
//    /* TRANDSDUCER BLOCK 3    */
//        trans1_FI_3_st_rev,
//    /* TRANDSDUCER BLOCK 4    */
//        trans1_FI_4_st_rev,
//    /* FUNCTION BLOCK 1: AO    */
//    /* FUNCTION BLOCK 2: AO    */
//    /* FUNCTION BLOCK 3: AO    */
//    /* FUNCTION BLOCK 4: AO    */
//    }
//}

MENU upload_variables
{
    LABEL        [menu_load_to_device];
    ITEMS
    {
        /* PHYSICAL BLOCK    */
        phys_tag_desc,
        phys_descriptor,
        phys_message,
        phys_install_date,
        phys_local_operation_enable,
        phys_strategy,
        phys_alert_key,
//        phys_lcd_dsp_channel,

        /* TRANDSDUCER BLOCK 1: Converter */
        trans1_FI_1_tag_desc,
        trans1_FI_1_strategy,
        trans1_FI_1_alert_key,
        trans1_FI_1_target_mode,
        trans1_FI_1_final_value_upper_range,
        trans1_FI_1_final_value_lower_range,
        trans1_FI_1_final_value_range_unit,
        trans1_FI_1_final_value_range_decimal_point,
        trans1_FI_1_act_sn,
        trans1_FI_1_cal_loc,
        trans1_FI_1_cal_date,
        trans1_FI_1_cal_who,
        trans1_FI_1_lin_type,
        trans1_FI_1_actuator_action,
        /* TRANDSDUCER BLOCK 2: Converter */
        trans1_FI_2_tag_desc,
        trans1_FI_2_strategy,
        trans1_FI_2_alert_key,
        trans1_FI_2_target_mode,
        trans1_FI_2_final_value_upper_range,
        trans1_FI_2_final_value_lower_range,
        trans1_FI_2_final_value_range_unit,
        trans1_FI_2_final_value_range_decimal_point,
        trans1_FI_2_act_sn,
        trans1_FI_2_cal_loc,
        trans1_FI_2_cal_date,
        trans1_FI_2_cal_who,
        trans1_FI_2_lin_type,
        trans1_FI_2_actuator_action,
        /* TRANDSDUCER BLOCK 3: Converter */
        trans1_FI_3_tag_desc,
        trans1_FI_3_strategy,
        trans1_FI_3_alert_key,
        trans1_FI_3_target_mode,
        trans1_FI_3_final_value_upper_range,
        trans1_FI_3_final_value_lower_range,
        trans1_FI_3_final_value_range_unit,
        trans1_FI_3_final_value_range_decimal_point,
        trans1_FI_3_act_sn,
        trans1_FI_3_cal_loc,
        trans1_FI_3_cal_date,
        trans1_FI_3_cal_who,
        trans1_FI_3_lin_type,
        trans1_FI_3_actuator_action,
        /* TRANDSDUCER BLOCK 4: Converter */
        trans1_FI_4_tag_desc,
        trans1_FI_4_strategy,
        trans1_FI_4_alert_key,
        trans1_FI_4_target_mode,
        trans1_FI_4_final_value_upper_range,
        trans1_FI_4_final_value_lower_range,
        trans1_FI_4_final_value_range_unit,
        trans1_FI_4_final_value_range_decimal_point,
        trans1_FI_4_act_sn,
        trans1_FI_4_cal_loc,
        trans1_FI_4_cal_date,
        trans1_FI_4_cal_who,
        trans1_FI_4_lin_type,
        trans1_FI_4_actuator_action,
        /* TRANDSDUCER BLOCK 5: Lcd */
        trans2_LCD_1_tag_desc,//trans1_FI_5_tag_desc,
        trans2_LCD_1_strategy,
        trans2_LCD_1_alert_key,
        trans2_LCD_1_target_mode,
        trans2_LCD_1_LcdEnable_1,
        trans2_LCD_1_LcdEnable_2,
        trans2_LCD_1_LcdEnable_3,
        trans2_LCD_1_LcdEnable_4,
        trans2_LCD_1_LcdEnable_5,
        trans2_LCD_1_LcdEnable_6,
        trans2_LCD_1_LcdEnable_7,
        trans2_LCD_1_LcdEnable_8,
        trans2_LCD_1_LcdDisType_1,
        trans2_LCD_1_LcdDisType_2,
        trans2_LCD_1_LcdDisType_3,
        trans2_LCD_1_LcdDisType_4,
        trans2_LCD_1_LcdDisType_5,
        trans2_LCD_1_LcdDisType_6,
        trans2_LCD_1_LcdDisType_7,
        trans2_LCD_1_LcdDisType_8,
        trans2_LCD_1_LcdDecimalPoint_1,
        trans2_LCD_1_LcdDecimalPoint_2,
        trans2_LCD_1_LcdDecimalPoint_3,
        trans2_LCD_1_LcdDecimalPoint_4,
        trans2_LCD_1_LcdDecimalPoint_5,
        trans2_LCD_1_LcdDecimalPoint_6,
        trans2_LCD_1_LcdDecimalPoint_7,
        trans2_LCD_1_LcdDecimalPoint_8,

        /* FUNCTION BLOCK 1: AO 1    */
        func3_AO_1_tag_desc,
        func3_AO_1_strategy,
        func3_AO_1_alert_key,
        func3_AO_1_target_mode,
        func3_AO_1_batch_id,
        func3_AO_1_batch_unit,
        func3_AO_1_batch_operation,
        func3_AO_1_batch_phase,
        func3_AO_1_in_channel,
        func3_AO_1_out_channel,
        func3_AO_1_pv_upper_range_value,
        func3_AO_1_pv_lower_range_value,
        func3_AO_1_pv_unit,
        func3_AO_1_pv_decimal_point,
        func3_AO_1_out_upper_range_value,
        func3_AO_1_out_lower_range_value,
        func3_AO_1_out_unit,
        func3_AO_1_out_decimal_point,
        func3_AO_1_fsafe_type,
        func3_AO_1_fsafe_time,
        func3_AO_1_fsafe_value,
        func3_AO_1_setpoint_deviation,
        func3_AO_1_check_back,
        func3_AO_1_check_back_mask,
        func3_AO_1_increase_close,

        /* FUNCTION BLOCK 1: AO 2    */
        func3_AO_2_tag_desc,
        func3_AO_2_strategy,
        func3_AO_2_alert_key,
        func3_AO_2_target_mode,
        func3_AO_2_batch_id,
        func3_AO_2_batch_unit,
        func3_AO_2_batch_operation,
        func3_AO_2_batch_phase,
        func3_AO_2_in_channel,
        func3_AO_2_out_channel,
        func3_AO_2_pv_upper_range_value,
        func3_AO_2_pv_lower_range_value,
        func3_AO_2_pv_unit,
        func3_AO_2_pv_decimal_point,
        func3_AO_2_out_upper_range_value,
        func3_AO_2_out_lower_range_value,
        func3_AO_2_out_unit,
        func3_AO_2_out_decimal_point,
        func3_AO_2_fsafe_type,
        func3_AO_2_fsafe_time,
        func3_AO_2_fsafe_value,
        func3_AO_2_setpoint_deviation,
        func3_AO_2_check_back,
        func3_AO_2_check_back_mask,
        func3_AO_2_increase_close,

        /* FUNCTION BLOCK 1: AO 3    */
        func3_AO_3_tag_desc,
        func3_AO_3_strategy,
        func3_AO_3_alert_key,
        func3_AO_3_target_mode,
        func3_AO_3_batch_id,
        func3_AO_3_batch_unit,
        func3_AO_3_batch_operation,
        func3_AO_3_batch_phase,
        func3_AO_3_in_channel,
        func3_AO_3_out_channel,
        func3_AO_3_pv_upper_range_value,
        func3_AO_3_pv_lower_range_value,
        func3_AO_3_pv_unit,
        func3_AO_3_pv_decimal_point,
        func3_AO_3_out_upper_range_value,
        func3_AO_3_out_lower_range_value,
        func3_AO_3_out_unit,
        func3_AO_3_out_decimal_point,
        func3_AO_3_fsafe_type,
        func3_AO_3_fsafe_time,
        func3_AO_3_fsafe_value,
        func3_AO_3_setpoint_deviation,
        func3_AO_3_check_back,
        func3_AO_3_check_back_mask,
        func3_AO_3_increase_close,

        /* FUNCTION BLOCK 1: AO 4    */
        func3_AO_4_tag_desc,
        func3_AO_4_strategy,
        func3_AO_4_alert_key,
        func3_AO_4_target_mode,
        func3_AO_4_batch_id,
        func3_AO_4_batch_unit,
        func3_AO_4_batch_operation,
        func3_AO_4_batch_phase,
        func3_AO_4_in_channel,
        func3_AO_4_out_channel,
        func3_AO_4_pv_upper_range_value,
        func3_AO_4_pv_lower_range_value,
        func3_AO_4_pv_unit,
        func3_AO_4_pv_decimal_point,
        func3_AO_4_out_upper_range_value,
        func3_AO_4_out_lower_range_value,
        func3_AO_4_out_unit,
        func3_AO_4_out_decimal_point,
        func3_AO_4_fsafe_type,
        func3_AO_4_fsafe_time,
        func3_AO_4_fsafe_value,
        func3_AO_4_setpoint_deviation,
        func3_AO_4_check_back,
        func3_AO_4_check_back_mask,
        func3_AO_4_increase_close
    }
    PRE_READ_ACTIONS
    {
        method_pre_write_phys_write_locking
    }
}




/*---------------------------------------------------------------------*/
/*    Menu: Device                                                     */
/*---------------------------------------------------------------------*/

MENU Menu_S_Device
{
    LABEL        [menu_Device];
    ITEMS
    {
        std_NodeAddress,
        SEPARATOR,
        std_LoadinDevice,
        std_LoadinPC,
        SEPARATOR,
        Menu_online,
        Menu_offline,
        SEPARATOR,
        Menu_cal,
        Menu_simulate,
        SEPARATOR,
        OnlineDialog_reset,
        OnlineDialog_write_locking,
        OnlineDialog_ident_number
    }
}

MENU Menu_M_Device
{
    LABEL        [menu_Device];
    ITEMS
    {
        std_NodeAddress,
        SEPARATOR,
        std_LoadinDevice,
        std_LoadinPC,
        SEPARATOR
//        Menu_online,
//        Menu_offline,
//        SEPARATOR,
//        Menu_cal,
//        Menu_simulate
    }
}

MENU Menu_online
{
    LABEL [MC_Online_Conf];
    ITEMS
    {
//        OnlineDialog_trans1_FI_1_setting,
//        OnlineDialog_trans1_FI_2_setting,
//        OnlineDialog_trans1_FI_3_setting,
//        OnlineDialog_trans1_FI_4_setting,
        Menu_AO_on,
        OnlineDialog_LCD_display

    }
}

MENU Menu_offline
{
    LABEL [MC_Offline_Conf];
    ITEMS
    {
        OfflineWindow_trans1_setting,
        Menu_AO_off,
//        OfflineWindow_LCD_display
    }
}

MENU Menu_cal
{
    LABEL [MC_menu_cal];
    ITEMS
    {
        Menu_trans1_cal
    }
}


MENU Menu_simulate
{
    LABEL "Simulate";
    ITEMS
    {
        Menu_simulate_AO
    }
}

MENU OfflineWindow_trans1_setting
{
    LABEL "Transducer (4)";
    ITEMS
    {
        Page_trans1_FI_1_setting,
        Page_trans1_FI_1_table,
        Page_trans1_FI_2_setting,
        Page_trans1_FI_2_table,
        Page_trans1_FI_3_setting,
        Page_trans1_FI_3_table,
        Page_trans1_FI_4_setting,
        Page_trans1_FI_4_table
    }
}

MENU Page_trans1_FI_1_table
{
    LABEL "User Table1";
    ITEMS
    {
        table_x_1,
		table_x_2,
		table_x_3,
		table_x_4,
		table_x_5,
		table_x_6,
		table_x_7,
		table_x_8,
        table_x_9,
		table_x_10,
		table_x_11,
		table_x_12,
		table_x_13,
		table_x_14,
		table_x_15,
		table_x_16,		
/*		number_of_points,   */
		SEPARATOR,
		table_y_1,
		table_y_2,
		table_y_3,
		table_y_4,
		table_y_5,
		table_y_6,
		table_y_7,
		table_y_8,
        table_y_9,  
		table_y_10, 
		table_y_11, 
		table_y_12, 
		table_y_13, 
		table_y_14, 
		table_y_15, 
		table_y_16, 
        SEPARATOR,
        method_read_table_1,
		method_send_table_1       
    }
}

MENU Page_trans1_FI_1_setting
{
    LABEL "Transducer 1";
    ITEMS
    {
        Group_trans1_FI_1_lin_type,
        Group_trans1_FI_1_scales,
        Group_trans1_FI_1_actuator_action,
        Group_trans1_FI_1_converter
    }
}

MENU Group_trans1_FI_1_lin_type
{
    LABEL "Select Linearization Type";
    ITEMS
    {
        trans1_FI_1_lin_type,
        SEPARATOR,
        method_trans1_FI_1_lin_type
    }
}

MENU Group_trans1_FI_1_scales
{
    LABEL "Set Scale of Final Value";
    ITEMS
    {
        trans1_FI_1_final_value_lower_range,
        trans1_FI_1_final_value_upper_range,
        SEPARATOR,
        method_trans1_FI_1_scales
    }
}

MENU Group_trans1_FI_1_actuator_action
{
    LABEL   "Select Fail Safe Position";
    ITEMS
    {
        trans1_FI_1_actuator_action,
        SEPARATOR,
        method_trans1_FI_1_actuator_action
    }
}

MENU Group_trans1_FI_1_converter
{
    LABEL   "Converter Info";
    ITEMS
    {
        trans1_FI_1_act_sn,
        trans1_FI_1_cal_loc,
        trans1_FI_1_cal_date,
        trans1_FI_1_cal_who,
        SEPARATOR,
        method_trans1_FI_1_converter
    }
}

MENU Page_trans1_FI_2_table
{
    LABEL "User Table2";
    ITEMS
    {
        table_x_1,
		table_x_2,
		table_x_3,
		table_x_4,
		table_x_5,
		table_x_6,
		table_x_7,
		table_x_8,
        table_x_9,
		table_x_10,
		table_x_11,
		table_x_12,
		table_x_13,
		table_x_14,
		table_x_15,
		table_x_16,		
/*		number_of_points,   */
		SEPARATOR,
		table_y_1,
		table_y_2,
		table_y_3,
		table_y_4,
		table_y_5,
		table_y_6,
		table_y_7,
		table_y_8,
        table_y_9,  
		table_y_10, 
		table_y_11, 
		table_y_12, 
		table_y_13, 
		table_y_14, 
		table_y_15, 
		table_y_16, 
        SEPARATOR,
        method_read_table_2,
		method_send_table_2       
    }
}
MENU Page_trans1_FI_2_setting
{
    LABEL "Transducer 2";
    ITEMS
    {
        Group_trans1_FI_2_lin_type,
        Group_trans1_FI_2_scales,
        Group_trans1_FI_2_actuator_action,
        Group_trans1_FI_2_converter
    }
}

MENU Group_trans1_FI_2_lin_type
{
    LABEL "Select Linearization Type";
    ITEMS
    {
        trans1_FI_2_lin_type,
        SEPARATOR,
        method_trans1_FI_2_lin_type
    }
}

MENU Group_trans1_FI_2_scales
{
    LABEL "Set Scale of Final Value";
    ITEMS
    {
        trans1_FI_2_final_value_lower_range,
        trans1_FI_2_final_value_upper_range,
        SEPARATOR,
        method_trans1_FI_2_scales
    }
}
MENU Group_trans1_FI_2_actuator_action
{
    LABEL   "Select Fail Safe Position";
    ITEMS
    {
        trans1_FI_2_actuator_action,
        SEPARATOR,
        method_trans1_FI_2_actuator_action
    }
}
MENU Group_trans1_FI_2_converter
{
    LABEL   "Converter Info";
    ITEMS
    {
        trans1_FI_2_act_sn,
        trans1_FI_2_cal_loc,
        trans1_FI_2_cal_date,
        trans1_FI_2_cal_who,
        SEPARATOR,
        method_trans1_FI_2_converter
    }
}

MENU Page_trans1_FI_3_table
{
    LABEL "User Table3";
    ITEMS
    {
        table_x_1,
		table_x_2,
		table_x_3,
		table_x_4,
		table_x_5,
		table_x_6,
		table_x_7,
		table_x_8,
        table_x_9,
		table_x_10,
		table_x_11,
		table_x_12,
		table_x_13,
		table_x_14,
		table_x_15,
		table_x_16,		
/*		number_of_points,   */
		SEPARATOR,
		table_y_1,
		table_y_2,
		table_y_3,
		table_y_4,
		table_y_5,
		table_y_6,
		table_y_7,
		table_y_8,
        table_y_9,  
		table_y_10, 
		table_y_11, 
		table_y_12, 
		table_y_13, 
		table_y_14, 
		table_y_15, 
		table_y_16, 
        SEPARATOR,
        method_read_table_3,
		method_send_table_3       
    }
}
MENU Page_trans1_FI_3_setting
{
    LABEL "Transducer 3";
    ITEMS
    {
        Group_trans1_FI_3_lin_type,
        Group_trans1_FI_3_scales,
        Group_trans1_FI_3_actuator_action,
        Group_trans1_FI_3_converter
    }
}

MENU Group_trans1_FI_3_lin_type
{
    LABEL "Select Linearization Type";
    ITEMS
    {
        trans1_FI_3_lin_type,
        SEPARATOR,
        method_trans1_FI_3_lin_type
    }
}

MENU Group_trans1_FI_3_scales
{
    LABEL "Set Scale of Final Value";
    ITEMS
    {
        trans1_FI_3_final_value_lower_range,
        trans1_FI_3_final_value_upper_range,
        SEPARATOR,
        method_trans1_FI_3_scales
    }
}
MENU Group_trans1_FI_3_actuator_action
{
    LABEL   "Select Fail Safe Position";
    ITEMS
    {
        trans1_FI_3_actuator_action,
        SEPARATOR,
        method_trans1_FI_3_actuator_action
    }
}
MENU Group_trans1_FI_3_converter
{
    LABEL   "Converter Info";
    ITEMS
    {
        trans1_FI_3_act_sn,
        trans1_FI_3_cal_loc,
        trans1_FI_3_cal_date,
        trans1_FI_3_cal_who,
        SEPARATOR,
        method_trans1_FI_3_converter
    }
}

MENU Page_trans1_FI_4_table
{
    LABEL "User Table4";
    ITEMS
    {
        table_x_1,
		table_x_2,
		table_x_3,
		table_x_4,
		table_x_5,
		table_x_6,
		table_x_7,
		table_x_8,
        table_x_9,
		table_x_10,
		table_x_11,
		table_x_12,
		table_x_13,
		table_x_14,
		table_x_15,
		table_x_16,		
/*		number_of_points,   */
		SEPARATOR,
		table_y_1,
		table_y_2,
		table_y_3,
		table_y_4,
		table_y_5,
		table_y_6,
		table_y_7,
		table_y_8,
        table_y_9,  
		table_y_10, 
		table_y_11, 
		table_y_12, 
		table_y_13, 
		table_y_14, 
		table_y_15, 
		table_y_16, 
        SEPARATOR,
        method_read_table_4,
		method_send_table_4       
    }
}
MENU Page_trans1_FI_4_setting
{
    LABEL "Transducer 4";
    ITEMS
    {
        Group_trans1_FI_4_lin_type,
        Group_trans1_FI_4_scales,
        Group_trans1_FI_4_actuator_action,
        Group_trans1_FI_4_converter
    }
}

MENU Group_trans1_FI_4_lin_type
{
    LABEL "Select Linearization Type";
    ITEMS
    {
        trans1_FI_4_lin_type,
        SEPARATOR,
        method_trans1_FI_4_lin_type
    }
}

MENU Group_trans1_FI_4_scales
{
    LABEL "Set Scale of Final Value";
    ITEMS
    {
        trans1_FI_4_final_value_lower_range,
        trans1_FI_4_final_value_upper_range,
        SEPARATOR,
        method_trans1_FI_4_scales
    }
}

MENU Group_trans1_FI_4_actuator_action
{
    LABEL   "Select Fail Safe Position";
    ITEMS
    {
        trans1_FI_4_actuator_action,
        SEPARATOR,
        method_trans1_FI_4_actuator_action
    }
}

MENU Group_trans1_FI_4_converter
{
    LABEL   "Converter Info";
    ITEMS
    {
        trans1_FI_4_act_sn,
        trans1_FI_4_cal_loc,
        trans1_FI_4_cal_date,
        trans1_FI_4_cal_who,
        SEPARATOR,
        method_trans1_FI_4_converter
    }
}

MENU Menu_trans1_cal
{
    LABEL "Transducer";
    ITEMS
    {
        OnlineDialog_trans1_FI_1_cal,
        OnlineDialog_trans1_FI_2_cal,
        OnlineDialog_trans1_FI_3_cal,
        OnlineDialog_trans1_FI_4_cal
    }
}

MENU OnlineDialog_trans1_FI_1_cal
{
    LABEL [MC_cal_trd1];
    ITEMS
    {
        Page_trans1_FI_1_cal_lower,
        Page_trans1_FI_1_cal_upper
    }
}

MENU Page_trans1_FI_1_cal_lower
{
    LABEL "Lower";
    ITEMS
    {
        func3_AO_1_target_mode,
        func3_AO_1_actual_mode,
        method_trans1_FI_1_lower_cal,
        SEPARATOR
    }
}

MENU Page_trans1_FI_1_cal_upper
{
    LABEL "Upper";
    ITEMS
    {
        func3_AO_1_target_mode,
        func3_AO_1_actual_mode,
        method_trans1_FI_1_upper_cal,
        SEPARATOR
    }
}

MENU OnlineDialog_trans1_FI_2_cal
{
    LABEL [MC_cal_trd2];
    ITEMS
    {
        Page_trans1_FI_2_cal_lower,
        Page_trans1_FI_2_cal_upper
    }
}

MENU Page_trans1_FI_2_cal_lower
{
    LABEL "Lower";
    ITEMS
    {
        func3_AO_2_target_mode,
        func3_AO_2_actual_mode,
        method_trans1_FI_2_lower_cal,
        SEPARATOR
    }
}

MENU Page_trans1_FI_2_cal_upper
{
    LABEL "Upper";
    ITEMS
    {
        func3_AO_2_target_mode,
        func3_AO_2_actual_mode,
        method_trans1_FI_2_upper_cal,
        SEPARATOR
    }
}

MENU OnlineDialog_trans1_FI_3_cal
{
    LABEL [MC_cal_trd3];
    ITEMS
    {
        Page_trans1_FI_3_cal_lower,
        Page_trans1_FI_3_cal_upper
    }
}

MENU Page_trans1_FI_3_cal_lower
{
    LABEL "Lower";
    ITEMS
    {
        func3_AO_3_target_mode,
        func3_AO_3_actual_mode,
        method_trans1_FI_3_lower_cal,
        SEPARATOR
    }
}

MENU Page_trans1_FI_3_cal_upper
{
    LABEL "Upper";
    ITEMS
    {
        func3_AO_3_target_mode,
        func3_AO_3_actual_mode,
        method_trans1_FI_3_upper_cal,
        SEPARATOR
    }
}

MENU OnlineDialog_trans1_FI_4_cal
{
    LABEL [MC_cal_trd4];
    ITEMS
    {
        Page_trans1_FI_4_cal_lower,
        Page_trans1_FI_4_cal_upper
    }
}

MENU Page_trans1_FI_4_cal_lower
{
    LABEL "Lower";
    ITEMS
    {
        func3_AO_4_target_mode,
        func3_AO_4_actual_mode,
        method_trans1_FI_4_lower_cal,
        SEPARATOR
    }
}

MENU Page_trans1_FI_4_cal_upper
{
    LABEL "Upper";
    ITEMS
    {
        func3_AO_4_target_mode,
        func3_AO_4_actual_mode,
        method_trans1_FI_4_upper_cal,
        SEPARATOR
    }
}

MENU OnlineWindow_simulation
{
    LABEL    [menu_dialog_simulation];
    ITEMS
    {
        Menu_simulate_AO
    }
}

/*---------------------------------------------------------------------*/
/*    Menu: View                                                       */
/*---------------------------------------------------------------------*/
MENU Menu_S_View
{
    LABEL        [menu_View];
    ITEMS
    {
        OnlineWindow_display,
        SEPARATOR,
        OnlineWindow_yt,
        Menu_S_alarm,
        OnlineWindow_diagnosis
        SEPARATOR,
        std_Funktionsleiste,
        std_Statuszeile,
        SEPARATOR,
        std_Update     
    }
}

MENU OnlineWindow_display
{
    LABEL        [menu_dialog_display];
    ITEMS
    {
        Page_display_trans1_FI_1,
        Page_display_trans1_FI_2,
        Page_display_trans1_FI_3,
        Page_display_trans1_FI_4,
        Page_display_AO_1,
        Page_display_AO_2,
	    Page_display_AO_3,
        Page_display_AO_4
    }
}

MENU Page_display_trans1_FI_1
{
    LABEL        "Transducer 1";
    ITEMS
    {
        BarVal_trans1_FI_1_display_measure,
        Group_trans1_FI_1_display_Final_Value,
        Group_trans1_FI_1_display_Return_Value
    }
}

MENU BarVal_trans1_FI_1_display_measure
{
    LABEL        "Final Value";
    ITEMS
    {
        trans1_FI_1_final_value                (READ_ONLY),
        trans1_FI_1_final_value_lower_range    (READ_ONLY),
        trans1_FI_1_final_value_upper_range    (READ_ONLY)
    }
}

MENU Group_trans1_FI_1_display_Final_Value
{
    LABEL        "Final Value form AO";
    ITEMS
    {
        trans1_FI_1_final_value                    (READ_ONLY),
        SEPARATOR,
        trans1_FI_1_final_value_status             (READ_ONLY)
//        trans1_FI_1_final_value_status_quality     (READ_ONLY),
//        trans1_FI_1_final_value_status_limit       (READ_ONLY)
    }
}

MENU Group_trans1_FI_1_display_Return_Value
{
    LABEL        "Return Value";
    ITEMS
    {
        trans1_FI_1_return_value                   (READ_ONLY),
        SEPARATOR,
        trans1_FI_1_return_value_status             (READ_ONLY)
//        trans1_FI_1_return_value_status_quality    (READ_ONLY),
//        trans1_FI_1_return_value_status_limit      (READ_ONLY)
    }
}

MENU Page_display_trans1_FI_2
{
    LABEL        "Transducer 2";
    ITEMS
    {
        BarVal_trans1_FI_2_display_measure,
        Group_trans1_FI_2_display_Final_Value,
        Group_trans1_FI_2_display_Return_Value
    }
}

MENU BarVal_trans1_FI_2_display_measure
{
    LABEL        "Final Value";
    ITEMS
    {
        trans1_FI_2_final_value                (READ_ONLY),
        trans1_FI_2_final_value_lower_range    (READ_ONLY),
        trans1_FI_2_final_value_upper_range    (READ_ONLY)
    }
}

MENU Group_trans1_FI_2_display_Final_Value
{
    LABEL        "Final Value form AO";
    ITEMS
    {
        trans1_FI_2_final_value                    (READ_ONLY),
        SEPARATOR,
        trans1_FI_2_final_value_status             (READ_ONLY)
//        trans1_FI_2_final_value_status_quality     (READ_ONLY),
//        trans1_FI_2_final_value_status_limit       (READ_ONLY)
    }
}

MENU Group_trans1_FI_2_display_Return_Value
{
    LABEL        "Return Value";
    ITEMS
    {
        trans1_FI_2_return_value                   (READ_ONLY),
        SEPARATOR,
        trans1_FI_2_return_value_status            (READ_ONLY)
//        trans1_FI_2_return_value_status_quality    (READ_ONLY),
//        trans1_FI_2_return_value_status_limit      (READ_ONLY)
    }
}

MENU Page_display_trans1_FI_3
{
    LABEL        "Transducer 3";
    ITEMS
    {
        BarVal_trans1_FI_3_display_measure,
        Group_trans1_FI_3_display_Final_Value,
        Group_trans1_FI_3_display_Return_Value
    }
}

MENU BarVal_trans1_FI_3_display_measure
{
    LABEL        "Final Value";
    ITEMS
    {
        trans1_FI_3_final_value                (READ_ONLY),
        trans1_FI_3_final_value_lower_range    (READ_ONLY),
        trans1_FI_3_final_value_upper_range    (READ_ONLY)
    }
}

MENU Group_trans1_FI_3_display_Final_Value
{
    LABEL        "Final Value form AO";
    ITEMS
    {
        trans1_FI_3_final_value                    (READ_ONLY),
        SEPARATOR,
        trans1_FI_3_final_value_status     (READ_ONLY)
//        trans1_FI_3_final_value_status_quality     (READ_ONLY),
//        trans1_FI_3_final_value_status_limit       (READ_ONLY)
    }
}

MENU Group_trans1_FI_3_display_Return_Value
{
    LABEL        "Return Value";
    ITEMS
    {
        trans1_FI_3_return_value                   (READ_ONLY),
        SEPARATOR,
        trans1_FI_3_return_value_status            (READ_ONLY)
//
//        trans1_FI_3_return_value_status_quality    (READ_ONLY),
//        trans1_FI_3_return_value_status_limit      (READ_ONLY)
    }
}

MENU Page_display_trans1_FI_4
{
    LABEL        "Transducer 4";
    ITEMS
    {
        BarVal_trans1_FI_4_display_measure,
        Group_trans1_FI_4_display_Final_Value,
        Group_trans1_FI_4_display_Return_Value
    }
}

MENU BarVal_trans1_FI_4_display_measure
{
    LABEL        "Final Value";
    ITEMS
    {
        trans1_FI_4_final_value                (READ_ONLY),
        trans1_FI_4_final_value_lower_range    (READ_ONLY),
        trans1_FI_4_final_value_upper_range    (READ_ONLY)
    }
}

MENU Group_trans1_FI_4_display_Final_Value
{
    LABEL        "Final Value form AO";
    ITEMS
    {
        trans1_FI_4_final_value                    (READ_ONLY),
        SEPARATOR,
        trans1_FI_4_final_value_status            (READ_ONLY)
//        trans1_FI_4_final_value_status_quality     (READ_ONLY),
//        trans1_FI_4_final_value_status_limit       (READ_ONLY)
    }
}

MENU Group_trans1_FI_4_display_Return_Value
{
    LABEL        "Return Value";
    ITEMS
    {
        trans1_FI_4_return_value                   (READ_ONLY),
        SEPARATOR,
        trans1_FI_4_return_value_status            (READ_ONLY)
//        trans1_FI_4_return_value_status_quality    (READ_ONLY),
//        trans1_FI_4_return_value_status_limit      (READ_ONLY)
    }
}

MENU Menu_S_alarm
{
    LABEL        [menu_dialog_alarm];
    ITEMS
    {
        OnlineWindow_S_alarm_func3_AO_1,
        OnlineWindow_S_alarm_func3_AO_2,
        OnlineWindow_S_alarm_func3_AO_3,
        OnlineWindow_S_alarm_func3_AO_4
    }
}

MENU OnlineWindow_diagnosis
{
    LABEL        [menu_dialog_diagnosis];
    ITEMS
    {
        Page_diagnosis_general,
        Page_diagnosis_phys_block,
        Page_diagnosis_trans1_FI_1_block,
        Page_diagnosis_trans1_FI_2_block,
        Page_diagnosis_trans1_FI_3_block,
        Page_diagnosis_trans1_FI_4_block,
        Page_diagnosis_func3_AO_1,
        Page_diagnosis_func3_AO_2,
        Page_diagnosis_func3_AO_3,
        Page_diagnosis_func3_AO_4
    }
}

MENU Page_diagnosis_trans1_FI_1_block
{
    LABEL    "Transducer 1";
    ITEMS
    {
        trans1_FI_1_blk_object,
        trans1_FI_1_blk_parent_class,
        trans1_FI_1_blk_class,
        trans1_FI_1_blk_dd_reference,
        trans1_FI_1_blk_dd_rev,
        trans1_FI_1_blk_profile,
        trans1_FI_1_blk_profile_rev,
        trans1_FI_1_st_rev,
        trans1_FI_1_actual_mode
    }
}

MENU Page_diagnosis_trans1_FI_2_block
{
    LABEL    "Transducer 2";
    ITEMS
    {
        trans1_FI_2_blk_object,
        trans1_FI_2_blk_parent_class,
        trans1_FI_2_blk_class,
        trans1_FI_2_blk_dd_reference,
        trans1_FI_2_blk_dd_rev,
        trans1_FI_2_blk_profile,
        trans1_FI_2_blk_profile_rev,
        trans1_FI_2_st_rev,
        trans1_FI_2_actual_mode
    }
}

MENU Page_diagnosis_trans1_FI_3_block
{
    LABEL    "Transducer 3";
    ITEMS
    {
        trans1_FI_3_blk_object,
        trans1_FI_3_blk_parent_class,
        trans1_FI_3_blk_class,
        trans1_FI_3_blk_dd_reference,
        trans1_FI_3_blk_dd_rev,
        trans1_FI_3_blk_profile,
        trans1_FI_3_blk_profile_rev,
        trans1_FI_3_st_rev,
        trans1_FI_3_actual_mode
    }
}

MENU Page_diagnosis_trans1_FI_4_block
{
    LABEL    "Transducer 4";
    ITEMS
    {
        trans1_FI_4_blk_object,
        trans1_FI_4_blk_parent_class,
        trans1_FI_4_blk_class,
        trans1_FI_4_blk_dd_reference,
        trans1_FI_4_blk_dd_rev,
        trans1_FI_4_blk_profile,
        trans1_FI_4_blk_profile_rev,
        trans1_FI_4_st_rev,
        trans1_FI_4_actual_mode
    }
}

/***********************************************************************/
/*****    Table: Specialist    *****************************************/
/***********************************************************************/

MENU Table_Main_Specialist
{
    LABEL    "NCS_FI105 (Specialist)";
    ITEMS
    {
        Tab_s_info,
        Tab_s_trd,
        Tab_s_ao

    }
}

MENU Tab_s_info
{
    LABEL    [MC_Tab_info];
    ITEMS
    {
        Tab_s_manuf_info,       /* file Phys_Blk.inc */
        Tab_s_block_tag,
        Tab_s_get_info,         /* file Phys_Blk.inc */
        Tab_serial_numbers,
        Tab_device_revisions,   /* file Phys_Blk.inc */
        Tab_s_certificates      /* file Phys_Blk.inc */
    }
}

MENU Tab_s_block_tag
{
    LABEL    [MC_Tab_block_tag];
    ITEMS
    {
        phys_tag_desc,
        trans1_FI_1_tag_desc,
        trans1_FI_2_tag_desc,
        trans1_FI_3_tag_desc,
        trans1_FI_4_tag_desc,
        trans2_LCD_1_tag_desc,
        func3_AO_1_tag_desc,
        func3_AO_2_tag_desc,
        func3_AO_3_tag_desc,
        func3_AO_4_tag_desc
        
    }
}

MENU Tab_serial_numbers
{
    LABEL   [MC_Tab_serial_numbers];
    ITEMS
    {
        phys_device_ser_num   (READ_ONLY),
    }
}

MENU Tab_s_trd
{
    LABEL   "Transducer (5)";
    ITEMS
    {
        Tab_s_trd_1,
        Tab_s_trd_2,
        Tab_s_trd_3,
        Tab_s_trd_4,
        Tab_s_lcd
    }
}

MENU Tab_s_trd_1
{
    LABEL   "Transducer 1";
    ITEMS
    {
        Tab_s_trd_1_lin_type,
        Tab_s_trd_1_scale,
        Tab_s_trd_1_actuator_action,
        Tab_s_trd_1_converter
    }
}

MENU Tab_s_trd_1_lin_type
{
    LABEL   "Select Linearization Type";
    ITEMS
    {
        trans1_FI_1_lin_type
    }
}

MENU Tab_s_trd_1_scale
{
    LABEL   "Set Scale of Final Value";
    ITEMS
    {
        trans1_FI_1_final_value_upper_range,
        trans1_FI_1_final_value_lower_range
    }
}

MENU Tab_s_trd_1_actuator_action
{
    LABEL   "Select Fail Safe Position";
    ITEMS
    {
        trans1_FI_1_actuator_action
    }
}

MENU Tab_s_trd_1_converter
{
    LABEL   "Converter Info";
    ITEMS
    {
        trans1_FI_1_act_sn,
        trans1_FI_1_cal_loc,
        trans1_FI_1_cal_date,
        trans1_FI_1_cal_who
    }
}

MENU Tab_s_trd_2
{
    LABEL   "Transducer 2";
    ITEMS
    {
        Tab_s_trd_2_lin_type,
        Tab_s_trd_2_scale,
        Tab_s_trd_2_actuator_action,
        Tab_s_trd_2_converter
    }
}

MENU Tab_s_trd_2_lin_type
{
    LABEL   "Select Linearization Type";
    ITEMS
    {
        trans1_FI_2_lin_type
    }
}

MENU Tab_s_trd_2_scale
{
    LABEL   "Set Scale of Final Value";
    ITEMS
    {
        trans1_FI_2_final_value_upper_range,
        trans1_FI_2_final_value_lower_range
    }
}
MENU Tab_s_trd_2_actuator_action
{
    LABEL   "Select Fail Safe Position";
    ITEMS
    {
        trans1_FI_2_actuator_action
    }
}
MENU Tab_s_trd_2_converter
{
    LABEL   "Converter Info";
    ITEMS
    {
        trans1_FI_2_act_sn,
        trans1_FI_2_cal_loc,
        trans1_FI_2_cal_date,
        trans1_FI_2_cal_who
    }
}

MENU Tab_s_trd_3
{
    LABEL   "Transducer 3";
    ITEMS
    {
        Tab_s_trd_3_lin_type,
        Tab_s_trd_3_scale,
        Tab_s_trd_3_actuator_action,
        Tab_s_trd_3_converter
    }
}

MENU Tab_s_trd_3_lin_type
{
    LABEL   "Select Linearization Type";
    ITEMS
    {
        trans1_FI_3_lin_type
    }
}

MENU Tab_s_trd_3_scale
{
    LABEL   "Set Scale of Final Value";
    ITEMS
    {
        trans1_FI_3_final_value_upper_range,
        trans1_FI_3_final_value_lower_range
    }
}
MENU Tab_s_trd_3_actuator_action
{
    LABEL   "Select Fail Safe Position";
    ITEMS
    {
        trans1_FI_3_actuator_action
    }
}
MENU Tab_s_trd_3_converter
{
    LABEL   "Converter Info";
    ITEMS
    {
        trans1_FI_3_act_sn,
        trans1_FI_3_cal_loc,
        trans1_FI_3_cal_date,
        trans1_FI_3_cal_who
    }
}

MENU Tab_s_trd_4
{
    LABEL   "Transducer 4";
    ITEMS
    {
        Tab_s_trd_4_lin_type,
        Tab_s_trd_4_scale,
        Tab_s_trd_4_actuator_action,
        Tab_s_trd_4_converter
    }
}

MENU Tab_s_trd_4_lin_type
{
    LABEL   "Select Linearization Type";
    ITEMS
    {
        trans1_FI_4_lin_type
    }
}

MENU Tab_s_trd_4_actuator_action
{
    LABEL   "Select Fail Safe Position";
    ITEMS
    {
        trans1_FI_4_actuator_action
    }
}

MENU Tab_s_trd_4_scale
{
    LABEL   "Set Scale of Final Value";
    ITEMS
    {
        trans1_FI_4_final_value_upper_range,
        trans1_FI_4_final_value_lower_range
    }
}

MENU Tab_s_trd_4_converter
{
    LABEL   "Converter Info";
    ITEMS
    {
        trans1_FI_4_act_sn,
        trans1_FI_4_cal_loc,
        trans1_FI_4_cal_date,
        trans1_FI_4_cal_who
    }
}

MENU Tab_s_ao
{
    LABEL   "Analog Output (4)";
    ITEMS
    {
        Tab_s_AO_1,
        Tab_s_AO_2,
        Tab_s_AO_3,
        Tab_s_AO_4
    }
}

/******************************************************************************/
/*****    Table: Maintenance    ***********************************************/
/******************************************************************************/
MENU Table_Main_Maintenance
{
    LABEL    "NCS_FI105 (Maintenance)";
    ITEMS
    {
        Tab_m_info,
        Tab_m_trd,
        Tab_m_AO
//        Tab_m_lcd
    }
}

MENU Tab_m_info
{
    LABEL    [MC_Tab_info];
    ITEMS
    {
        Tab_m_manuf_info,       /* file Phys_Blk.inc */
        Tab_m_block_tag,
        Tab_m_get_info,         /* file Phys_Blk.inc */
        Tab_serial_numbers,     /* file Phys_Blk.inc */
        Tab_device_revisions,   /* file Phys_Blk.inc */
        Tab_m_certificates      /* file Phys_Blk.inc */
    }
}

MENU Tab_m_block_tag
{
    LABEL    [MC_Tab_block_tag];
    ITEMS
    {
        phys_tag_desc  (READ_ONLY),
        trans1_FI_1_tag_desc  (READ_ONLY),
        trans1_FI_2_tag_desc  (READ_ONLY),
        trans1_FI_3_tag_desc  (READ_ONLY),
        trans1_FI_4_tag_desc  (READ_ONLY),
        trans2_LCD_1_tag_desc (READ_ONLY),
        func3_AO_1_tag_desc  (READ_ONLY),
        func3_AO_2_tag_desc  (READ_ONLY),
        func3_AO_3_tag_desc  (READ_ONLY),
        func3_AO_4_tag_desc  (READ_ONLY)
    }
}
//MENU Tab_m_trd
//{
//    LABEL   "Transducer (5)";
//    ITEMS
//    {
//        Tab_m_trd_1,
//        Tab_m_trd_2,
//        Tab_m_trd_3,
//        Tab_m_trd_4,
//        Tab_m_lcd
//    }
//}
//
//MENU Tab_m_trd_1
//{
//    LABEL   "Transducer 1";
//    ITEMS
//    {
//        Tab_m_trd_1_lin_type,
//        Tab_m_trd_1_scale,
//        Tab_m_trd_1_actuator_action,
//        Tab_m_trd_1_converter
//    }
//}
//
//MENU Tab_m_trd_1_lin_type
//{
//    LABEL   "Select Linearization Type";
//    ITEMS
//    {
//        trans1_FI_1_lin_type   (READ ONLY)
//    }
//}
//
//MENU Tab_m_trd_1_scale
//{
//    LABEL   "Set Scale of Final Value";
//    ITEMS
//    {
//        trans1_FI_1_final_value_upper_range (READ ONLY),
//        trans1_FI_1_final_value_lower_range (READ ONLY)
//    }
//}
//
//MENU Tab_m_trd_1_actuator_action
//{
//    LABEL   "Select Fail Safe Position";
//    ITEMS
//    {
//        trans1_FI_1_actuator_action (READ ONLY)
//    }
//}
//
//MENU Tab_m_trd_1_converter
//{
//    LABEL   "Converter Info";
//    ITEMS
//    {
//        trans1_FI_1_act_sn,(READ ONLY)
//        trans1_FI_1_cal_loc,(READ ONLY)
//        trans1_FI_1_cal_date,(READ ONLY)
//        trans1_FI_1_cal_who(READ ONLY)
//    }
//}
//
//MENU Tab_m_trd_2
//{
//    LABEL   "Transducer 2";
//    ITEMS
//    {
//        Tab_m_trd_2_lin_type, (READ ONLY)
//        Tab_m_trd_2_scale,    (READ ONLY)
//        Tab_m_trd_2_actuator_action, (READ ONLY)
//        Tab_m_trd_2_converter     (READ ONLY)
//    }
//}
//
//MENU Tab_m_trd_2_lin_type
//{
//    LABEL   "Select Linearization Type";
//    ITEMS
//    {
//        trans1_FI_2_lin_type (READ ONLY)
//    }
//}
//
//MENU Tab_m_trd_2_scale
//{
//    LABEL   "Set Scale of Final Value";
//    ITEMS
//    {
//        trans1_FI_2_final_value_upper_range, (READ ONLY)
//        trans1_FI_2_final_value_lower_range  (READ ONLY)
//    }
//}
//MENU Tab_m_trd_2_actuator_action
//{
//    LABEL   "Select Fail Safe Position";
//    ITEMS
//    {
//        trans1_FI_2_actuator_action (READ ONLY)
//    }
//}
//MENU Tab_m_trd_2_converter
//{
//    LABEL   "Converter Info";
//    ITEMS
//    {
//        trans1_FI_2_act_sn,(READ ONLY)
//        trans1_FI_2_cal_loc,(READ ONLY)
//        trans1_FI_2_cal_date,(READ ONLY)
//        trans1_FI_2_cal_who(READ ONLY)
//    }
//}
//
//MENU Tab_m_trd_3
//{
//    LABEL   "Transducer 3";
//    ITEMS
//    {
//        Tab_m_trd_3_lin_type,
//        Tab_m_trd_3_scale,
//        Tab_m_trd_3_actuator_action,
//        Tab_m_trd_3_converter
//    }
//}
//
//MENU Tab_m_trd_3_lin_type
//{
//    LABEL   "Select Linearization Type";
//    ITEMS
//    {
//        trans1_FI_3_lin_type (READ ONLY)
//    }
//}
//
//MENU Tab_m_trd_3_scale
//{
//    LABEL   "Set Scale of Final Value";
//    ITEMS
//    {
//        trans1_FI_3_final_value_upper_range, (READ ONLY)
//        trans1_FI_3_final_value_lower_range  (READ ONLY)
//    }
//}
//MENU Tab_m_trd_3_actuator_action
//{
//    LABEL   "Select Fail Safe Position";
//    ITEMS
//    {
//        trans1_FI_3_actuator_action (READ ONLY)
//    }
//}
//MENU Tab_m_trd_3_converter
//{
//    LABEL   "Converter Info";
//    ITEMS
//    {
//        trans1_FI_3_act_sn,(READ ONLY)
//        trans1_FI_3_cal_loc,(READ ONLY)
//        trans1_FI_3_cal_date,(READ ONLY)
//        trans1_FI_3_cal_who(READ ONLY)
//    }
//}
//
//MENU Tab_m_trd_4
//{
//    LABEL   "Transducer 4";
//    ITEMS
//    {
//        Tab_m_trd_4_lin_type,
//        Tab_m_trd_4_scale,
//        Tab_m_trd_4_actuator_action,
//        Tab_m_trd_4_converter
//    }
//}
//
//MENU Tab_m_trd_4_lin_type
//{
//    LABEL   "Select Linearization Type";
//    ITEMS
//    {
//        trans1_FI_4_lin_type (READ ONLY)
//    }
//}
//
//MENU Tab_m_trd_4_actuator_action
//{
//    LABEL   "Select Fail Safe Position";
//    ITEMS
//    {
//        trans1_FI_4_actuator_action (READ ONLY)
//    }
//}
//
//MENU Tab_m_trd_4_scale
//{
//    LABEL   "Set Scale of Final Value";
//    ITEMS
//    {
//        trans1_FI_4_final_value_upper_range, (READ ONLY)
//        trans1_FI_4_final_value_lower_range (READ ONLY)
//    }
//}
//
//MENU Tab_m_trd_4_converter
//{
//    LABEL   "Converter Info";
//    ITEMS
//    {
//        trans1_FI_4_act_sn,(READ ONLY)
//        trans1_FI_4_cal_loc,(READ ONLY)
//        trans1_FI_4_cal_date,(READ ONLY)
//        trans1_FI_4_cal_who(READ ONLY)
//    }
//}
//
MENU Tab_m_trd_1
{
    LABEL   "Transducer 1";
    ITEMS
    {
        Tab_m_trd_1_lin_type,
        Tab_m_trd_1_scale,
        Tab_m_trd_1_converter
    }
}

MENU Tab_m_trd_1_lin_type
{
    LABEL   "Select Linearization Type";
    ITEMS
    {
        trans1_FI_1_lin_type                    (READ_ONLY)
    }
}

MENU Tab_m_trd_1_scale
{
    LABEL   "Set Scale of Final Value";
    ITEMS
    {
        trans1_FI_1_final_value_upper_range     (READ_ONLY),
        trans1_FI_1_final_value_lower_range     (READ_ONLY)
    }
}

MENU Tab_m_trd_1_converter
{
    LABEL   "Converter Info";
    ITEMS
    {
        trans1_FI_1_act_sn                      (READ_ONLY),
        trans1_FI_1_cal_loc                     (READ_ONLY),
        trans1_FI_1_cal_date                    (READ_ONLY),
        trans1_FI_1_cal_who                     (READ_ONLY)
    }
}

MENU Tab_m_trd_2
{
    LABEL   "Transducer 2";
    ITEMS
    {
        Tab_m_trd_2_lin_type,
        Tab_m_trd_2_scale,
        Tab_m_trd_2_converter
    }
}

MENU Tab_m_trd_2_lin_type
{
    LABEL   "Select Linearization Type";
    ITEMS
    {
        trans1_FI_2_lin_type                    (READ_ONLY)
    }
}

MENU Tab_m_trd_2_scale
{
    LABEL   "Set Scale of Final Value";
    ITEMS
    {
        trans1_FI_2_final_value_upper_range     (READ_ONLY),
        trans1_FI_2_final_value_lower_range     (READ_ONLY)
    }
}

MENU Tab_m_trd_2_converter
{
    LABEL   "Converter Info";
    ITEMS
    {
        trans1_FI_2_act_sn                      (READ_ONLY),
        trans1_FI_2_cal_loc                     (READ_ONLY),
        trans1_FI_2_cal_date                    (READ_ONLY),
        trans1_FI_2_cal_who                     (READ_ONLY)
    }
}

MENU Tab_m_trd_3
{
    LABEL   "Transducer 3";
    ITEMS
    {
        Tab_m_trd_3_lin_type,
        Tab_m_trd_3_scale,
        Tab_m_trd_3_converter
    }
}

MENU Tab_m_trd_3_lin_type
{
    LABEL   "Select Linearization Type";
    ITEMS
    {
        trans1_FI_3_lin_type                    (READ_ONLY)
    }
}

MENU Tab_m_trd_3_scale
{
    LABEL   "Set Scale of Final Value";
    ITEMS
    {
        trans1_FI_3_final_value_upper_range     (READ_ONLY),
        trans1_FI_3_final_value_lower_range     (READ_ONLY)
    }
}

MENU Tab_m_trd_3_converter
{
    LABEL   "Converter Info";
    ITEMS
    {
        trans1_FI_3_act_sn                      (READ_ONLY),
        trans1_FI_3_cal_loc                     (READ_ONLY),
        trans1_FI_3_cal_date                    (READ_ONLY),
        trans1_FI_3_cal_who                     (READ_ONLY)
    }
}

MENU Tab_m_trd_4
{
    LABEL   "Transducer 4";
    ITEMS
    {
        Tab_m_trd_4_lin_type,
        Tab_m_trd_4_scale,
        Tab_m_trd_4_converter
    }
}

MENU Tab_m_trd_4_lin_type
{
    LABEL   "Select Linearization Type";
    ITEMS
    {
        trans1_FI_4_lin_type                    (READ_ONLY)
    }
}

MENU Tab_m_trd_4_scale
{
    LABEL   "Set Scale of Final Value";
    ITEMS
    {
        trans1_FI_4_final_value_upper_range     (READ_ONLY),
        trans1_FI_4_final_value_lower_range     (READ_ONLY)
    }
}

MENU Tab_m_trd_4_converter
{
    LABEL   "Converter Info";
    ITEMS
    {
        trans1_FI_4_act_sn                      (READ_ONLY),
        trans1_FI_4_cal_loc                     (READ_ONLY),
        trans1_FI_4_cal_date                    (READ_ONLY),
        trans1_FI_4_cal_who                     (READ_ONLY)
    }
}

MENU Tab_m_trd
{
    LABEL   "Transducer (5)";
    ITEMS
    {
        Tab_m_trd_1,
        Tab_m_trd_2,
        Tab_m_trd_3,
        Tab_m_trd_4,
        Tab_m_lcd
    }
}

MENU Tab_m_AO
{
    LABEL   "Analog Output (4)";
    ITEMS
    {
        Tab_m_AO_1,
        Tab_m_AO_2,
        Tab_m_AO_3,
        Tab_m_AO_4
    }
}

MENU Tab_m_AO_1
{
	LABEL		"AO-1";
	ITEMS
	{
		Tab_m_basic_AO_1,
		Tab_m_advanced_AO_1
	}
}

MENU Tab_m_basic_AO_1
{
	LABEL		"Basic";
	ITEMS
	{
		Tab_m_target_mode_AO_1,
		Tab_m_channel_in_AO_1,
		Tab_m_channel_out_AO_1,
		Tab_m_direction_AO_1,
		Tab_m_scale_pv_AO_1,
		Tab_m_scale_out_AO_1
	}
}

MENU Tab_m_advanced_AO_1
{
	LABEL		"Advanced";
	ITEMS
	{
		Tab_m_fault_set_AO_1,
		Tab_m_batch_AO_1
	}
}

MENU Tab_m_target_mode_AO_1
{
	LABEL		"Select Block Mode";
	ITEMS
	{
		func3_AO_1_target_mode  (READ_ONLY)
	}
}

MENU Tab_m_channel_in_AO_1
{
	LABEL		"Select Input";
	ITEMS
	{
		func3_AO_1_in_channel       (READ_ONLY)
	}
}

MENU Tab_m_channel_out_AO_1
{
	LABEL		"Select Output";
	ITEMS
	{
		func3_AO_1_out_channel       (READ_ONLY)//(READ_ONLY)
	}
}


MENU 	Tab_m_scale_pv_AO_1
{
	LABEL "Set Scale of Input Value";
	ITEMS
	{
		func3_AO_1_pv_upper_range_value(READ_ONLY),
		func3_AO_1_pv_lower_range_value(READ_ONLY),
		func3_AO_1_pv_unit              (READ_ONLY)
	}
}

MENU    Tab_m_scale_out_AO_1
{
	LABEL "Set Scale of Output Value";
	ITEMS
	{
		func3_AO_1_out_upper_range_value    (READ_ONLY),
		func3_AO_1_out_lower_range_value    (READ_ONLY),
		func3_AO_1_out_unit (READ_ONLY)
	}
}

MENU Tab_m_direction_AO_1
{
	LABEL		"Select Positioner/Actuator Action";
	ITEMS
	{
		func3_AO_1_increase_close (READ_ONLY)
	}
}

MENU Tab_m_fault_set_AO_1
{
	LABEL		"Set Fail Safe Values";
	ITEMS
	{
		func3_AO_1_fsafe_type (READ_ONLY),
		func3_AO_1_fsafe_time (READ_ONLY),
		func3_AO_1_fsafe_value (READ_ONLY)
	}
}

MENU Tab_m_batch_AO_1
{
	LABEL		"Define Batch Information";
	ITEMS
	{
		func3_AO_1_batch_id,  
		func3_AO_1_batch_unit,
		func3_AO_1_batch_operation,
		func3_AO_1_batch_phase
	}
}

MENU Tab_m_AO_2
{
	LABEL		"AO-2";
	ITEMS
	{
		Tab_m_basic_AO_2,
		Tab_m_advanced_AO_2
	}
}

MENU Tab_m_basic_AO_2
{
	LABEL		"Basic";
	ITEMS
	{
		Tab_m_target_mode_AO_2,
		Tab_m_channel_in_AO_2,
		Tab_m_channel_out_AO_2,
		Tab_m_direction_AO_2,
		Tab_m_scale_pv_AO_1,
		Tab_m_scale_out_AO_2
	}
}

MENU Tab_m_advanced_AO_2
{
	LABEL		"Advanced";
	ITEMS
	{
		Tab_m_fault_set_AO_2,
		Tab_m_batch_AO_2
	}
}

MENU Tab_m_target_mode_AO_2
{
	LABEL		"Select Block Mode";
	ITEMS
	{
		func3_AO_2_target_mode  (READ_ONLY)
	}
}

MENU Tab_m_channel_in_AO_2
{
	LABEL		"Select Input";
	ITEMS
	{
		func3_AO_2_in_channel       (READ_ONLY)
	}
}

MENU Tab_m_channel_out_AO_2
{
	LABEL		"Select Output";
	ITEMS
	{
		func3_AO_2_out_channel       (READ_ONLY)//(READ_ONLY)
	}
}


MENU 	Tab_m_scale_pv_AO_2
{
	LABEL "Set Scale of Input Value";
	ITEMS
	{
		func3_AO_2_pv_upper_range_value (READ_ONLY),
		func3_AO_2_pv_lower_range_value (READ_ONLY),
		func3_AO_2_pv_unit              (READ_ONLY)
	}
}

MENU    Tab_m_scale_out_AO_2
{
	LABEL "Set Scale of Output Value";
	ITEMS
	{
		func3_AO_2_out_upper_range_value    (READ_ONLY),
		func3_AO_2_out_lower_range_value    (READ_ONLY),
		func3_AO_2_out_unit (READ_ONLY)
	}
}

MENU Tab_m_direction_AO_2
{
	LABEL		"Select Positioner/Actuator Action";
	ITEMS
	{
		func3_AO_2_increase_close (READ_ONLY)
	}
}

MENU Tab_m_fault_set_AO_2
{
	LABEL		"Set Fail Safe Values";
	ITEMS
	{
		func3_AO_2_fsafe_type    (READ_ONLY),
		func3_AO_2_fsafe_time    (READ_ONLY),
		func3_AO_2_fsafe_value (READ_ONLY)
	}
}

MENU Tab_m_batch_AO_2
{
	LABEL		"Define Batch Information";
	ITEMS
	{
		func3_AO_2_batch_id,  
		func3_AO_2_batch_unit,
		func3_AO_2_batch_operation,
		func3_AO_2_batch_phase
	}
}
MENU Tab_m_AO_3
{
	LABEL		"AO-3";
	ITEMS
	{
		Tab_m_basic_AO_3,
		Tab_m_advanced_AO_3
	}
}

MENU Tab_m_basic_AO_3
{
	LABEL		"Basic";
	ITEMS
	{
		Tab_m_target_mode_AO_3,
		Tab_m_channel_in_AO_3,
		Tab_m_channel_out_AO_3,
		Tab_m_direction_AO_3,
		Tab_m_scale_pv_AO_3,
		Tab_m_scale_out_AO_3
	}
}

MENU Tab_m_advanced_AO_3
{
	LABEL		"Advanced";
	ITEMS
	{
		Tab_m_fault_set_AO_3,
		Tab_m_batch_AO_3
	}
}

MENU Tab_m_target_mode_AO_3
{
	LABEL		"Select Block Mode";
	ITEMS
	{
		func3_AO_3_target_mode  (READ_ONLY)
	}
}

MENU Tab_m_channel_in_AO_3
{
	LABEL		"Select Input";
	ITEMS
	{
		func3_AO_3_in_channel       (READ_ONLY)
	}
}

MENU Tab_m_channel_out_AO_3
{
	LABEL		"Select Output";
	ITEMS
	{
		func3_AO_3_out_channel       (READ_ONLY)//(READ_ONLY)
	}
}


MENU 	Tab_m_scale_pv_AO_3
{
	LABEL "Set Scale of Input Value";
	ITEMS
	{
		func3_AO_3_pv_upper_range_value (READ_ONLY),
		func3_AO_3_pv_lower_range_value (READ_ONLY),
		func3_AO_3_pv_unit              (READ_ONLY)
	}
}

MENU    Tab_m_scale_out_AO_3
{
	LABEL "Set Scale of Output Value";
	ITEMS
	{
		func3_AO_3_out_upper_range_value    (READ_ONLY),
		func3_AO_3_out_lower_range_value    (READ_ONLY),
		func3_AO_3_out_unit (READ_ONLY)
	}
}

MENU Tab_m_direction_AO_3
{
	LABEL		"Select Positioner/Actuator Action";
	ITEMS
	{
		func3_AO_3_increase_close (READ_ONLY)
	}
}

MENU Tab_m_fault_set_AO_3
{
	LABEL		"Set Fail Safe Values";
	ITEMS
	{
		func3_AO_3_fsafe_type (READ_ONLY),
		func3_AO_3_fsafe_time (READ_ONLY),
		func3_AO_3_fsafe_value (READ_ONLY)
	}
}

MENU Tab_m_batch_AO_3
{
	LABEL		"Define Batch Information";
	ITEMS
	{
		func3_AO_3_batch_id,  
		func3_AO_3_batch_unit,
		func3_AO_3_batch_operation,
		func3_AO_3_batch_phase
	}
}
MENU Tab_m_AO_4
{
	LABEL		"AO-4";
	ITEMS
	{
		Tab_m_basic_AO_4,
		Tab_m_advanced_AO_4
	}
}

MENU Tab_m_basic_AO_4
{
	LABEL		"Basic";
	ITEMS
	{
		Tab_m_target_mode_AO_4,
		Tab_m_channel_in_AO_4,
		Tab_m_channel_out_AO_4,
		Tab_m_direction_AO_4,
		Tab_m_scale_pv_AO_4,
		Tab_m_scale_out_AO_4
	}
}

MENU Tab_m_advanced_AO_4
{
	LABEL		"Advanced";
	ITEMS
	{
		Tab_m_fault_set_AO_4,
		Tab_m_batch_AO_4
	}
}

MENU Tab_m_target_mode_AO_4
{
	LABEL		"Select Block Mode";
	ITEMS
	{
		func3_AO_4_target_mode  (READ_ONLY)
	}
}

MENU Tab_m_channel_in_AO_4
{
	LABEL		"Select Input";
	ITEMS
	{
		func3_AO_4_in_channel       (READ_ONLY)
	}
}

MENU Tab_m_channel_out_AO_4
{
	LABEL		"Select Output";
	ITEMS
	{
		func3_AO_4_out_channel       (READ_ONLY)//(READ_ONLY)
	}
}


MENU 	Tab_m_scale_pv_AO_4
{
	LABEL "Set Scale of Input Value";
	ITEMS
	{
		func3_AO_4_pv_upper_range_value (READ_ONLY),
		func3_AO_4_pv_lower_range_value (READ_ONLY),
		func3_AO_4_pv_unit              (READ_ONLY)
	}
}

MENU    Tab_m_scale_out_AO_4
{
	LABEL "Set Scale of Output Value";
	ITEMS
	{
		func3_AO_4_out_upper_range_value    (READ_ONLY),
		func3_AO_4_out_lower_range_value    (READ_ONLY),
		func3_AO_4_out_unit(READ_ONLY)
	}
}

MENU Tab_m_direction_AO_4
{
	LABEL		"Select Positioner/Actuator Action";
	ITEMS
	{
		func3_AO_4_increase_close (READ_ONLY)
	}
}

MENU Tab_m_fault_set_AO_4
{
	LABEL		"Set Fail Safe Values";
	ITEMS
	{
		func3_AO_4_fsafe_type  (READ_ONLY),
		func3_AO_4_fsafe_time  (READ_ONLY),
		func3_AO_4_fsafe_value (READ_ONLY)
	}
}

MENU Tab_m_batch_AO_4
{
	LABEL		"Define Batch Information";
	ITEMS
	{
		func3_AO_4_batch_id,  
		func3_AO_4_batch_unit,
		func3_AO_4_batch_operation,
		func3_AO_4_batch_phase
	}
}

METHOD std_NodeAddress
{
    LABEL        [menu_Device_NodeAddress];
    DEFINITION
    {
    }
}

METHOD std_LoadinDevice
{
    LABEL        [menu_Device_LoadinDevice];
    DEFINITION
    {
    }
}

METHOD std_LoadinPC
{
    LABEL        [menu_Device_LoadinPC];
    DEFINITION
    {
    }
}

METHOD std_Funktionsleiste
{
    LABEL        [menu_View_Toolbar];
    DEFINITION
    {
    }
}

METHOD std_Statuszeile
{
    LABEL        [menu_View_Statusbar];
    DEFINITION
    {
    }
}

METHOD std_Update
{
    LABEL        [menu_View_Update];
    DEFINITION
    {
    }
}

METHOD method_set
{
    LABEL        [MC_Write];
    HELP         [transfer_help];
    DEFINITION
    {
    }
}

METHOD  method_pre_write_phys_write_locking
{
    LABEL   [method_pre_write_phys_write_locking];
    DEFINITION
    {
        int ret;
        ReadCommand (read_phys_write_locking);
        if ( phys_write_locking == 0 )
        {
            ret = ACKNOWLEDGE([label_DeviceIsWriteProtected]);
            if (ret) process_abort();
        }
    }
}

METHOD  method_trans1_FI_1_lin_type
{
    LABEL "Write";
	DEFINITION
	{
		WriteCommand(write_trans1_FI_1_lin_type);
		ReadCommand(read_trans1_FI_1_lin_type);
	}
}

METHOD  method_trans1_FI_1_scales
{
    LABEL "Write";
	DEFINITION
    {
    
		WriteCommand(write_trans1_FI_1_final_value_range);
		ReadCommand(read_trans1_FI_1_final_value_range);
    }
}
METHOD  method_trans1_FI_1_actuator_action
{
    LABEL "Write";
	DEFINITION
    {
    
		WriteCommand(write_trans1_FI_1_actuator_action);
		ReadCommand(read_trans1_FI_1_actuator_action);
    }
}
METHOD  method_trans1_FI_1_converter
{
    LABEL "Write";
	DEFINITION
    {
		WriteCommand(write_trans1_FI_1_act_sn);
		WriteCommand(write_trans1_FI_1_cal_loc);
		WriteCommand(write_trans1_FI_1_cal_date);
		WriteCommand(write_trans1_FI_1_cal_who);
		ReadCommand(read_trans1_FI_1_act_sn);
		ReadCommand(read_trans1_FI_1_cal_loc);
		ReadCommand(read_trans1_FI_1_cal_date);
		ReadCommand(read_trans1_FI_1_cal_who);
    }
}

METHOD	method_trans1_FI_1_lower_cal
{
	LABEL "Lower Calibration Point";
	HELP  "Lower Calibration Point";
	DEFINITION
	{
		char   flagtest1, flagtest;
		float  trim_point, var_feedback;
		int    rc, result, actual_mode, CalControl;

		flagtest1 = 0;
		flagtest = 0;

        actual_mode = ivar_value(func3_AO_1_actual_mode);
        if (actual_mode == 0x10)
        {
            CalControl = 1;
            fassign(trans1_FI_1_cal_control,CalControl);
            WriteCommand(write_trans1_FI_1_cal_control);
        }
        else
        {
            /* display a message that requires user acknowledgment */
            ACKNOWLEDGE("WARNING: Control loop should be in manual !");
			flagtest1 = 1;
			flagtest = 1;
        }

	  /*  3.99mA <= desired point <= 11.5mA */

	  /*  show operating limits for lower and wait acknowledgment from user */

		trim_point = fvar_value(trans1_FI_1_sensor_value);

		while (flagtest == 0)
		{
			rc=GET_LOCAL_VAR_VALUE("Lower Calibration Point ( from 3.99 to 11.50 mA ):", trim_point);

			if(rc==0)
			{
				if(trim_point < 3.99 || trim_point > 11.50)
				{
					ACKNOWLEDGE("Value out of range");
				}
				else
				{
					flagtest=1;
					fassign(trans1_FI_1_sensor_value,trim_point);
				    WriteCommand(write_trans1_FI_1_sensor_value);
				}
			}
			else
			{
				flagtest=1;
				flagtest1=1;
			}
	    }

        while (flagtest1 == 0)
        {
            ACKNOWLEDGE("Please, read the current in channel 1.");
            rc=GET_LOCAL_VAR_VALUE("Please, enter the miliamperimeter's current value:",var_feedback);

            if(rc==0)
            {
                fassign(trans1_FI_1_cal_point_lo,var_feedback);
                result = SELECT_FROM_LIST("Proceed it again ?","Yes;No");

                if (result == 0)
                  flagtest1 = 0;
                else
                {
                  WriteCommand(write_trans1_FI_1_cal_point_lo);
                  ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                  flagtest1 = 1;
                }
            }
            else
            {
                ReadCommand(read_trans1_FI_1_cal_point_lo);
                ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                flagtest1 = 1;
            }
        }
        CalControl = 0;
        fassign(trans1_FI_1_cal_control,CalControl);
        WriteCommand(write_trans1_FI_1_cal_control);
	}
}

METHOD	method_trans1_FI_1_upper_cal
{
	LABEL "Upper Calibration Point";
	HELP  "Upper Calibration Point";
	DEFINITION
	{
		char   flagtest1, flagtest;
		float  trim_point, var_feedback;
		int    rc, result, actual_mode, CalControl;

		flagtest1 = 0;
		flagtest = 0;

        actual_mode = ivar_value(func3_AO_1_actual_mode);
        if (actual_mode == 0x10)
        {
            CalControl = 1;
            fassign(trans1_FI_1_cal_control,CalControl);
            WriteCommand(write_trans1_FI_1_cal_control);
        }
        else
        {
            /* display a message that requires user acknowledgment */
            ACKNOWLEDGE("WARNING: Control loop should be in manual !");
			flagtest1 = 1;
			flagtest = 1;
        }

	  /*  12.5mA <= desired point <= 20.01 mA */

	  /*  show operating limits for upper and wait acknowledgment from user */

	    trim_point = fvar_value(trans1_FI_1_sensor_value);
	
	    while (flagtest == 0)
	    {
            rc=GET_LOCAL_VAR_VALUE("Upper Calibration Point ( from 12.5 to 20.01 mA ):", trim_point);

            if(rc==0)
            {
                if(trim_point < 12.5 || trim_point > 20.01)
                {
                    ACKNOWLEDGE("Value out of range");
                }
                else
                {
                    flagtest=1;
                    fassign(trans1_FI_1_sensor_value,trim_point);
                    WriteCommand(write_trans1_FI_1_sensor_value);
                }
            }
            else
            {
                flagtest=1;
                flagtest1=1;
            }
        }

        while (flagtest1 == 0)
        {
            ACKNOWLEDGE("Please, read the current in channel 1.");
            rc=GET_LOCAL_VAR_VALUE("Please, enter the miliamperimeter's current value:",var_feedback);

            if(rc==0)
            {
                fassign(trans1_FI_1_cal_point_hi,var_feedback);
                result = SELECT_FROM_LIST("Proceed it again ?","Yes;No");
                if (result == 0)
                  flagtest1 = 0;
                else
                {
                  WriteCommand(write_trans1_FI_1_cal_point_hi);
                  ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                  flagtest1 = 1;
                }
            }
            else
            {
                ReadCommand(read_trans1_FI_1_cal_point_hi);
                ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                flagtest1 = 1;
            }
        }
        CalControl = 0;
        fassign(trans1_FI_1_cal_control,CalControl);
        WriteCommand(write_trans1_FI_1_cal_control);
	}
}

METHOD method_read_table_1
{
	LABEL   "Read table";
	HELP 	[meth_read_table_src_help];
	DEFINITION
	{
		int i;
		float x1[16],y1[16];

		for (i=0;i<16;i++)
		{
			iassign(trans1_FI_1_tab_entryidx,i+1);
			WriteCommand(write_trans1_FI_1_tab_entryidx);
			ReadCommand(read_trans1_FI_1_tab_value);
			x1[i] = fvar_value(trans1_FI_1_tab_x_value);
			y1[i] = fvar_value(trans1_FI_1_tab_y_value);
		}

		fassign(table_x_1,x1[0]);
		fassign(table_y_1,y1[0]);
		fassign(table_x_2,x1[1]);
		fassign(table_y_2,y1[1]);
		fassign(table_x_3,x1[2]);
		fassign(table_y_3,y1[2]);
		fassign(table_x_4,x1[3]);
		fassign(table_y_4,y1[3]);
		fassign(table_x_5,x1[4]);
		fassign(table_y_5,y1[4]);
		fassign(table_x_6,x1[5]);
		fassign(table_y_6,y1[5]);
		fassign(table_x_7,x1[6]);
		fassign(table_y_7,y1[6]);
		fassign(table_x_8,x1[7]);
		fassign(table_y_8,y1[7]);
       	fassign(table_x_9,x1[8]);
		fassign(table_y_9,y1[8]);
		fassign(table_x_10,x1[9]);
		fassign(table_y_10,y1[9]);
		fassign(table_x_11,x1[10]);
		fassign(table_y_11,y1[10]);
		fassign(table_x_12,x1[11]);
		fassign(table_y_12,y1[11]);
		fassign(table_x_13,x1[12]);
		fassign(table_y_13,y1[12]);
		fassign(table_x_14,x1[13]);
		fassign(table_y_14,y1[13]);
		fassign(table_x_15,x1[14]);
		fassign(table_y_15,y1[14]);
		fassign(table_x_16,x1[15]);
		fassign(table_y_16,y1[15]);
	}
}
METHOD method_send_table_1
{
	LABEL "Write Table";
	DEFINITION
	{
		int     opcode,num_point,i, rc;
		float   x1[16],y1[16];
		int		status,flag1,flag2;
		char	text[];

		flag1 = 0;
		flag2 = 0;

		while (flag1 == 0)
		{
			rc=GET_LOCAL_VAR_VALUE("Please enter the number of points you would like to validate in your table.", num_point);
			if (rc==0)
			{
				if(num_point < 2 || num_point > 16)
				{
					ACKNOWLEDGE("Number of points is out of the range ( 2 - 16)");
				}
				else
				{
					flag1 = 1;
				}
			}
			else
			{
				flag1 = 1;
				flag2 = 1;
				ACKNOWLEDGE("The table will not be written");
			}
		}

		if (flag2==0)
		{
			x1[0] = fvar_value(table_x_1);
			y1[0] = fvar_value(table_y_1);
			x1[1] = fvar_value(table_x_2);
			y1[1] = fvar_value(table_y_2);
			x1[2] = fvar_value(table_x_3);
			y1[2] = fvar_value(table_y_3);
			x1[3] = fvar_value(table_x_4);
			y1[3] = fvar_value(table_y_4);
			x1[4] = fvar_value(table_x_5);
			y1[4] = fvar_value(table_y_5);
			x1[5] = fvar_value(table_x_6);
			y1[5] = fvar_value(table_y_6);
			x1[6] = fvar_value(table_x_7);
			y1[6] = fvar_value(table_y_7);
			x1[7] = fvar_value(table_x_8);
			y1[7] = fvar_value(table_y_8);
            x1[8] = fvar_value(table_x_9);
			y1[8] = fvar_value(table_y_9);
			x1[9] = fvar_value(table_x_10);
			y1[9] = fvar_value(table_y_10);
			x1[10] = fvar_value(table_x_11);
			y1[10] = fvar_value(table_y_11);
			x1[11] = fvar_value(table_x_12);
			y1[11] = fvar_value(table_y_12);
			x1[12] = fvar_value(table_x_13);
			y1[12] = fvar_value(table_y_13);
			x1[13] = fvar_value(table_x_14);
			y1[13] = fvar_value(table_y_14);
			x1[14] = fvar_value(table_x_15);
			y1[14] = fvar_value(table_y_15);
			x1[15] = fvar_value(table_x_16);
			y1[15] = fvar_value(table_y_16);

			opcode = 1;

			/*		num_point = ivar_value(number_of_points); */

			iassign(trans1_FI_1_tab_opcode, opcode);
			WriteCommand(write_trans1_FI_1_tab_opcode);
			for (i=1;i<=num_point;i++)
			{
				iassign(trans1_FI_1_tab_entryidx,i);
				WriteCommand(write_trans1_FI_1_tab_entryidx);

				fassign(trans1_FI_1_tab_x_value,x1[i-1]);
				fassign(trans1_FI_1_tab_y_value,y1[i-1]);
				WriteCommand(write_trans1_FI_1_tab_value);
			}
			opcode = 3;
			iassign(trans1_FI_1_tab_opcode, opcode);
			WriteCommand(write_trans1_FI_1_tab_opcode);

			ReadCommand(read_trans1_FI_1_tab_status);
			status = ivar_value(trans1_FI_1_tab_status);

			switch (status)
			{
				case 0:
				{
					get_dictionary_string(lin_tab_status_NOT_INIT, text);
					PUT_MESSAGE (text);
					break;
				}
				case 2:
                case 20:
				{
					get_dictionary_string(lin_tab_status_NOT_INC, text);
					PUT_MESSAGE (text);
					break;
				}
				case 3:
                case 21:
				{
					get_dictionary_string(lin_tab_status_NOT_DEC, text);
					PUT_MESSAGE (text);
					break;
				}
				case 4:
                case 22:
				{
					get_dictionary_string(lin_tab_status_NOT_ENOUGH_VALUES, text);
					PUT_MESSAGE (text);
					break;
				}
				case 5:
                case 23:
				{
					get_dictionary_string(lin_tab_status_TOO_MANY_VALUES, text);
					PUT_MESSAGE (text);
					break;
				}
				case 6:
                case 24:
				{
					get_dictionary_string(lin_tab_status_GRADIENT, text);
					PUT_MESSAGE (text);
					break;
				}
				case 7:
                case 25:
				{
					get_dictionary_string(lin_tab_status_NOT_ACCEPTED, text);
					PUT_MESSAGE (text);
					break;
				}
                case 8:
                case 26:
				{
//					get_dictionary_string("Table is currently loaded", text);
//					PUT_MESSAGE (text);
                    PUT_MESSAGE ("Table is currently loaded");
					break;
				}
                case 9:
                case 27:
				{
//					get_dictionary_string("softing and checking of Table", text);
//					PUT_MESSAGE (text);
                    PUT_MESSAGE ("softing and checking of Table");
					break;
				}
				case 1:		// table status: good
				{
					get_dictionary_string(lin_tab_status_GOOD,text);
					PUT_MESSAGE (text);
					break;
				}
				default:
				{

                    PUT_MESSAGE (status);
                  
				 /*	get_dictionary_string(status, text);
					 PUT_MESSAGE (text); */
//					ACKNOWLEDGE(" Upper than sixteen  ");
					break;
				}
			}
		}
	 }
}

METHOD  method_trans1_FI_2_lin_type
{
    LABEL "Write";
	DEFINITION
	{
		WriteCommand(write_trans1_FI_2_lin_type);
		ReadCommand(read_trans1_FI_2_lin_type);
	}
}

METHOD  method_trans1_FI_2_scales
{
    LABEL "Write";
	DEFINITION
    {
    
		WriteCommand(write_trans1_FI_2_final_value_range);
		ReadCommand(read_trans1_FI_2_final_value_range);
    }
}
METHOD  method_trans1_FI_2_actuator_action
{
    LABEL "Write";
	DEFINITION
    {
    
		WriteCommand(write_trans1_FI_2_actuator_action);
		ReadCommand(read_trans1_FI_2_actuator_action);
    }
}
METHOD  method_trans1_FI_2_converter
{
    LABEL "Write";
	DEFINITION
    {
		WriteCommand(write_trans1_FI_2_act_sn);
		WriteCommand(write_trans1_FI_2_cal_loc);
		WriteCommand(write_trans1_FI_2_cal_date);
		WriteCommand(write_trans1_FI_2_cal_who);
		ReadCommand(read_trans1_FI_2_act_sn);
		ReadCommand(read_trans1_FI_2_cal_loc);
		ReadCommand(read_trans1_FI_2_cal_date);
		ReadCommand(read_trans1_FI_2_cal_who);
    }
}

METHOD	method_trans1_FI_2_lower_cal
{
	LABEL "Lower Calibration Point";
	HELP  "Lower Calibration Point";
	DEFINITION
	{
		char   flagtest1, flagtest;
		float  trim_point, var_feedback;
		int    rc, result, actual_mode, CalControl;

		flagtest1 = 0;
		flagtest = 0;

        actual_mode = ivar_value(func3_AO_2_actual_mode);
        if (actual_mode == 0x10)
        {
            CalControl = 1;
            fassign(trans1_FI_2_cal_control,CalControl);
            WriteCommand(write_trans1_FI_2_cal_control);
        }
        else
        {
            /* display a message that requires user acknowledgment */
            ACKNOWLEDGE("WARNING: Control loop should be in manual !");
			flagtest1 = 1;
			flagtest = 1;
        }

	  /*  3.99mA <= desired point <= 11.5mA */

	  /*  show operating limits for lower and wait acknowledgment from user */

		trim_point = fvar_value(trans1_FI_2_sensor_value);

		while (flagtest == 0)
		{
			rc=GET_LOCAL_VAR_VALUE("Lower Calibration Point ( from 3.99 to 11.50 mA ):", trim_point);

			if(rc==0)
			{
				if(trim_point < 3.99 || trim_point > 11.50)
				{
					ACKNOWLEDGE("Value out of range");
				}
				else
				{
					flagtest=1;
					fassign(trans1_FI_2_sensor_value,trim_point);
				    WriteCommand(write_trans1_FI_2_sensor_value);
				}
			}
			else
			{
				flagtest=1;
				flagtest1=1;
			}
	    }

        while (flagtest1 == 0)
        {
            ACKNOWLEDGE("Please, read the current in channel 2.");
            rc=GET_LOCAL_VAR_VALUE("Please, enter the miliamperimeter's current value:",var_feedback);

            if(rc==0)
            {
                fassign(trans1_FI_2_cal_point_lo,var_feedback);
                result = SELECT_FROM_LIST("Proceed it again ?","Yes;No");

                if (result == 0)
                  flagtest1 = 0;
                else
                {
                  WriteCommand(write_trans1_FI_2_cal_point_lo);
                  ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                  flagtest1 = 1;
                }
            }
            else
            {
                ReadCommand(read_trans1_FI_2_cal_point_lo);
                ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                flagtest1 = 1;
            }
        }
        CalControl = 0;
        fassign(trans1_FI_2_cal_control,CalControl);
        WriteCommand(write_trans1_FI_2_cal_control);
	}
}

METHOD	method_trans1_FI_2_upper_cal
{
	LABEL "Upper Calibration Point";
	HELP  "Upper Calibration Point";
	DEFINITION
	{
		char   flagtest1, flagtest;
		float  trim_point, var_feedback;
		int    rc, result, actual_mode, CalControl;

		flagtest1 = 0;
		flagtest = 0;

        actual_mode = ivar_value(func3_AO_2_actual_mode);
        if (actual_mode == 0x10)
        {
            CalControl = 1;
            fassign(trans1_FI_2_cal_control,CalControl);
            WriteCommand(write_trans1_FI_2_cal_control);
        }
        else
        {
            /* display a message that requires user acknowledgment */
            ACKNOWLEDGE("WARNING: Control loop should be in manual !");
			flagtest1 = 1;
			flagtest = 1;
        }

	  /*  12.5mA <= desired point <= 20.01 mA */

	  /*  show operating limits for upper and wait acknowledgment from user */

	    trim_point = fvar_value(trans1_FI_2_sensor_value);
	
	    while (flagtest == 0)
	    {
            rc=GET_LOCAL_VAR_VALUE("Upper Calibration Point ( from 12.5 to 20.01 mA ):", trim_point);

            if(rc==0)
            {
                if(trim_point < 12.5 || trim_point > 20.01)
                {
                    ACKNOWLEDGE("Value out of range");
                }
                else
                {
                    flagtest=1;
                    fassign(trans1_FI_2_sensor_value,trim_point);
                    WriteCommand(write_trans1_FI_2_sensor_value);
                }
            }
            else
            {
                flagtest=1;
                flagtest1=1;
            }
        }

        while (flagtest1 == 0)
        {
            ACKNOWLEDGE("Please, read the current in channel 2.");
            rc=GET_LOCAL_VAR_VALUE("Please, enter the miliamperimeter's current value:",var_feedback);

            if(rc==0)
            {
                fassign(trans1_FI_2_cal_point_hi,var_feedback);
                result = SELECT_FROM_LIST("Proceed it again ?","Yes;No");
                if (result == 0)
                  flagtest1 = 0;
                else
                {
                  WriteCommand(write_trans1_FI_2_cal_point_hi);
                  ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                  flagtest1 = 1;
                }
            }
            else
            {
                ReadCommand(read_trans1_FI_2_cal_point_hi);
                ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                flagtest1 = 1;
            }
        }
        CalControl = 0;
        fassign(trans1_FI_2_cal_control,CalControl);
        WriteCommand(write_trans1_FI_2_cal_control);
	}
}

METHOD method_read_table_2
{
	LABEL   "Read table";
	HELP 	[meth_read_table_src_help];
	DEFINITION
	{
		int i;
		float x1[16],y1[16];

		for (i=0;i<16;i++)
		{
			iassign(trans1_FI_2_tab_entryidx,i+1);
			WriteCommand(write_trans1_FI_2_tab_entryidx);
			ReadCommand(read_trans1_FI_2_tab_value);
			x1[i] = fvar_value(trans1_FI_2_tab_x_value);
			y1[i] = fvar_value(trans1_FI_2_tab_y_value);
		}

		fassign(table_x_1,x1[0]);
		fassign(table_y_1,y1[0]);
		fassign(table_x_2,x1[1]);
		fassign(table_y_2,y1[1]);
		fassign(table_x_3,x1[2]);
		fassign(table_y_3,y1[2]);
		fassign(table_x_4,x1[3]);
		fassign(table_y_4,y1[3]);
		fassign(table_x_5,x1[4]);
		fassign(table_y_5,y1[4]);
		fassign(table_x_6,x1[5]);
		fassign(table_y_6,y1[5]);
		fassign(table_x_7,x1[6]);
		fassign(table_y_7,y1[6]);
		fassign(table_x_8,x1[7]);
		fassign(table_y_8,y1[7]);
       	fassign(table_x_9,x1[8]);
		fassign(table_y_9,y1[8]);
		fassign(table_x_10,x1[9]);
		fassign(table_y_10,y1[9]);
		fassign(table_x_11,x1[10]);
		fassign(table_y_11,y1[10]);
		fassign(table_x_12,x1[11]);
		fassign(table_y_12,y1[11]);
		fassign(table_x_13,x1[12]);
		fassign(table_y_13,y1[12]);
		fassign(table_x_14,x1[13]);
		fassign(table_y_14,y1[13]);
		fassign(table_x_15,x1[14]);
		fassign(table_y_15,y1[14]);
		fassign(table_x_16,x1[15]);
		fassign(table_y_16,y1[15]);
	}
}
METHOD method_send_table_2
{
	LABEL "Write Table";
	DEFINITION
	{
		int     opcode,num_point,i, rc;
		float   x1[16],y1[16];
		int		status,flag1,flag2;
		char	text[];

		flag1 = 0;
		flag2 = 0;

		while (flag1 == 0)
		{
			rc=GET_LOCAL_VAR_VALUE("Please enter the number of points you would like to validate in your table.", num_point);
			if (rc==0)
			{
				if(num_point < 2 || num_point > 16)
				{
					ACKNOWLEDGE("Number of points is out of the range ( 2 - 16)");
				}
				else
				{
					flag1 = 1;
				}
			}
			else
			{
				flag1 = 1;
				flag2 = 1;
				ACKNOWLEDGE("The table will not be written");
			}
		}

		if (flag2==0)
		{
			x1[0] = fvar_value(table_x_1);
			y1[0] = fvar_value(table_y_1);
			x1[1] = fvar_value(table_x_2);
			y1[1] = fvar_value(table_y_2);
			x1[2] = fvar_value(table_x_3);
			y1[2] = fvar_value(table_y_3);
			x1[3] = fvar_value(table_x_4);
			y1[3] = fvar_value(table_y_4);
			x1[4] = fvar_value(table_x_5);
			y1[4] = fvar_value(table_y_5);
			x1[5] = fvar_value(table_x_6);
			y1[5] = fvar_value(table_y_6);
			x1[6] = fvar_value(table_x_7);
			y1[6] = fvar_value(table_y_7);
			x1[7] = fvar_value(table_x_8);
			y1[7] = fvar_value(table_y_8);
            x1[8] = fvar_value(table_x_9);
			y1[8] = fvar_value(table_y_9);
			x1[9] = fvar_value(table_x_10);
			y1[9] = fvar_value(table_y_10);
			x1[10] = fvar_value(table_x_11);
			y1[10] = fvar_value(table_y_11);
			x1[11] = fvar_value(table_x_12);
			y1[11] = fvar_value(table_y_12);
			x1[12] = fvar_value(table_x_13);
			y1[12] = fvar_value(table_y_13);
			x1[13] = fvar_value(table_x_14);
			y1[13] = fvar_value(table_y_14);
			x1[14] = fvar_value(table_x_15);
			y1[14] = fvar_value(table_y_15);
			x1[15] = fvar_value(table_x_16);
			y1[15] = fvar_value(table_y_16);

			opcode = 1;

			/*		num_point = ivar_value(number_of_points); */

			iassign(trans1_FI_2_tab_opcode, opcode);
			WriteCommand(write_trans1_FI_2_tab_opcode);
			for (i=1;i<=num_point;i++)
			{
				iassign(trans1_FI_2_tab_entryidx,i);
				WriteCommand(write_trans1_FI_2_tab_entryidx);

				fassign(trans1_FI_2_tab_x_value,x1[i-1]);
				fassign(trans1_FI_2_tab_y_value,y1[i-1]);
				WriteCommand(write_trans1_FI_2_tab_value);
			}
			opcode = 3;
			iassign(trans1_FI_2_tab_opcode, opcode);
			WriteCommand(write_trans1_FI_2_tab_opcode);

			ReadCommand(read_trans1_FI_2_tab_status);
			status = ivar_value(trans1_FI_2_tab_status);

			switch (status)
			{
				case 0:
				{
					get_dictionary_string(lin_tab_status_NOT_INIT, text);
					PUT_MESSAGE (text);
					break;
				}
				case 2:
                case 20:
				{
					get_dictionary_string(lin_tab_status_NOT_INC, text);
					PUT_MESSAGE (text);
					break;
				}
				case 3:
                case 21:
				{
					get_dictionary_string(lin_tab_status_NOT_DEC, text);
					PUT_MESSAGE (text);
					break;
				}
				case 4:
                case 22:
				{
					get_dictionary_string(lin_tab_status_NOT_ENOUGH_VALUES, text);
					PUT_MESSAGE (text);
					break;
				}
				case 5:
                case 23:
				{
					get_dictionary_string(lin_tab_status_TOO_MANY_VALUES, text);
					PUT_MESSAGE (text);
					break;
				}
				case 6:
                case 24:
				{
					get_dictionary_string(lin_tab_status_GRADIENT, text);
					PUT_MESSAGE (text);
					break;
				}
				case 7:
                case 25:
				{
					get_dictionary_string(lin_tab_status_NOT_ACCEPTED, text);
					PUT_MESSAGE (text);
					break;
				}
                case 8:
                case 26:
				{
//					get_dictionary_string("Table is currently loaded", text);
//					PUT_MESSAGE (text);
                    PUT_MESSAGE ("Table is currently loaded");
					break;
				}
                case 9:
                case 27:
				{
//					get_dictionary_string("softing and checking of Table", text);
//					PUT_MESSAGE (text);
                    PUT_MESSAGE ("softing and checking of Table");
					break;
				}
				case 1:		// table status: good
				{
					get_dictionary_string(lin_tab_status_GOOD,text);
					PUT_MESSAGE (text);
					break;
				}
				default:
				{

                    PUT_MESSAGE (status);
                  
				 /*	get_dictionary_string(status, text);
					 PUT_MESSAGE (text); */
//					ACKNOWLEDGE(" Upper than sixteen  ");
					break;
				}
			}
		}
	 }
}

METHOD  method_trans1_FI_3_lin_type
{
    LABEL "Write";
	DEFINITION
	{
		WriteCommand(write_trans1_FI_3_lin_type);
		ReadCommand(read_trans1_FI_3_lin_type);
	}
}

METHOD  method_trans1_FI_3_scales
{
    LABEL "Write";
	DEFINITION
    {
    
		WriteCommand(write_trans1_FI_3_final_value_range);
		ReadCommand(read_trans1_FI_3_final_value_range);
    }
}
METHOD  method_trans1_FI_3_actuator_action
{
    LABEL "Write";
	DEFINITION
    {
    
		WriteCommand(write_trans1_FI_3_actuator_action);
		ReadCommand(read_trans1_FI_3_actuator_action);
    }
}
METHOD  method_trans1_FI_3_converter
{
    LABEL "Write";
	DEFINITION
    {
		WriteCommand(write_trans1_FI_3_act_sn);
		WriteCommand(write_trans1_FI_3_cal_loc);
		WriteCommand(write_trans1_FI_3_cal_date);
		WriteCommand(write_trans1_FI_3_cal_who);
		ReadCommand(read_trans1_FI_3_act_sn);
		ReadCommand(read_trans1_FI_3_cal_loc);
		ReadCommand(read_trans1_FI_3_cal_date);
		ReadCommand(read_trans1_FI_3_cal_who);
    }
}

METHOD	method_trans1_FI_3_lower_cal
{
	LABEL "Lower Calibration Point";
	HELP  "Lower Calibration Point";
	DEFINITION
	{
		char   flagtest1, flagtest;
		float  trim_point, var_feedback;
		int    rc, result, actual_mode, CalControl;

		flagtest1 = 0;
		flagtest = 0;

        actual_mode = ivar_value(func3_AO_3_actual_mode);
        if (actual_mode == 0x10)
        {
            CalControl = 1;
            fassign(trans1_FI_3_cal_control,CalControl);
            WriteCommand(write_trans1_FI_3_cal_control);
        }
        else
        {
            /* display a message that requires user acknowledgment */
            ACKNOWLEDGE("WARNING: Control loop should be in manual !");
			flagtest1 = 1;
			flagtest = 1;
        }

	  /*  3.99mA <= desired point <= 11.5mA */

	  /*  show operating limits for lower and wait acknowledgment from user */

		trim_point = fvar_value(trans1_FI_3_sensor_value);

		while (flagtest == 0)
		{
			rc=GET_LOCAL_VAR_VALUE("Lower Calibration Point ( from 3.99 to 11.50 mA ):", trim_point);

			if(rc==0)
			{
				if(trim_point < 3.99 || trim_point > 11.50)
				{
					ACKNOWLEDGE("Value out of range");
				}
				else
				{
					flagtest=1;
					fassign(trans1_FI_3_sensor_value,trim_point);
				    WriteCommand(write_trans1_FI_3_sensor_value);
				}
			}
			else
			{
				flagtest=1;
				flagtest1=1;
			}
	    }

        while (flagtest1 == 0)
        {
            ACKNOWLEDGE("Please, read the current in channel 3.");
            rc=GET_LOCAL_VAR_VALUE("Please, enter the miliamperimeter's current value:",var_feedback);

            if(rc==0)
            {
                fassign(trans1_FI_3_cal_point_lo,var_feedback);
                result = SELECT_FROM_LIST("Proceed it again ?","Yes;No");

                if (result == 0)
                  flagtest1 = 0;
                else
                {
                  WriteCommand(write_trans1_FI_3_cal_point_lo);
                  ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                  flagtest1 = 1;
                }
            }
            else
            {
                ReadCommand(read_trans1_FI_3_cal_point_lo);
                ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                flagtest1 = 1;
            }
        }
        CalControl = 0;
        fassign(trans1_FI_3_cal_control,CalControl);
        WriteCommand(write_trans1_FI_3_cal_control);
	}
}

METHOD	method_trans1_FI_3_upper_cal
{
	LABEL "Upper Calibration Point";
	HELP  "Upper Calibration Point";
	DEFINITION
	{
		char   flagtest1, flagtest;
		float  trim_point, var_feedback;
		int    rc, result, actual_mode, CalControl;

		flagtest1 = 0;
		flagtest = 0;

        actual_mode = ivar_value(func3_AO_3_actual_mode);
        if (actual_mode == 0x10)
        {
            CalControl = 1;
            fassign(trans1_FI_3_cal_control,CalControl);
            WriteCommand(write_trans1_FI_3_cal_control);
        }
        else
        {
            /* display a message that requires user acknowledgment */
            ACKNOWLEDGE("WARNING: Control loop should be in manual !");
			flagtest1 = 1;
			flagtest = 1;
        }

	  /*  12.5mA <= desired point <= 20.01 mA */

	  /*  show operating limits for upper and wait acknowledgment from user */

	    trim_point = fvar_value(trans1_FI_3_sensor_value);
	
	    while (flagtest == 0)
	    {
            rc=GET_LOCAL_VAR_VALUE("Upper Calibration Point ( from 12.5 to 20.01 mA ):", trim_point);

            if(rc==0)
            {
                if(trim_point < 12.5 || trim_point > 20.01)
                {
                    ACKNOWLEDGE("Value out of range");
                }
                else
                {
                    flagtest=1;
                    fassign(trans1_FI_3_sensor_value,trim_point);
                    WriteCommand(write_trans1_FI_3_sensor_value);
                }
            }
            else
            {
                flagtest=1;
                flagtest1=1;
            }
        }

        while (flagtest1 == 0)
        {
            ACKNOWLEDGE("Please, read the current in channel 3.");
            rc=GET_LOCAL_VAR_VALUE("Please, enter the miliamperimeter's current value:",var_feedback);

            if(rc==0)
            {
                fassign(trans1_FI_3_cal_point_hi,var_feedback);
                result = SELECT_FROM_LIST("Proceed it again ?","Yes;No");
                if (result == 0)
                  flagtest1 = 0;
                else
                {
                  WriteCommand(write_trans1_FI_3_cal_point_hi);
                  ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                  flagtest1 = 1;
                }
            }
            else
            {
                ReadCommand(read_trans1_FI_3_cal_point_hi);
                ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                flagtest1 = 1;
            }
        }
        CalControl = 0;
        fassign(trans1_FI_3_cal_control,CalControl);
        WriteCommand(write_trans1_FI_3_cal_control);
	}
}

METHOD method_read_table_3
{
	LABEL   "Read table";
	HELP 	[meth_read_table_src_help];
	DEFINITION
	{
		int i;
		float x1[16],y1[16];

		for (i=0;i<16;i++)
		{
			iassign(trans1_FI_3_tab_entryidx,i+1);
			WriteCommand(write_trans1_FI_3_tab_entryidx);
			ReadCommand(read_trans1_FI_3_tab_value);
			x1[i] = fvar_value(trans1_FI_3_tab_x_value);
			y1[i] = fvar_value(trans1_FI_3_tab_y_value);
		}

		fassign(table_x_1,x1[0]);
		fassign(table_y_1,y1[0]);
		fassign(table_x_2,x1[1]);
		fassign(table_y_2,y1[1]);
		fassign(table_x_3,x1[2]);
		fassign(table_y_3,y1[2]);
		fassign(table_x_4,x1[3]);
		fassign(table_y_4,y1[3]);
		fassign(table_x_5,x1[4]);
		fassign(table_y_5,y1[4]);
		fassign(table_x_6,x1[5]);
		fassign(table_y_6,y1[5]);
		fassign(table_x_7,x1[6]);
		fassign(table_y_7,y1[6]);
		fassign(table_x_8,x1[7]);
		fassign(table_y_8,y1[7]);
       	fassign(table_x_9,x1[8]);
		fassign(table_y_9,y1[8]);
		fassign(table_x_10,x1[9]);
		fassign(table_y_10,y1[9]);
		fassign(table_x_11,x1[10]);
		fassign(table_y_11,y1[10]);
		fassign(table_x_12,x1[11]);
		fassign(table_y_12,y1[11]);
		fassign(table_x_13,x1[12]);
		fassign(table_y_13,y1[12]);
		fassign(table_x_14,x1[13]);
		fassign(table_y_14,y1[13]);
		fassign(table_x_15,x1[14]);
		fassign(table_y_15,y1[14]);
		fassign(table_x_16,x1[15]);
		fassign(table_y_16,y1[15]);
	}
}
METHOD method_send_table_3
{
	LABEL "Write Table";
	DEFINITION
	{
		int     opcode,num_point,i, rc;
		float   x1[16],y1[16];
		int		status,flag1,flag2;
		char	text[];

		flag1 = 0;
		flag2 = 0;

		while (flag1 == 0)
		{
			rc=GET_LOCAL_VAR_VALUE("Please enter the number of points you would like to validate in your table.", num_point);
			if (rc==0)
			{
				if(num_point < 2 || num_point > 16)
				{
					ACKNOWLEDGE("Number of points is out of the range ( 2 - 16)");
				}
				else
				{
					flag1 = 1;
				}
			}
			else
			{
				flag1 = 1;
				flag2 = 1;
				ACKNOWLEDGE("The table will not be written");
			}
		}

		if (flag2==0)
		{
			x1[0] = fvar_value(table_x_1);
			y1[0] = fvar_value(table_y_1);
			x1[1] = fvar_value(table_x_2);
			y1[1] = fvar_value(table_y_2);
			x1[2] = fvar_value(table_x_3);
			y1[2] = fvar_value(table_y_3);
			x1[3] = fvar_value(table_x_4);
			y1[3] = fvar_value(table_y_4);
			x1[4] = fvar_value(table_x_5);
			y1[4] = fvar_value(table_y_5);
			x1[5] = fvar_value(table_x_6);
			y1[5] = fvar_value(table_y_6);
			x1[6] = fvar_value(table_x_7);
			y1[6] = fvar_value(table_y_7);
			x1[7] = fvar_value(table_x_8);
			y1[7] = fvar_value(table_y_8);
            x1[8] = fvar_value(table_x_9);
			y1[8] = fvar_value(table_y_9);
			x1[9] = fvar_value(table_x_10);
			y1[9] = fvar_value(table_y_10);
			x1[10] = fvar_value(table_x_11);
			y1[10] = fvar_value(table_y_11);
			x1[11] = fvar_value(table_x_12);
			y1[11] = fvar_value(table_y_12);
			x1[12] = fvar_value(table_x_13);
			y1[12] = fvar_value(table_y_13);
			x1[13] = fvar_value(table_x_14);
			y1[13] = fvar_value(table_y_14);
			x1[14] = fvar_value(table_x_15);
			y1[14] = fvar_value(table_y_15);
			x1[15] = fvar_value(table_x_16);
			y1[15] = fvar_value(table_y_16);

			opcode = 1;

			/*		num_point = ivar_value(number_of_points); */

			iassign(trans1_FI_3_tab_opcode, opcode);
			WriteCommand(write_trans1_FI_3_tab_opcode);
			for (i=1;i<=num_point;i++)
			{
				iassign(trans1_FI_3_tab_entryidx,i);
				WriteCommand(write_trans1_FI_3_tab_entryidx);

				fassign(trans1_FI_3_tab_x_value,x1[i-1]);
				fassign(trans1_FI_3_tab_y_value,y1[i-1]);
				WriteCommand(write_trans1_FI_3_tab_value);
			}
			opcode = 3;
			iassign(trans1_FI_3_tab_opcode, opcode);
			WriteCommand(write_trans1_FI_3_tab_opcode);

			ReadCommand(read_trans1_FI_3_tab_status);
			status = ivar_value(trans1_FI_3_tab_status);

			switch (status)
			{
				case 0:
				{
					get_dictionary_string(lin_tab_status_NOT_INIT, text);
					PUT_MESSAGE (text);
					break;
				}
				case 2:
                case 20:
				{
					get_dictionary_string(lin_tab_status_NOT_INC, text);
					PUT_MESSAGE (text);
					break;
				}
				case 3:
                case 21:
				{
					get_dictionary_string(lin_tab_status_NOT_DEC, text);
					PUT_MESSAGE (text);
					break;
				}
				case 4:
                case 22:
				{
					get_dictionary_string(lin_tab_status_NOT_ENOUGH_VALUES, text);
					PUT_MESSAGE (text);
					break;
				}
				case 5:
                case 23:
				{
					get_dictionary_string(lin_tab_status_TOO_MANY_VALUES, text);
					PUT_MESSAGE (text);
					break;
				}
				case 6:
                case 24:
				{
					get_dictionary_string(lin_tab_status_GRADIENT, text);
					PUT_MESSAGE (text);
					break;
				}
				case 7:
                case 25:
				{
					get_dictionary_string(lin_tab_status_NOT_ACCEPTED, text);
					PUT_MESSAGE (text);
					break;
				}
                case 8:
                case 26:
				{
//					get_dictionary_string("Table is currently loaded", text);
//					PUT_MESSAGE (text);
                    PUT_MESSAGE ("Table is currently loaded");
					break;
				}
                case 9:
                case 27:
				{
//					get_dictionary_string("softing and checking of Table", text);
//					PUT_MESSAGE (text);
                    PUT_MESSAGE ("softing and checking of Table");
					break;
				}
				case 1:		// table status: good
				{
					get_dictionary_string(lin_tab_status_GOOD,text);
					PUT_MESSAGE (text);
					break;
				}
				default:
				{

                    PUT_MESSAGE (status);
                  
				 /*	get_dictionary_string(status, text);
					 PUT_MESSAGE (text); */
//					ACKNOWLEDGE(" Upper than sixteen  ");
					break;
				}
			}
		}
	 }
}

METHOD  method_trans1_FI_4_lin_type
{
    LABEL "Write";
	DEFINITION
	{
		WriteCommand(write_trans1_FI_4_lin_type);
		ReadCommand(read_trans1_FI_4_lin_type);
	}
}

METHOD  method_trans1_FI_4_scales
{
    LABEL "Write";
	DEFINITION
    {
    
		WriteCommand(write_trans1_FI_4_final_value_range);
		ReadCommand(read_trans1_FI_4_final_value_range);
    }
}
METHOD  method_trans1_FI_4_actuator_action
{
    LABEL "Write";
	DEFINITION
    {
    
		WriteCommand(write_trans1_FI_4_actuator_action);
		ReadCommand(read_trans1_FI_4_actuator_action);
    }
}
METHOD  method_trans1_FI_4_converter
{
    LABEL "Write";
	DEFINITION
    {
		WriteCommand(write_trans1_FI_4_act_sn);
		WriteCommand(write_trans1_FI_4_cal_loc);
		WriteCommand(write_trans1_FI_4_cal_date);
		WriteCommand(write_trans1_FI_4_cal_who);
		ReadCommand(read_trans1_FI_4_act_sn);
		ReadCommand(read_trans1_FI_4_cal_loc);
		ReadCommand(read_trans1_FI_4_cal_date);
		ReadCommand(read_trans1_FI_4_cal_who);
    }
}

METHOD	method_trans1_FI_4_lower_cal
{
	LABEL "Lower Calibration Point";
	HELP  "Lower Calibration Point";
	DEFINITION
	{
		char   flagtest1, flagtest;
		float  trim_point, var_feedback;
		int    rc, result, actual_mode, CalControl;

		flagtest1 = 0;
		flagtest = 0;

        actual_mode = ivar_value(func3_AO_4_actual_mode);
        if (actual_mode == 0x10)
        {
            CalControl = 1;
            fassign(trans1_FI_4_cal_control,CalControl);
            WriteCommand(write_trans1_FI_4_cal_control);
        }
        else
        {
            /* display a message that requires user acknowledgment */
            ACKNOWLEDGE("WARNING: Control loop should be in manual !");
			flagtest1 = 1;
			flagtest = 1;
        }

	  /*  3.99mA <= desired point <= 11.5mA */

	  /*  show operating limits for lower and wait acknowledgment from user */

		trim_point = fvar_value(trans1_FI_4_sensor_value);

		while (flagtest == 0)
		{
			rc=GET_LOCAL_VAR_VALUE("Lower Calibration Point ( from 3.99 to 11.50 mA ):", trim_point);

			if(rc==0)
			{
				if(trim_point < 3.99 || trim_point > 11.50)
				{
					ACKNOWLEDGE("Value out of range");
				}
				else
				{
					flagtest=1;
					fassign(trans1_FI_4_sensor_value,trim_point);
				    WriteCommand(write_trans1_FI_4_sensor_value);
				}
			}
			else
			{
				flagtest=1;
				flagtest1=1;
			}
	    }

        while (flagtest1 == 0)
        {
            ACKNOWLEDGE("Please, read the current in channel 4.");
            rc=GET_LOCAL_VAR_VALUE("Please, enter the miliamperimeter's current value:",var_feedback);

            if(rc==0)
            {
                fassign(trans1_FI_4_cal_point_lo,var_feedback);
                result = SELECT_FROM_LIST("Proceed it again ?","Yes;No");

                if (result == 0)
                  flagtest1 = 0;
                else
                {
                  WriteCommand(write_trans1_FI_4_cal_point_lo);
                  ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                  flagtest1 = 1;
                }
            }
            else
            {
                ReadCommand(read_trans1_FI_4_cal_point_lo);
                ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                flagtest1 = 1;
            }
        }
        CalControl = 0;
        fassign(trans1_FI_4_cal_control,CalControl);
        WriteCommand(write_trans1_FI_4_cal_control);
	}
}

METHOD	method_trans1_FI_4_upper_cal
{
	LABEL "Upper Calibration Point";
	HELP  "Upper Calibration Point";
	DEFINITION
	{
		char   flagtest1, flagtest;
		float  trim_point, var_feedback;
		int    rc, result, actual_mode, CalControl;

		flagtest1 = 0;
		flagtest = 0;

        actual_mode = ivar_value(func3_AO_4_actual_mode);
        if (actual_mode == 0x10)
        {
            CalControl = 1;
            fassign(trans1_FI_4_cal_control,CalControl);
            WriteCommand(write_trans1_FI_4_cal_control);
        }
        else
        {
            /* display a message that requires user acknowledgment */
            ACKNOWLEDGE("WARNING: Control loop should be in manual !");
			flagtest1 = 1;
			flagtest = 1;
        }

	  /*  12.5mA <= desired point <= 20.01 mA */

	  /*  show operating limits for upper and wait acknowledgment from user */

	    trim_point = fvar_value(trans1_FI_4_sensor_value);
	
	    while (flagtest == 0)
	    {
            rc=GET_LOCAL_VAR_VALUE("Upper Calibration Point ( from 12.5 to 20.01 mA ):", trim_point);

            if(rc==0)
            {
                if(trim_point < 12.5 || trim_point > 20.01)
                {
                    ACKNOWLEDGE("Value out of range");
                }
                else
                {
                    flagtest=1;
                    fassign(trans1_FI_4_sensor_value,trim_point);
                    WriteCommand(write_trans1_FI_4_sensor_value);
                }
            }
            else
            {
                flagtest=1;
                flagtest1=1;
            }
        }

        while (flagtest1 == 0)
        {
            ACKNOWLEDGE("Please, read the current in channel 4.");
            rc=GET_LOCAL_VAR_VALUE("Please, enter the miliamperimeter's current value:",var_feedback);

            if(rc==0)
            {
                fassign(trans1_FI_4_cal_point_hi,var_feedback);
                result = SELECT_FROM_LIST("Proceed it again ?","Yes;No");
                if (result == 0)
                  flagtest1 = 0;
                else
                {
                  WriteCommand(write_trans1_FI_4_cal_point_hi);
                  ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                  flagtest1 = 1;
                }
            }
            else
            {
                ReadCommand(read_trans1_FI_4_cal_point_hi);
                ACKNOWLEDGE("WARNING: Loop must be returned to auto mode !");
                flagtest1 = 1;
            }
        }
        CalControl = 0;
        fassign(trans1_FI_4_cal_control,CalControl);
        WriteCommand(write_trans1_FI_4_cal_control);
	}
}

METHOD method_read_table_4
{
	LABEL   "Read table";
	HELP 	[meth_read_table_src_help];
	DEFINITION
	{
		int i;
		float x1[16],y1[16];

		for (i=0;i<16;i++)
		{
			iassign(trans1_FI_4_tab_entryidx,i+1);
			WriteCommand(write_trans1_FI_4_tab_entryidx);
			ReadCommand(read_trans1_FI_4_tab_value);
			x1[i] = fvar_value(trans1_FI_4_tab_x_value);
			y1[i] = fvar_value(trans1_FI_4_tab_y_value);
		}

		fassign(table_x_1,x1[0]);
		fassign(table_y_1,y1[0]);
		fassign(table_x_2,x1[1]);
		fassign(table_y_2,y1[1]);
		fassign(table_x_3,x1[2]);
		fassign(table_y_3,y1[2]);
		fassign(table_x_4,x1[3]);
		fassign(table_y_4,y1[3]);
		fassign(table_x_5,x1[4]);
		fassign(table_y_5,y1[4]);
		fassign(table_x_6,x1[5]);
		fassign(table_y_6,y1[5]);
		fassign(table_x_7,x1[6]);
		fassign(table_y_7,y1[6]);
		fassign(table_x_8,x1[7]);
		fassign(table_y_8,y1[7]);
       	fassign(table_x_9,x1[8]);
		fassign(table_y_9,y1[8]);
		fassign(table_x_10,x1[9]);
		fassign(table_y_10,y1[9]);
		fassign(table_x_11,x1[10]);
		fassign(table_y_11,y1[10]);
		fassign(table_x_12,x1[11]);
		fassign(table_y_12,y1[11]);
		fassign(table_x_13,x1[12]);
		fassign(table_y_13,y1[12]);
		fassign(table_x_14,x1[13]);
		fassign(table_y_14,y1[13]);
		fassign(table_x_15,x1[14]);
		fassign(table_y_15,y1[14]);
		fassign(table_x_16,x1[15]);
		fassign(table_y_16,y1[15]);
	}
}
METHOD method_send_table_4
{
	LABEL "Write Table";
	DEFINITION
	{
		int     opcode,num_point,i, rc;
		float   x1[16],y1[16];
		int		status,flag1,flag2;
		char	text[];

		flag1 = 0;
		flag2 = 0;

		while (flag1 == 0)
		{
			rc=GET_LOCAL_VAR_VALUE("Please enter the number of points you would like to validate in your table.", num_point);
			if (rc==0)
			{
				if(num_point < 2 || num_point > 16)
				{
					ACKNOWLEDGE("Number of points is out of the range ( 2 - 16)");
				}
				else
				{
					flag1 = 1;
				}
			}
			else
			{
				flag1 = 1;
				flag2 = 1;
				ACKNOWLEDGE("The table will not be written");
			}
		}

		if (flag2==0)
		{
			x1[0] = fvar_value(table_x_1);
			y1[0] = fvar_value(table_y_1);
			x1[1] = fvar_value(table_x_2);
			y1[1] = fvar_value(table_y_2);
			x1[2] = fvar_value(table_x_3);
			y1[2] = fvar_value(table_y_3);
			x1[3] = fvar_value(table_x_4);
			y1[3] = fvar_value(table_y_4);
			x1[4] = fvar_value(table_x_5);
			y1[4] = fvar_value(table_y_5);
			x1[5] = fvar_value(table_x_6);
			y1[5] = fvar_value(table_y_6);
			x1[6] = fvar_value(table_x_7);
			y1[6] = fvar_value(table_y_7);
			x1[7] = fvar_value(table_x_8);
			y1[7] = fvar_value(table_y_8);
            x1[8] = fvar_value(table_x_9);
			y1[8] = fvar_value(table_y_9);
			x1[9] = fvar_value(table_x_10);
			y1[9] = fvar_value(table_y_10);
			x1[10] = fvar_value(table_x_11);
			y1[10] = fvar_value(table_y_11);
			x1[11] = fvar_value(table_x_12);
			y1[11] = fvar_value(table_y_12);
			x1[12] = fvar_value(table_x_13);
			y1[12] = fvar_value(table_y_13);
			x1[13] = fvar_value(table_x_14);
			y1[13] = fvar_value(table_y_14);
			x1[14] = fvar_value(table_x_15);
			y1[14] = fvar_value(table_y_15);
			x1[15] = fvar_value(table_x_16);
			y1[15] = fvar_value(table_y_16);

			opcode = 1;

			/*		num_point = ivar_value(number_of_points); */

			iassign(trans1_FI_4_tab_opcode, opcode);
			WriteCommand(write_trans1_FI_4_tab_opcode);
			for (i=1;i<=num_point;i++)
			{
				iassign(trans1_FI_4_tab_entryidx,i);
				WriteCommand(write_trans1_FI_4_tab_entryidx);

				fassign(trans1_FI_4_tab_x_value,x1[i-1]);
				fassign(trans1_FI_4_tab_y_value,y1[i-1]);
				WriteCommand(write_trans1_FI_4_tab_value);
			}
			opcode = 3;
			iassign(trans1_FI_4_tab_opcode, opcode);
			WriteCommand(write_trans1_FI_4_tab_opcode);

			ReadCommand(read_trans1_FI_4_tab_status);
			status = ivar_value(trans1_FI_4_tab_status);

			switch (status)
			{
				case 0:
				{
					get_dictionary_string(lin_tab_status_NOT_INIT, text);
					PUT_MESSAGE (text);
					break;
				}
				case 2:
                case 20:
				{
					get_dictionary_string(lin_tab_status_NOT_INC, text);
					PUT_MESSAGE (text);
					break;
				}
				case 3:
                case 21:
				{
					get_dictionary_string(lin_tab_status_NOT_DEC, text);
					PUT_MESSAGE (text);
					break;
				}
				case 4:
                case 22:
				{
					get_dictionary_string(lin_tab_status_NOT_ENOUGH_VALUES, text);
					PUT_MESSAGE (text);
					break;
				}
				case 5:
                case 23:
				{
					get_dictionary_string(lin_tab_status_TOO_MANY_VALUES, text);
					PUT_MESSAGE (text);
					break;
				}
				case 6:
                case 24:
				{
					get_dictionary_string(lin_tab_status_GRADIENT, text);
					PUT_MESSAGE (text);
					break;
				}
				case 7:
                case 25:
				{
					get_dictionary_string(lin_tab_status_NOT_ACCEPTED, text);
					PUT_MESSAGE (text);
					break;
				}
                case 8:
                case 26:
				{
//					get_dictionary_string("Table is currently loaded", text);
//					PUT_MESSAGE (text);
                    PUT_MESSAGE ("Table is currently loaded");
					break;
				}
                case 9:
                case 27:
				{
//					get_dictionary_string("softing and checking of Table", text);
//					PUT_MESSAGE (text);
                    PUT_MESSAGE ("softing and checking of Table");
					break;
				}
				case 1:		// table status: good
				{
					get_dictionary_string(lin_tab_status_GOOD,text);
					PUT_MESSAGE (text);
					break;
				}
				default:
				{

                    PUT_MESSAGE (status);
                  
				 /*	get_dictionary_string(status, text);
					 PUT_MESSAGE (text); */
//					ACKNOWLEDGE(" Upper than sixteen  ");
					break;
				}
			}
		}
	 }
}
